<?php
/*
Plugin Name: ARForms - Stripe Addon
Description: Extension for Arforms plugin to accept stripe payments
Version: 1.6
Plugin URI: http://www.arformsplugin.com/
Author: Repute InfoSystems
Author URI: http://reputeinfosystems.com/
Text Domain: ARForms-Stripe
*/


global $arfsiteurl;
$arfsiteurl = home_url();
if (is_ssl() and ( !preg_match('/^https:\/\/.*\..*$/', $arfsiteurl) or ! preg_match('/^https:\/\/.*\..*$/', WP_PLUGIN_URL))) {
    $arfsiteurl = str_replace('http://', 'https://', $arfsiteurl);
    define('ARF_STRIPE_URL', str_replace('http://', 'https://', WP_PLUGIN_URL . '/arformsstripe'));
} else
{  define('ARF_STRIPE_URL', WP_PLUGIN_URL . '/arformsstripe');}

if(!defined('ARF_STRIPE_DIR')){
	define('ARF_STRIPE_DIR', WP_PLUGIN_DIR . '/arformsstripe');
}

load_plugin_textdomain('ARForms-Stripe', false, 'arformsstripe/languages/' );

global $arf_stripe;
$arf_stripe = new ARF_Stripe();

global $arf_stripe_version;
$arf_stripe_version = '1.6';

global $arf_stripe_shortname;
$arf_stripe_shortname = 'ARFSTRP';


class ARF_Stripe {
	
	var $db_stripe_forms;
	var $db_stripe_order;
	
        function __construct() {
		global $wpdb,$is_version_compatible;
		$is_version_compatible = $this->is_arforms_version();
		
		$this->db_stripe_forms = $wpdb->prefix . 'arf_stripe_forms';
		$this->db_stripe_order = $wpdb->prefix . 'arf_stripe_order';
			    
        add_action('init', array('ARF_Stripe', 'arf_stripe_db_check'));
		
		register_activation_hook(__FILE__, array('ARF_Stripe', 'install') );

		register_activation_hook(__FILE__, array('ARF_Stripe', 'arf_stripe_check_network_activation'));
		
		register_uninstall_hook(__FILE__, array('ARF_Stripe', 'uninstall') );
		
		add_action('admin_menu', array(&$this, 'arf_stripe_menu'), 27);
		
		add_action('admin_notices', array(&$this, 'arf_stripe_admin_notices') );
		
		add_filter('arfafterviewentrydetail', array(&$this, 'arf_stripe_payment_detail'), 10, 2 );
		
		add_action('wp_ajax_arf_stripe_delete_order', array(&$this, 'arf_stripe_delete_order') );
		
		add_action('wp_ajax_arf_stripe_order_bulk_act', array(&$this, 'arf_stripe_order_bulk_act') );
				
		add_action('wp_ajax_arf_stripe_delete_form', array(&$this, 'arf_stripe_delete_form') );
		
		add_action('wp_ajax_arf_stripe_form_bulk_act', array(&$this, 'arf_stripe_form_bulk_act') );
						
		add_action('admin_enqueue_scripts', array( &$this, 'arf_set_js'), 11);
		
		add_action('admin_enqueue_scripts', array( &$this, 'arf_set_css'), 11);
		
		add_action('wp_ajax_arf_stripe_field_dropdown', array(&$this, 'arf_stripe_field_dropdown') );
		
		add_action('arfbeforedestroyform', array(&$this, 'arfdelete_stripe_form'), 11, 1);

		add_filter('upgrader_pre_install', array(&$this, 'arfstripe_backup'), 10, 2);
		
		add_action('admin_init', array( &$this, 'upgrade_data'));
		
		add_action('wp_ajax_arfs_form_order', array( &$this, 'arfs_form_order'));
		
		add_action('init', array(&$this, 'parse_standalone_request'));
		
        if (version_compare($this->get_arforms_version(), '2.5.4', '>=')) 
		{
		 	add_filter( 'arf_is_validateform_outside', array(&$this, 'arfstripe_validate_process'), 20, 2 );
		
			add_filter( 'arf_validate_form_outside_errors', array(&$this, 'arf_prevalidate_card'), 20, 4 );
		}
		else
		{
			add_filter('arf_validateform_outside', array(&$this, 'arfstripe_validate_process'), 20, 2 );
		
			add_action( 'wp_ajax_arf_prevalidate_field', array(&$this, 'arf_prevalidatecard') );
	
			add_action( 'wp_ajax_nopriv_arf_prevalidate_field', array(&$this, 'arf_prevalidatecard') );
		}
		
		//add_action( 'arf_predisplay_form', array(&$this, 'arf_before_form_render'), 10, 1 );	
		
		
		add_filter( 'arf_before_create_formentry', array(&$this, 'arf_before_submission_process_payment'), 9, 1 );	
		
		add_action( 'arfaftercreateentry', array(&$this, 'arf_change_entry_id'), 2, 2 );
		
		if($is_version_compatible)
		{
		    add_filter('arf_predisplay_form', array(&$this, 'arf_before_form_render_v3'), 10, 2); 
		    add_action('wp_ajax_add_new_rule_stripe_multiple_subscription', array(&$this, 'add_new_rule_stripe_multiple_subscription_v3') );
		    add_action('wp_ajax_add_new_rule_stripe', array(&$this, 'add_new_rule_stripe_v3'));	
		}
		else
		{
		    add_action( 'arf_predisplay_form', array(&$this, 'arf_before_form_render'), 10, 1 );
		    add_action('wp_ajax_add_new_rule_stripe_multiple_subscription', array(&$this, 'add_new_rule_stripe_multiple_subscription') );
		    add_action('wp_ajax_add_new_rule_stripe', array(&$this, 'add_new_rule_stripe') );	
		}

		add_filter( 'arf_after_create_formentry', array(&$this, 'arf_change_entryid_fail'), 9, 2 );
		
		add_filter( 'arfpredisplayformcols', array(&$this, 'arfprechangestripeformcols'), 11, 2 ); 	
		
		add_filter('script_loader_tag', array(&$this, 'arf_stripe_prevent_rocket_loader_script'), 10, 2);
		
		add_action('user_register',array(&$this,'arf_add_capabilities_to_new_user'));

		add_filter('arf_prevent_paypal_to_stop_sending_email_outside',array(&$this,'arf_stripe_send_conditional_email'),10,3 );
	}
	
	public static function arf_stripe_check_network_activation($network_wide){
        if (!$network_wide)
           return;

        deactivate_plugins(plugin_basename(__FILE__), TRUE, TRUE);

        header('Location: ' . network_admin_url('plugins.php?deactivate=true'));
        exit;
    }

    function arf_stripe_getapiurl() {
        $api_url = 'https://www.arpluginshop.com/';
        return $api_url;
    }

    function arf_stripe_get_remote_post_params($plugin_info = "") {
        global $wpdb, $arfversion;

        $action = "";
        $action = $plugin_info;

        if (!function_exists('get_plugins')) {
            require_once(ABSPATH . 'wp-admin/includes/plugin.php');
        }
        $plugin_list = get_plugins();
        $site_url = home_url();
        $plugins = array();

        $active_plugins = get_option('active_plugins');

        foreach ($plugin_list as $key => $plugin) {
            $is_active = in_array($key, $active_plugins);


            if (strpos(strtolower($plugin["Title"]), "arformsstripe") !== false) {
                $name = substr($key, 0, strpos($key, "/"));
                $plugins[] = array("name" => $name, "version" => $plugin["Version"], "is_active" => $is_active);
            }
        }
        $plugins = json_encode($plugins);


        $theme = wp_get_theme();
        $theme_name = $theme->get("Name");
        $theme_uri = $theme->get("ThemeURI");
        $theme_version = $theme->get("Version");
        $theme_author = $theme->get("Author");
        $theme_author_uri = $theme->get("AuthorURI");

        $im = is_multisite();
        $sortorder = get_option("arfSortOrder");

        $post = array("wp" => get_bloginfo("version"), "php" => phpversion(), "mysql" => $wpdb->db_version(), "plugins" => $plugins, "tn" => $theme_name, "tu" => $theme_uri, "tv" => $theme_version, "ta" => $theme_author, "tau" => $theme_author_uri, "im" => $im, "sortorder" => $sortorder);

        return $post;
    }

	function arf_add_capabilities_to_new_user($user_id)
	{
            if( $user_id == '' ){
                return;
            }
            if( user_can($user_id,'administrator')){
		
		$stripecapabilities = array(
		    'arfstripeconfiguration' => __('Configure Stripe Forms', 'ARForms-Stripe'),
		    'arfstripetransaction' => __('View Stripe Transactions', 'ARForms-Stripe'),	
		);
		
		$arfroles = $stripecapabilities;

                $userObj = new WP_User($user_id);
                foreach ($arfroles as $arfrole => $arfroledescription){
                    $userObj->add_cap($arfrole);
                }
                unset($arfrole);
                unset($arfroles);
                unset($arfroledescription);
            }
	}
	
	public static function arf_stripe_db_check(){
	global $arf_stripe;
		$arf_stripe_version = get_option('arf_stripe_version');
		
		if( !isset($arf_stripe_version) || $arf_stripe_version ==''  )
                {  $arf_stripe->install();}
	}

	public static function install(){
            global $arf_stripe;
            $arf_stripe_version = get_option('arf_stripe_version');
		
		if( !isset($arf_stripe_version) || $arf_stripe_version ==''  ) {
			
			global $wpdb, $arf_stripe_version;
			
			update_option('arf_stripe_version', $arf_stripe_version);	
						
			$charset_collate = '';
			
			if( !empty($wpdb->charset) )
				$charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
	
			if( !empty($wpdb->collate) )
				$charset_collate .= " COLLATE $wpdb->collate";
			if(file_exists(ABSPATH . 'wp-admin/includes/upgrade.php')){
				require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
			}
						
			$table_name = $arf_stripe->db_stripe_order;		
			
			$sql = "CREATE TABLE {$table_name} (
	
					id int(11) NOT NULL auto_increment,
					
					item_name varchar(255) default NULL,
					
					txn_id varchar(255) default NULL,
					 
					payment_status varchar(255) default NULL,               
	
					mc_gross float(11,2) default NULL,
	
					mc_currency varchar(255) default NULL,
					
					quantity varchar(255) default NULL,
					
					payer_email varchar(255) default NULL,
					
					payment_type varchar(255) default NULL,
					 		
					user_id int(11) default NULL,
					
					entry_id int(11) default NULL,	
	
					form_id int(11) default NULL,
					
					created_at datetime NOT NULL,
					
					PRIMARY KEY (id)
	
				  ) {$charset_collate};";
			
			dbDelta($sql);
			
						
			$table_name = $arf_stripe->db_stripe_forms;		
			
			$sql = "CREATE TABLE {$table_name} (
	
					id int(11) NOT NULL auto_increment,
					
					form_id int(11) NOT NULL,
					
					form_name varchar(255) default NULL,
					
					options longtext default NULL,
					
					created_at datetime NOT NULL,
					 	
					PRIMARY KEY (id)
	
				  ) {$charset_collate};";
				
			dbDelta($sql);
			
            $arf_stripe->getwpversion();
		}
		
		$args = array(
		'role' => 'administrator',
		'fields' => 'id'
	    );
	    $users = get_users($args);
	    if( count($users) > 0 ){
		foreach($users as $key => $user_id ){

		   $stripecapabilities = array(
			'arfstripeconfiguration' => __('Configure Stripe Forms', 'ARForms-Stripe'),
			'arfstripetransaction' => __('View Stripe Transactions', 'ARForms-Stripe'),	
		    );
		    $arfroles = $stripecapabilities;

		    $userObj = new WP_User($user_id);
		    foreach ($arfroles as $arfrole => $arfroledescription){
			$userObj->add_cap($arfrole);
		    }
		    unset($arfrole);
		    unset($arfroles);
		    unset($arfroledescription);
		}
	    }
		
	}

	public static function uninstall(){
		global $wpdb,$arf_stripe;
		if ( is_multisite() ) {		
			$blogs = $wpdb->get_results("SELECT blog_id FROM {$wpdb->blogs}", ARRAY_A);
			if ($blogs) {
				foreach($blogs as $blog) {
					switch_to_blog($blog['blog_id']);
					
					delete_option('arf_stripe_version');
					$wpdb->query('DROP TABLE IF EXISTS '.$arf_stripe->db_stripe_forms);
					$wpdb->query('DROP TABLE IF EXISTS '.$arf_stripe->db_stripe_order);		
				}
				restore_current_blog();
			}
			
		} else {		
			delete_option('arf_stripe_version');
			$wpdb->query('DROP TABLE IF EXISTS '.$arf_stripe->db_stripe_forms);
			$wpdb->query('DROP TABLE IF EXISTS '.$arf_stripe->db_stripe_order);
		}		
	}
	

	function arf_stripe_admin_notices() {
		
        if (!$this->is_arforms_support())
			echo "<div class='updated'><p>".__('Stripe For ARForms plugin requires ARForms Plugin installed and active.', 'ARForms-Stripe')."</p></div>";
			
        else if (!version_compare($this->get_arforms_version(), '2.5.3', '>='))
			echo "<div class='updated'><p>".__('Stripe For ARForms plugin requires ARForms plugin installed with version 2.5.3 or higher.', 'ARForms-Stripe')."</p></div>";						
	}
	
	function is_arforms_support(){
		if (file_exists( ABSPATH . 'wp-admin/includes/plugin.php' )) {
		    include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		}
		
		
		return is_plugin_active( 'arforms/arforms.php' );
		
	}
	
	function get_arforms_version(){
		
		$arf_db_version = get_option('arf_db_version');
		
		return (isset($arf_db_version)) ? $arf_db_version : 0;
	}

	function route(){
            global $arf_stripe,$is_version_compatible;
            if( isset($_REQUEST['page']) and $_REQUEST['page'] == 'ARForms-Stripe' and isset($_REQUEST['arfaction']) and ( $_REQUEST['arfaction'] == 'new' || $_REQUEST['arfaction'] == 'edit' ) ){
		    if($is_version_compatible){
			return $arf_stripe->edit_form_v3();
		    }else{
			return $arf_stripe->edit_form();
		    }

		} else if( isset($_REQUEST['page']) and $_REQUEST['page'] == 'ARForms-Stripe-order' ){		
			
            return $arf_stripe->list_orders();
		} else {	
			
            return $arf_stripe->list_forms();
		}
		
	}

	function arf_stripe_menu(){
		
        if (version_compare($this->get_arforms_version(), '2.5.3', '>=')) {
			
			global $arfsettings;

			
				
            add_submenu_page('ARForms', 'ARForms | ' . __('Stripe Configuration', 'ARForms-Stripe'), __('Stripe Configuration', 'ARForms-Stripe'), 'arfstripeconfiguration', 'ARForms-Stripe', array(&$this, 'route'));
			
            add_submenu_page('ARForms', 'ARForms | ' . __('Stripe Transactions', 'ARForms-Stripe'), __('Stripe Transactions', 'ARForms-Stripe'), 'arfstripetransaction', 'ARForms-Stripe-order', array(&$this, 'route'));
		
		}		
		
	}
	
	function arf_set_js(){
		global $arf_stripe_version,$is_version_compatible;
		if(isset($_REQUEST['page']) && $_REQUEST['page'] != '' && ( $_REQUEST['page'] == "ARForms-Stripe" || $_REQUEST['page'] == "ARForms-Stripe-order" ) )
		{
			wp_register_script('arfstripe-js', ARF_STRIPE_URL . '/js/arf_stripe.js',array('jquery'),$arf_stripe_version);
			wp_enqueue_script( 'arfstripe-js');
			
			wp_register_script('arfbootstrap-js', ARFURL . '/bootstrap/js/bootstrap.min.js',array('jquery'),$arf_stripe_version);
			wp_enqueue_script( 'arfbootstrap-js');
			wp_enqueue_script('jquery-bootstrap-slect', ARFURL.'/bootstrap/js/bootstrap-select.js', array('jquery'),$arf_stripe_version);
			
			wp_enqueue_script( 'jquery', ARFURL . '/datatables/media/js/jquery.js',array(),$arf_stripe_version);
			wp_enqueue_script( 'jquery_dataTables', ARFURL . '/datatables/media/js/jquery.dataTables.js',array(),$arf_stripe_version);
			wp_enqueue_script( 'ColVis', ARFURL . '/datatables/media/js/ColVis.js',array(),$arf_stripe_version);
			wp_enqueue_script( 'FixedColumns', ARFURL . '/datatables/media/js/FixedColumns.js',array(),$arf_stripe_version);
			/*wp_enqueue_script( 'jqplot_min',ARFURL . '/js/linechart/jquery.jqplot.min.js',array(),$arf_stripe_version);
			wp_enqueue_script( 'barRenderer_min',ARFURL . '/js/linechart/jqplot.barRenderer.min.js',array(),$arf_stripe_version);
			wp_enqueue_script( 'logAxisRenderer_min',ARFURL . '/js/linechart/jqplot.logAxisRenderer.min.js',array(),$arf_stripe_version);	
			wp_enqueue_script( 'canvasTextRenderer_min',ARFURL . '/js/linechart/jqplot.canvasTextRenderer.min.js',array(),$arf_stripe_version);	
			wp_enqueue_script( 'canvasAxisLabelRenderer_min',ARFURL . '/js/linechart/jqplot.canvasAxisLabelRenderer.min.js',array(),$arf_stripe_version);	
			wp_enqueue_script( 'canvasAxisTickRenderer_min',ARFURL . '/js/linechart/jqplot.canvasAxisTickRenderer.min.js',array(),$arf_stripe_version);	
			wp_enqueue_script( 'dateAxisRenderer_min',ARFURL . '/js/linechart/jqplot.dateAxisRenderer.min.js',array(),$arf_stripe_version);	
			wp_enqueue_script( 'categoryAxisRenderer_min',ARFURL . '/js/linechart/jqplot.categoryAxisRenderer.min.js',array(),$arf_stripe_version);		
			wp_enqueue_script( 'highlighter_min',ARFURL . '/js/linechart/jqplot.highlighter.min.js',array(),$arf_stripe_version);*/
			?><?php
            wp_register_script('arf_tipso', ARFURL . '/js/tipso.min.js', array('jquery'),array(),$arf_stripe_version);
            wp_enqueue_script('arf_tipso');
            if($is_version_compatible)
            {
	            wp_register_script('bootstrap-locale-js', ARFURL . '/bootstrap/js/moment-with-locales.js', array(), $arf_stripe_version);
	            wp_enqueue_script('bootstrap-locale-js');
	            wp_register_script('bootstrap-datepicker', ARFURL . '/bootstrap/js/bootstrap-datetimepicker.js', array('jquery'), $arf_stripe_version, true);
	            wp_enqueue_script('bootstrap-datepicker');
            }
            else
            {
				wp_enqueue_script('jquery-ui-datepicker');
            }
		}
	}

	function arf_set_css(){
            global $arf_stripe_version,$is_version_compatible;
		if(isset($_REQUEST['page']) && $_REQUEST['page'] != '' && ( $_REQUEST['page'] == "ARForms-Stripe" || $_REQUEST['page'] == "ARForms-Stripe-order" ) )
		{
			wp_register_style('arfstripe-css', ARF_STRIPE_URL . '/css/arf_stripe.css',array(),$arf_stripe_version);
			wp_enqueue_style('arfstripe-css');
			
			wp_register_style('arfbootstrap-css', ARFURL.'/bootstrap/css/bootstrap.css',array(),$arf_stripe_version);
			wp_enqueue_style('arfbootstrap-css');
			wp_enqueue_style('arfbootstrap-select', ARFURL.'/bootstrap/css/bootstrap-select.css',array(),$arf_stripe_version);
			/*wp_enqueue_style('jqplot_min_css',ARFURL . '/js/linechart/jquery.jqplot.min.css',array(),$arf_stripe_version);*/
			
            wp_register_style('arf_tipso_css', ARFURL . '/css/tipso.min.css',array(),$arf_stripe_version);
            wp_enqueue_style('arf_tipso_css');
            if($is_version_compatible)
            {
	            wp_register_style('arfbootstrap-datepicker-css', ARFURL . '/bootstrap/css/bootstrap-datetimepicker.css', array(), $arf_stripe_version);
	            wp_enqueue_style('arfbootstrap-datepicker-css');
            }
		}
	}
		
	function list_orders(){
        global $arf_stripe, $arrecordcontroller,$is_version_compatible;
	if($is_version_compatible){
	    $file = 'list_orders_3.0.php';
	}else{
	    $file = 'list_orders.php';
	}
		require(ARF_STRIPE_DIR.'/core/'.$file);
	}

	function arf_stripe_order_new($message='', $errors = array(), $form_id = '', $datequery='', $startdate='', $enddate='' ){
        global $arf_stripe, $wpdb, $arrecordcontroller,$arformcontroller;
		global $wpdb;
		$actions['bulk_delete'] = __('Delete', 'ARForms-Stripe');
		$actions['bulk_csv'] = __('Export to CSV', 'ARForms-Stripe');

		global $style_settings, $wp_scripts;
		$wp_format_date = get_option('date_format');

		if ($wp_format_date == 'F j, Y' || $wp_format_date == 'm/d/Y') {
		    $date_format_new = 'MM/DD/YYYY';
		    $date_format_new1 = 'MM-DD-YYYY';
		    $start_date_new = '01/01/1970';
		    $end_date_new = '12/31/2050';
		} else if ($wp_format_date == 'd/m/Y') {
		    $date_format_new = 'DD/MM/YYYY';
		    $date_format_new1 = 'DD-MM-YYYY';
		    $start_date_new = '01/01/1970';
		    $end_date_new = '31/12/2050';
		} else if ($wp_format_date == 'Y/m/d') {
		    $date_format_new = 'DD/MM/YYYY';
		    $date_format_new1 = 'DD-MM-YYYY';
		    $start_date_new = '01/01/1970';
		    $end_date_new = '31/12/2050';
		} else {
		    $date_format_new = 'MM/DD/YYYY';
		    $date_format_new1 = 'MM-DD-YYYY';
		    $start_date_new = '01/01/1970';
		    $end_date_new = '12/31/2050';
		}
		/*if( $wp_format_date == 'F j, Y' || $wp_format_date =='m/d/Y' ) {
			$date_format_new = 'mm/dd/yy';
		} else if( $wp_format_date == 'd/m/Y' ) {
			$date_format_new = 'dd/mm/yy';
		} else if( $wp_format_date == 'Y/m/d' ) {
			$date_format_new = 'dd/mm/yy';
		} else {
			$date_format_new = 'mm/dd/yy';
		}*/
	?>
        <script data-cfasync="false" type="text/javascript" charset="utf-8">
	// <![CDATA[
		jQuery(document).ready( function () {
			jQuery('.arf_delete_entry').click(function(event) {
				var id = jQuery(this).attr('data-id');
				if (id == null || id == 'undefined') {
				return;
			    }
			    var delete_popup_html ='';
			    delete_popup_html +='<div class="delete_popup arfformentry_delete arfactive delete_form_message_'+id+'" id="delete_form_message">';
				delete_popup_html +='<input type="hidden" value="'+id+'" id="delete_entry_id"/>';
				delete_popup_html +='<div class="delete_column_arrow" style="position:absolute;"></div>';
				delete_popup_html +='<div class="delete_title"><div class="delete_confirm_message">Are you sure you want </br> to delete this transaction?</div>';
				delete_popup_html +='<div class="delete_popup_footer">';
			    delete_popup_html +='<button type="button" class="rounded_button add_button arf_delete_modal_left arfdelete_color_red" onclick="arfstripeactionfunc(\'delete\','+id+');">Delete</button>&nbsp;&nbsp;';
			    delete_popup_html +='<button type="button" class="rounded_button delete_button arfdelete_color_gray" onclick="arf_delete_close_popup('+id+');">Cancel</button>';
				delete_popup_html +='</div>';
				delete_popup_html +='</div>';
				delete_popup_html +='</div>';
				var select_content = jQuery(this).parent().parent('.arf-row-actions');
			    jQuery(delete_popup_html).insertAfter(select_content);
			    jQuery('.delete_form_message_'+id).show();
			});
			jQuery.fn.dataTableExt.oPagination.four_button = {

			"fnInit": function ( oSettings, nPaging, fnCallbackDraw )
			{
				nFirst = document.createElement( 'span' );
				nPrevious = document.createElement( 'span' );



				var nInput = document.createElement( 'input' );
				var nPage = document.createElement( 'span' );
				var nOf = document.createElement( 'span' );
				nOf.className = "paginate_of";
				nInput.className = "current_page_no";
				nPage.className = "paginate_page";
				nInput.type = "text";
				nInput.style.width = "40px";
				nInput.style.height = "26px";
				nInput.style.display = "inline";


				nPaging.appendChild( nPage );



				jQuery(nInput).keyup( function (e) {

					if ( e.which == 38 || e.which == 39 )
					{
						this.value++;
					}
					else if ( (e.which == 37 || e.which == 40) && this.value > 1 )
					{
						this.value--;
					}

					if ( this.value == "" || this.value.match(/[^0-9]/) )
					{

						return;
					}

					var iNewStart = oSettings._iDisplayLength * (this.value - 1);
					if ( iNewStart > oSettings.fnRecordsDisplay() )
					{

						oSettings._iDisplayStart = (Math.ceil((oSettings.fnRecordsDisplay()-1) /
							oSettings._iDisplayLength)-1) * oSettings._iDisplayLength;
						fnCallbackDraw( oSettings );
						return;
					}

					oSettings._iDisplayStart = iNewStart;
					fnCallbackDraw( oSettings );
				} );




				nNext = document.createElement( 'span' );
				nLast = document.createElement( 'span' );
				var nFirst = document.createElement( 'span' );
				var nPrevious = document.createElement( 'span' );
				var nPage = document.createElement( 'span' );
				var nOf = document.createElement( 'span' );

				nNext.style.backgroundRepeat = "no-repeat";
                                nNext.style.backgroundPosition = "center";
                                nNext.title = "Next";

                                nLast.style.backgroundRepeat = "no-repeat";
                                nLast.style.backgroundPosition = "center";
                                nLast.title = "Last";

                                nFirst.style.backgroundRepeat = "no-repeat";
                                nFirst.style.backgroundPosition = "center";
                                nFirst.title = "First";

                                nPrevious.style.backgroundRepeat = "no-repeat";
                                nPrevious.style.backgroundPosition = "center";
                                nPrevious.title = "Previous";

				nFirst.appendChild( document.createTextNode( ' ' ) );
				nPrevious.appendChild( document.createTextNode( ' ' ) );

				nLast.appendChild( document.createTextNode( ' ' ) );
				nNext.appendChild( document.createTextNode( ' ' ) );


				nOf.className = "paginate_button nof";

				nPaging.appendChild( nFirst );
				nPaging.appendChild( nPrevious );

				nPaging.appendChild( nInput );
				nPaging.appendChild( nOf );

				nPaging.appendChild( nNext );
				nPaging.appendChild( nLast );

				jQuery(nFirst).click( function () {
					oSettings.oApi._fnPageChange( oSettings, "first" );
					fnCallbackDraw( oSettings );
				} );

				jQuery(nPrevious).click( function() {
					oSettings.oApi._fnPageChange( oSettings, "previous" );
					fnCallbackDraw( oSettings );
				} );

				jQuery(nNext).click( function() {
					oSettings.oApi._fnPageChange( oSettings, "next" );
					fnCallbackDraw( oSettings );
				} );

				jQuery(nLast).click( function() {
					oSettings.oApi._fnPageChange( oSettings, "last" );
					fnCallbackDraw( oSettings );
				} );


				jQuery(nFirst).bind( 'selectstart', function () { return false; } );
				jQuery(nPrevious).bind( 'selectstart', function () { return false; } );
				jQuery('span', nPaging).bind( 'mousedown', function () { return false; } );
				jQuery('span', nPaging).bind( 'selectstart', function () { return false; } );
				jQuery(nNext).bind( 'selectstart', function () { return false; } );
				jQuery(nLast).bind( 'selectstart', function () { return false; } );
			},


			"fnUpdate": function ( oSettings, fnCallbackDraw )
			{
				if ( !oSettings.aanFeatures.p )
				{
					return;
				}


				var an = oSettings.aanFeatures.p;
				for ( var i=0, iLen=an.length ; i<iLen ; i++ )
				{
					var buttons = an[i].getElementsByTagName('span');


					if ( oSettings._iDisplayStart === 0 )
					{

						buttons[1].className = "paginate_disabled_first arfhelptip";
						buttons[2].className = "paginate_disabled_previous arfhelptip";
					}
					else
					{

						buttons[1].className = "paginate_enabled_first arfhelptip";
						buttons[2].className = "paginate_enabled_previous arfhelptip";
					}

					if ( oSettings.fnDisplayEnd() == oSettings.fnRecordsDisplay() )
					{
						buttons[4].className = "paginate_disabled_next arfhelptip";
						buttons[5].className = "paginate_disabled_last arfhelptip";
					}
					else
					{

						buttons[4].className = "paginate_enabled_next arfhelptip";
						buttons[5].className = "paginate_enabled_last arfhelptip";
					}



					if ( !oSettings.aanFeatures.p )
					{
						return;
					}
					var iPages = Math.ceil((oSettings.fnRecordsDisplay()) / oSettings._iDisplayLength);
					var iCurrentPage = Math.ceil(oSettings._iDisplayStart / oSettings._iDisplayLength) + 1;

					if(document.getElementById('of_grid'))
						of_grid = document.getElementById('of_grid').value;
					else
						of_grid = 'of';

					var an = oSettings.aanFeatures.p;
					for ( var i=0, iLen=an.length ; i<iLen ; i++ )
					{
						var spans = an[i].getElementsByTagName('span');
						var inputs = an[i].getElementsByTagName('input');
						spans[spans.length-3].innerHTML =" "+of_grid+" "+iPages
						inputs[0].value = iCurrentPage;
					}
				}
			}
		}

		jQuery('#example').dataTable( {
			"sDom": '<"H"lfr>t<"footer"ip>',
			"sPaginationType": "four_button",
			"bJQueryUI": true,
			"bPaginate": true,
			"bAutoWidth" : false,
			"aoColumnDefs": [
				{ "bVisible": false, "aTargets": [] },
				{ "bSortable": false, "aTargets": [ 0, 6 ] }
			],
			"oColVis": {
			   "aiExclude": [ 0, 6 ]
			},

			});
	});

	// ]]>

	jQuery(document).ready( function () {
	
		jQuery("#datepicker_from").datetimepicker({
	            useCurrent: false,
	            format: '<?php echo $date_format_new; ?>',
	            locale: '<?php echo (isset($options['locale'])) ? $options['locale'] : ''; ?>',
	            minDate: moment('<?php echo $start_date_new; ?>', '<?php echo $date_format_new1; ?>'),
	            maxDate: moment('<?php echo $end_date_new; ?>', '<?php echo $date_format_new1; ?>')
	        });

	        jQuery("#datepicker_to").datetimepicker({
	            useCurrent: false,
	            format: '<?php echo $date_format_new; ?>',
	            locale: '<?php echo (isset($options['locale'])) ? $options['locale'] : ''; ?>',
	            minDate: moment('<?php echo $start_date_new; ?>', '<?php echo $date_format_new1; ?>'),
	            maxDate: moment('<?php echo $end_date_new; ?>', '<?php echo $date_format_new1; ?>')
	        });



		jQuery("#cb-select-all-1").click(function () {
			  jQuery('input[name="item-action[]"]').attr('checked', this.checked);
		});


		jQuery('input[name="item-action[]"]').click(function(){

			if(jQuery('input[name="item-action[]"]').length == jQuery('input[name="item-action[]"]:checked').length) {
				jQuery("#cb-select-all-1").attr("checked", "checked");
			} else {
				jQuery("#cb-select-all-1").removeAttr("checked");
			}

		});

	});

	</script>
  <div class="arf_form_entry_select">
		    <table class="arf_form_entry_select_sub" style="padding-top:0px;">
		    <tr>
			<th class="arf_form_entry_left" style="float:none;text-align:left;"><?php _e('Select form','ARForms-Stripe');?>:</th>
			<th class="arf_form_entry_left"><?php _e('Select Date', 'ARForms-Stripe'); ?> (<?php _e('optional', 'ARForms-Stripe'); ?>)</th>
		    </tr>
		    <tr>
			<td><div class="sltstandard" style="float:none; width: 290px !important;margin-right:60px;">
			    <?php
				$get_form_id = (isset($_GET['form'])) ? $_GET['form'] : $form_id;
				$arf_stripe->stripe_form_dropdown('arf_stripe_forms_dropdown', $form_id, __('All Forms', 'ARForms-Stripe')); ?>
			    </div></td>
			<td>
			    <?php
			    if (is_rtl()) {
				$sel_frm_date_wrap = 'float:right;text-align:right;';
				$sel_frm_sel_date = 'float:right;';
				$sel_frm_button = 'float:right;';
			    } else {
				$sel_frm_date_wrap = 'float:left;text-align:left;';
				$sel_frm_sel_date = 'float:left;';
				$sel_frm_button = 'float:left;';
			    }
			    ?>
			    <div style="position:relative; <?php echo $sel_frm_date_wrap; ?>">
				<div style="<?php echo $sel_frm_sel_date; ?>"><div class="arfentrytitle" style='margin-left:0;'><?php _e('From', 'ARForms-Stripe'); ?></div><input type="text" class="txtmodal1" id="datepicker_from" value="" name="datepicker_from" style="width:120px;height:35px;vertical-align:middle; " /></div> <div class="arfentrytitle"><?php _e('To', 'ARForms-Stripe'); ?></div>&nbsp;&nbsp;<div style="<?php echo $sel_frm_sel_date; ?>"><input type="text" class="txtmodal1" id="datepicker_to" name="datepicker_to"  value="" style="width:120px;height:35px;vertical-align:middle; "/></div>
				<div style=" <?php echo $sel_frm_button; ?>">
				    <div class="arf_form_entry_left">&nbsp;</div>
				    <div style="float:left;text-align:left;"><button type="button" class="rounded_button arf_btn_dark_blue" onclick="change_form_orders();" style="width: 35px !important;height: 35px;"><?php _e('Go', 'ARForms-Stripe'); ?></button></div>
				</div>
				<input type="hidden" name="please_select_form" id="please_select_form" value="<?php _e('Please select a form', 'ARForms-Stripe'); ?>" />
			    </div>
			</td>
		    </tr>
		</table>
	    </div>
    <div style="clear:both; margin-bottom:10px"></div>

    <?php
		if (isset($message) && $message != ''){ 
                    if(is_admin()){ ?>
                        <script type="text/javascript" language="javascript"> setTimeout( function(){ success_msg(); },10); </script>
                        <div id="success_message" class="arf_success_message">
                            <div class="message_descripiton">
                                <div style="float: left; margin-right: 15px;"><?php  echo $message; ?></div>
                                <div class="message_svg_icon">
                                    <svg style="height: 14px;stroke-width: 14px;">
                                        <path fill-rule="evenodd" clip-rule="evenodd" fill="#FFFFFF" d="M6.075,14.407l-5.852-5.84l1.616-1.613l4.394,4.385L17.181,0.411
                                                                                        l1.616,1.613L6.392,14.407H6.075z"></path></svg>
                                </div>
                            </div>
                        </div>
                    <?php } }

		if( isset($errors) && is_array($errors) && count($errors) > 0 ){ ?>
		<?php
                foreach ($errors as $error) {
                    ?><script type="text/javascript" language="javascript"> setTimeout( function(){ error_msg(); },10); </script>
                    <div id="error_message" class="arf_error_message">
                    <div class="message_descripiton">
                            <div style="float: left; margin-right: 15px;"><?php echo stripslashes($error); ?></div>
                            <div class="message_svg_icon">
                                    <svg style="height: 14px;stroke-width: 14px;"><path fill-rule="evenodd" clip-rule="evenodd" fill="#ffffff" d="M10.702,10.909L6.453,6.66l-4.249,4.249L1.143,9.848l4.249-4.249L1.154,1.361l1.062-1.061l4.237,4.237l4.238-4.237l1.061,1.061L7.513,5.599l4.249,4.249L10.702,10.909z"></path></svg>
                            </div>
                    </div>
                    </div>
                <?php } ?>
	<?php } ?>
		    <?php $two = '1';?>
		    <div class="alignleft actions">
			<div class="arf_list_bulk_action_wrapper">
			    <input id="arf_bulk_action_one" name="action<?php echo $two; ?>" value="-1" type="hidden">
			    <dl class="arf_selectbox" data-name="action<?php echo $two; ?>" data-id="arf_bulk_action_one">
				<dt style="width:121px;"><span><?php echo __('Bulk Actions', 'ARForms-Stripe'); ?></span>
				    <input value="<?php echo __('Bulk Actions','ARForms-Stripe');?>" style="display:none;" class="" type="text">
				    <svg viewBox="0 0 2000 1000" width="15px" height="15px">
				    <g fill="#000">
					<path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"/>
				    </g>
				    </svg>
				</dt>
				<dd>
				    <ul style="display: none;width: 121px;" data-id="arf_bulk_action_one">
					<li data-value='-1' data-label='<?php _e('Bulk Actions', 'ARForms-Stripe'); ?>'><?php _e('Bulk Actions', 'ARForms-Stripe'); ?></li>
					<?php
					foreach ($actions as $name => $title) {
					$class = 'edit' == $name ? ' class="hide-if-no-js" ' : '';?>
					    <li <?php echo $class; ?> data-value='<?php echo $name; ?>' data-label='<?Php echo $title; ?>'><?php echo $title; ?></li>
					<?php }?>
				    </ul>
				</dd>
			    </dl>
			</div>
			<?php
			    echo '<input type="submit" id="doaction'.$two.'" class="arf_bulk_action_btn rounded_button btn_green" value="'.__('Apply','ARForms-Stripe').'" />';
			    echo "\n";
			?>
		    </div>
		   <table cellpadding="0" cellspacing="0" border="0" class="display table_grid" id="example">
		    <thead>
			  <tr>
				<th class="center" style="width:50px;"><div class="arf_custom_checkbox_div">
				    <div class="arf_custom_checkbox_wrapper" style="margin-left:15px;">
				    <input id="cb-select-all-1" type="checkbox" class="">
				    <svg width="18px" height="18px">
					<path id="arfcheckbox_unchecked" d="M15.205,16.852H3.774c-1.262,0-2.285-1.023-2.285-2.286V3.136  c0-1.263,1.023-2.286,2.285-2.286h11.431c1.263,0,2.286,1.023,2.286,2.286v11.43C17.491,15.829,16.467,16.852,15.205,16.852z   M15.49,2.851h-12v12h12V2.851z"></path><path id="arfcheckbox_checked" d="M15.205,16.852H3.774c-1.262,0-2.285-1.023-2.285-2.286V3.136  c0-1.263,1.023-2.286,2.285-2.286h11.431c1.263,0,2.286,1.023,2.286,2.286v11.43C17.491,15.829,16.467,16.852,15.205,16.852z   M15.49,2.851h-12v12h12V2.851z M5.93,6.997l2.557,2.558l4.843-4.843l1.617,1.616l-4.844,4.843l0.007,0.007l-1.616,1.616  l-0.007-0.007l-0.006,0.007l-1.617-1.616l0.007-0.007L4.314,8.614L5.93,6.997z"></path></svg>
					</div>
				    </div>
				</th>
				<th class=""><?php _e('Transaction ID / Subscription ID', 'ARForms-Stripe'); ?></th>
				<th class=""><?php _e('Payment Status', 'ARForms-Stripe'); ?></th>
				<th class=""><?php _e('Total Amount', 'ARForms-Stripe'); ?></th>
				<th class=""><?php _e('Payment Type', 'ARForms-Stripe'); ?></th>
				<th class=""><?php _e('Payment Date', 'ARForms-Stripe'); ?></th>
				<th class="arf_col_action arf_action_cell"><?php _e('Action', 'ARForms-Stripe'); ?></th>
			  </tr>
		    </thead>
			  </tbody>
		   <?php
		   if(isset($form_id) and $form_id != '')
		   {
			if($datequery!="")
			{
			    $orders = $wpdb->get_results( $wpdb->prepare("SELECT * FROM ". $arf_stripe->db_stripe_order ." WHERE form_id = %d ".$datequery." ORDER BY id DESC", $form_id) );
			}else {
			    $orders = $wpdb->get_results( $wpdb->prepare("SELECT * FROM ".$arf_stripe->db_stripe_order." WHERE form_id = %d ORDER BY id DESC", $form_id) );
			}
	   }
	   else {
			if($datequery!="")
			{
			    $orders = $wpdb->get_results( "SELECT * FROM ".$arf_stripe->db_stripe_order." WHERE id!='' ".$datequery." ORDER BY id DESC" );
			}else {
			    $orders = $wpdb->get_results( "SELECT * FROM ".$arf_stripe->db_stripe_order." ORDER BY id DESC" );
			}
		   }

		   if( count($orders) > 0 ){
		   foreach( $orders as $order ){ ?>
		    <tr style="height: 50px;">
			<td class="center">
			    <div class="arf_custom_checkbox_div">
			    <div class="arf_custom_checkbox_wrapper" style="margin-left:15px;">
			    <input id="cb-item-action-<?php echo $order->id;?>" type="checkbox" value="<?php echo $order->id;?>" name="item-action[]">
			    <svg width="18px" height="18px">
				<path id="arfcheckbox_unchecked" d="M15.205,16.852H3.774c-1.262,0-2.285-1.023-2.285-2.286V3.136  c0-1.263,1.023-2.286,2.285-2.286h11.431c1.263,0,2.286,1.023,2.286,2.286v11.43C17.491,15.829,16.467,16.852,15.205,16.852z   M15.49,2.851h-12v12h12V2.851z"></path><path id="arfcheckbox_checked" d="M15.205,16.852H3.774c-1.262,0-2.285-1.023-2.285-2.286V3.136  c0-1.263,1.023-2.286,2.285-2.286h11.431c1.263,0,2.286,1.023,2.286,2.286v11.43C17.491,15.829,16.467,16.852,15.205,16.852z   M15.49,2.851h-12v12h12V2.851z M5.93,6.997l2.557,2.558l4.843-4.843l1.617,1.616l-4.844,4.843l0.007,0.007l-1.616,1.616  l-0.007-0.007l-0.006,0.007l-1.617-1.616l0.007-0.007L4.314,8.614L5.93,6.997z"></path></svg>
				</div>
			    </div>
			    <label for="cb-item-action-<?php echo $order->id;?>"><span></span></label></div></td>
		       <td><?php echo $order->txn_id; ?></td>
		       <td><?php echo ($order->payment_status == 'Completed') ? '<font style="color:#008000">'.$order->payment_status.'</font>' : '<font style="color:#FFA500">'.$order->payment_status.'</font>'; ?></td>
		       <td><?php echo $arformcontroller->arfdeciamlseparator($order->mc_gross).' '.$order->mc_currency; ?></td>
   <td class=""><?php if( isset($order->payment_type) and $order->payment_type == 1 ) { _e('Subscription', 'ARForms-Stripe'); }else { _e('Product / Service', 'ARForms-Stripe'); }?></td>
		       <td><?php echo date(get_option('date_format'), strtotime($order->created_at)); ?></td>
		       <td class="arf_action_cell">
       			<div class="arf-row-actions" style="padding-top: 0px !important;">
		       <?php
		       echo "<div class='arfformicondiv arfhelptip' title='" .__("View Entry","ARForms-Stripe"). "'><a href='javascript:void(0);' onclick='open_entry_thickbox({$order->entry_id});'><svg width='30px' height='30px' viewBox='-3 -8 32 32' class='arfsvgposition'><path fill-rule='evenodd' clip-rule='evenodd' fill='#ffffff' d='M12.993,15.23c-7.191,0-11.504-7.234-11.504-7.234  S5.801,0.85,12.993,0.85c7.189,0,11.504,7.19,11.504,7.19S20.182,15.23,12.993,15.23z M12.993,2.827  c-5.703,0-8.799,5.214-8.799,5.214s3.096,5.213,8.799,5.213c5.701,0,8.797-5.213,8.797-5.213S18.694,2.827,12.993,2.827z   M12.993,11.572c-1.951,0-3.531-1.581-3.531-3.531s1.58-3.531,3.531-3.531c1.949,0,3.531,1.581,3.531,3.531  S14.942,11.572,12.993,11.572z'/></svg></a></div>";
		       echo "<div class='arfformicondiv arfhelptip arfdeleteentry_div_".$order->id."' title='" .__("Delete","ARForms-Stripe"). "'><a class='arf_delete_entry' data-id='".$order->id."' style='cursor:pointer'><svg width='30px' height='30px' viewBox='-5 -5 32 32' class='arfsvgposition'><path fill-rule='evenodd' clip-rule='evenodd' fill='#ffffff' d='M18.435,4.857L18.413,19.87L3.398,19.88L3.394,4.857H1.489V2.929  h1.601h3.394V0.85h8.921v2.079h3.336h1.601l0,0v1.928H18.435z M15.231,4.857H6.597H5.425l0.012,13.018h10.945l0.005-13.018H15.231z   M11.4,6.845h2.029v9.065H11.4V6.845z M8.399,6.845h2.03v9.065h-2.03V6.845z' /></svg></a></div>";
		       	echo "<div id='view_entry_detail_container_{$order->entry_id}' style='display:none;'>" . $arrecordcontroller->get_entries_list($order->entry_id) . "</div><div style='clear:both;' class='arfmnarginbtm10'></div>";
			?>
			</div>
			</td>
		    </tr>
		   <?php } } ?>
				</tbody>
		   </table>
				<div class="clear"></div>
				<input type="hidden" name="show_hide_columns" id="show_hide_columns" value="<?php _e('Show / Hide columns','ARForms-Stripe');?>"/>
				<input type="hidden" name="search_grid" id="search_grid" value="<?php _e('Search','ARForms-Stripe');?>"/>
				<input type="hidden" name="entries_grid" id="entries_grid" value="<?php _e('entries','ARForms-Stripe');?>"/>
				<input type="hidden" name="show_grid" id="show_grid" value="<?php _e('Show','ARForms-Stripe');?>"/>
				<input type="hidden" name="showing_grid" id="showing_grid" value="<?php _e('Showing','ARForms-Stripe');?>"/>
				<input type="hidden" name="to_grid" id="to_grid" value="<?php _e('to','ARForms-Stripe');?>"/>
				<input type="hidden" name="of_grid" id="of_grid" value="<?php _e('of','ARForms-Stripe');?>"/>
				<input type="hidden" name="no_match_record_grid" id="no_match_record_grid" value="<?php _e('No matching records found','ARForms-Stripe');?>"/>
				<input type="hidden" name="no_record_grid" id="no_record_grid" value="<?php _e('No data available in table','ARForms-Stripe');?>"/>
				<input type="hidden" name="filter_grid" id="filter_grid" value="<?php _e('filtered from','ARForms-Stripe');?>"/>
				<input type="hidden" name="totalwd_grid" id="totalwd_grid" value="<?php _e('total','ARForms-Stripe');?>"/>

		    <?php $two = '2';?>
		    <div class="alignleft actions2">
			<div class="arf_list_bulk_action_wrapper">
			    <input id="arf_bulk_action_two" name="action<?php echo $two; ?>" value="-1" type="hidden">
			    <dl class="arf_selectbox" data-name="action<?php echo $two; ?>" data-id="arf_bulk_action_two">
				<dt style="width:121px;"><span><?php echo __('Bulk Actions', 'ARForms-Stripe'); ?></span>
				    <input value="<?php echo __('Bulk Actions', 'ARForms-Stripe'); ?>" style="display:none;" class="" type="text">
				    <svg viewBox="0 0 2000 1000" width="15px" height="15px">
				    <g fill="#000">
					<path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"/>
				    </g>
				    </svg>
				</dt>
				<dd>
				<ul style="display: none;width: 121px;" data-id="arf_bulk_action_two">
				    <li data-value='-1' data-label='<?php _e('Bulk Actions', 'ARForms-Stripe');?>'><?php _e('Bulk Actions','ARForms-Stripe');?></li>
				    <?php
				    foreach ($actions as $name => $title) {
				    $class = 'edit' == $name ? ' class="hide-if-no-js" ' : '';?>
					<li <?php echo $class;?> data-value='<?php echo $name;?>' data-label='<?Php echo $title;?>'><?php echo $title;?></li>
				    <?php }?>
				</ul>
				</dd>
			    </dl>
			</div>
			<?php
			   echo '<input type="submit" id="doaction'.$two.'" class="arf_bulk_action_btn rounded_button btn_green" value="'.__('Apply','ARForms-Stripe').'"/>';
			   echo "\n";
			?>
		    </div>
		    <div class="footer_grid"></div>

		<?php
	}

	
	function arf_stripe_order($message='', $errors = array(), $form_id = '', $datequery='', $startdate='', $enddate='' ){
        global $arf_stripe, $wpdb, $arrecordcontroller;
		global $wpdb;
		$actions['bulk_delete'] = __('Delete', 'ARForms-Stripe');
		$actions['bulk_csv'] = __('Export to CSV', 'ARForms-Stripe');
		
		global $style_settings, $wp_scripts;
		$wp_format_date = get_option('date_format');

		if( $wp_format_date == 'F j, Y' || $wp_format_date =='m/d/Y' ) {
			$date_format_new = 'mm/dd/yy';
		} else if( $wp_format_date == 'd/m/Y' ) {
			$date_format_new = 'dd/mm/yy';
		} else if( $wp_format_date == 'Y/m/d' ) {
			$date_format_new = 'dd/mm/yy';
		} else {
			$date_format_new = 'mm/dd/yy';
		}
	?>
        <script data-cfasync="false" type="text/javascript" charset="utf-8">
	// <![CDATA[
		jQuery(document).ready( function () {
			jQuery.fn.dataTableExt.oPagination.four_button = {
			
			"fnInit": function ( oSettings, nPaging, fnCallbackDraw )
			{	
				nFirst = document.createElement( 'span' );
				nPrevious = document.createElement( 'span' );
				
				
				
				var nInput = document.createElement( 'input' );
				var nPage = document.createElement( 'span' );
				var nOf = document.createElement( 'span' );
				nOf.className = "paginate_of";
				nInput.className = "current_page_no";
				nPage.className = "paginate_page";
				nInput.type = "text";
				nInput.style.width = "40px";
				nInput.style.height = "26px";
				nInput.style.display = "inline";
				
				 
				nPaging.appendChild( nPage );
				
				
				 
				jQuery(nInput).keyup( function (e) {
							 
					if ( e.which == 38 || e.which == 39 )
					{
						this.value++;
					}
					else if ( (e.which == 37 || e.which == 40) && this.value > 1 )
					{
						this.value--;
					}
		 
					if ( this.value == "" || this.value.match(/[^0-9]/) )
					{
						
						return;
					}
		 
					var iNewStart = oSettings._iDisplayLength * (this.value - 1);
					if ( iNewStart > oSettings.fnRecordsDisplay() )
					{
						
						oSettings._iDisplayStart = (Math.ceil((oSettings.fnRecordsDisplay()-1) /
							oSettings._iDisplayLength)-1) * oSettings._iDisplayLength;
						fnCallbackDraw( oSettings );
						return;
					}
		 
					oSettings._iDisplayStart = iNewStart;
					fnCallbackDraw( oSettings );
				} );
		 
				
				
				
				nNext = document.createElement( 'span' );
				nLast = document.createElement( 'span' );
				var nFirst = document.createElement( 'span' );
				var nPrevious = document.createElement( 'span' );
				var nPage = document.createElement( 'span' );
				var nOf = document.createElement( 'span' );
				
				nNext.style.backgroundImage = "url('<?php echo ARFURL; ?>/images/next_normal-icon.png')";
				nNext.style.backgroundRepeat = "no-repeat";
				nNext.style.backgroundPosition = "center";
				nNext.title = "Next";
				
				nLast.style.backgroundImage = "url('<?php echo ARFURL; ?>/images/last_normal-icon.png')";
				nLast.style.backgroundRepeat = "no-repeat";
				nLast.style.backgroundPosition = "center";
				nLast.title = "Last";
				
				nFirst.style.backgroundImage = "url('<?php echo ARFURL; ?>/images/first_normal-icon.png')";
				nFirst.style.backgroundRepeat = "no-repeat";
				nFirst.style.backgroundPosition = "center";
				nFirst.title = "First";
				
				nPrevious.style.backgroundImage = "url('<?php echo ARFURL; ?>/images/previous_normal-icon.png')";
				nPrevious.style.backgroundRepeat = "no-repeat";
				nPrevious.style.backgroundPosition = "center";		
				nPrevious.title = "Previous";		
				
				nFirst.appendChild( document.createTextNode( ' ' ) );
				nPrevious.appendChild( document.createTextNode( ' ' ) );
				
				nLast.appendChild( document.createTextNode( ' ' ) );
				nNext.appendChild( document.createTextNode( ' ' ) );
				
				 
				nOf.className = "paginate_button nof";
				 
				nPaging.appendChild( nFirst );
				nPaging.appendChild( nPrevious );
				
				nPaging.appendChild( nInput );
				nPaging.appendChild( nOf );
				
				nPaging.appendChild( nNext );
				nPaging.appendChild( nLast );
				 
				jQuery(nFirst).click( function () {
					oSettings.oApi._fnPageChange( oSettings, "first" );
					fnCallbackDraw( oSettings );
				} );
				 
				jQuery(nPrevious).click( function() {
					oSettings.oApi._fnPageChange( oSettings, "previous" );
					fnCallbackDraw( oSettings );
				} );
				 
				jQuery(nNext).click( function() {
					oSettings.oApi._fnPageChange( oSettings, "next" );
					fnCallbackDraw( oSettings );
				} );
				 
				jQuery(nLast).click( function() {
					oSettings.oApi._fnPageChange( oSettings, "last" );
					fnCallbackDraw( oSettings );
				} );
				 
				
				jQuery(nFirst).bind( 'selectstart', function () { return false; } );
				jQuery(nPrevious).bind( 'selectstart', function () { return false; } );
				jQuery('span', nPaging).bind( 'mousedown', function () { return false; } );
				jQuery('span', nPaging).bind( 'selectstart', function () { return false; } );
				jQuery(nNext).bind( 'selectstart', function () { return false; } );
				jQuery(nLast).bind( 'selectstart', function () { return false; } );
			},
			 
			
			"fnUpdate": function ( oSettings, fnCallbackDraw )
			{
				if ( !oSettings.aanFeatures.p )
				{
					return;
				}
				 
				
				var an = oSettings.aanFeatures.p;
				for ( var i=0, iLen=an.length ; i<iLen ; i++ )
				{
					var buttons = an[i].getElementsByTagName('span');
					
					
					if ( oSettings._iDisplayStart === 0 )
					{
						
						buttons[1].className = "paginate_disabled_first arfhelptip";
						buttons[2].className = "paginate_disabled_previous arfhelptip";
					}
					else
					{
						
						buttons[1].className = "paginate_enabled_first arfhelptip";
						buttons[2].className = "paginate_enabled_previous arfhelptip";
					}
		
					if ( oSettings.fnDisplayEnd() == oSettings.fnRecordsDisplay() )
					{
						buttons[4].className = "paginate_disabled_next arfhelptip";
						buttons[5].className = "paginate_disabled_last arfhelptip";
					}
					else
					{
						
						buttons[4].className = "paginate_enabled_next arfhelptip";
						buttons[5].className = "paginate_enabled_last arfhelptip";
					}
	
	
					
					if ( !oSettings.aanFeatures.p )
					{
						return;
					}
					var iPages = Math.ceil((oSettings.fnRecordsDisplay()) / oSettings._iDisplayLength);
					var iCurrentPage = Math.ceil(oSettings._iDisplayStart / oSettings._iDisplayLength) + 1;
					
					if(document.getElementById('of_grid'))
						of_grid = document.getElementById('of_grid').value;
					else
						of_grid = 'of';
					
					var an = oSettings.aanFeatures.p;
					for ( var i=0, iLen=an.length ; i<iLen ; i++ )
					{
						var spans = an[i].getElementsByTagName('span');
						var inputs = an[i].getElementsByTagName('input');
						spans[spans.length-3].innerHTML =" "+of_grid+" "+iPages
						inputs[0].value = iCurrentPage;
					}
				}
			}
		}
			
		jQuery('#example').dataTable( {
			"sDom": '<"H"lfr>t<"footer"ip>',	
			"sPaginationType": "four_button",
			"bJQueryUI": true,
			"bPaginate": true,
			"bAutoWidth" : false,					
			"aoColumnDefs": [
				{ "bVisible": false, "aTargets": [] },
				{ "bSortable": false, "aTargets": [ 0, 6 ] }
			],
			"oColVis": {
			   "aiExclude": [ 0, 6 ]
			},
			
			});
	});
					
	// ]]>
	
	jQuery(document).ready( function () { 	
		jQuery.datepicker.setDefaults(jQuery.datepicker.regional['']);

		jQuery("#datepicker_from").datepicker(jQuery.extend(jQuery.datepicker.regional['<?php echo (isset($options['locale'])) ? $options['locale'] : ''; ?>'], {dateFormat:'<?php echo $date_format_new; ?>',changeMonth:false,changeYear:false,yearRange:'<?php echo '1970' .':'. '2050' ?>'}));
	
		jQuery("#datepicker_to").datepicker(jQuery.extend(jQuery.datepicker.regional['<?php echo (isset($options['locale'])) ? $options['locale'] : ''; ?>'], {dateFormat:'<?php echo $date_format_new; ?>',changeMonth:false,changeYear:false,yearRange:'<?php echo '1970' .':'. '2050' ?>'}));	
		
			
		
		jQuery("#cb-select-all-1").click(function () {
			  jQuery('input[name="item-action[]"]').attr('checked', this.checked);
		});
	 
	   
		jQuery('input[name="item-action[]"]').click(function(){
	 
			if(jQuery('input[name="item-action[]"]').length == jQuery('input[name="item-action[]"]:checked').length) {
				jQuery("#cb-select-all-1").attr("checked", "checked");
			} else {
				jQuery("#cb-select-all-1").removeAttr("checked");
			}
	 
		});
		
	});
								
	</script>
    <div class="arf_form_entry_select">
		<div class="arf_form_entry_select_sub" style="width:100%;float:left;padding:20px 0;">
            <div class="arf_form_entry_left" style="width:34.5%;float:left;text-align:right;line-height:30px;height:30px;margin-right:0.5%;"><div><?php _e('Select form','ARForms-Stripe');?>:</div></div>
            <div style="width:65%;float:left;text-align:left" ><div class="sltstandard" style="float:none;"><?php 
            $arf_stripe->stripe_form_dropdown('arf_stripe_forms_dropdown', $form_id, __('All Forms', 'ARForms-Stripe')); ?></div></div>
            
            <div class="arf_form_entry_left" style="width:34.5%;float:left;text-align:right;line-height:30px;height:30px;margin-right:0.5%;margin-top:15px;"><div><?php _e('Select date From','ARForms-Stripe');?>:</div><div class="arf_form_entry_left_sub">(<?php _e('optional','ARForms-Stripe');?>)</div></div>
            <div style="float:left;text-align:left;width:65%;margin-top:15px;">
                <div style="float:left;"><input type="text" class="txtstandardnew" id="datepicker_from" value="" name="datepicker_from" style="vertical-align:middle; width:105px;" /></div> <div class="arfentrytitle"><?php _e('To','ARForms-Stripe');?>:</div>&nbsp;&nbsp;<div style="float:left;"><input type="text" class="txtstandardnew" id="datepicker_to" name="datepicker_to"  value="" style="vertical-align:middle;  width:105px;"/></div>
                
                <div style="width:100%;float:left;text-align:left; margin-top:15px;" ><button class="greensavebtn" style="width:110px; border:0px; color:#FFFFFF; height:40px; border-radius:3px;" onclick="change_form_orders();" type="button"><?php _e('Submit', 'ARForms-Stripe');?></button></div>
            </div>
                
        </div>
    </div>
    <div style="clear:both; margin-bottom:10px"></div>
    
    <?php
		if (isset($message) && $message != ''){ if(is_admin()){ ?><div id="success_message" style="margin-bottom:0px; margin-top:15px; width:95%;"><div class="arfsuccessmsgicon"></div><div class="arf_success_message"><?php } echo $message; if(is_admin()){ ?></div></div><?php } }
		
		if( isset($errors) && is_array($errors) && count($errors) > 0 ){ ?>	
		<div style="margin-bottom:0px; margin-top:8px;">	
			<ul id="frm_errors" style="margin-bottom: 0px; margin-top: 0px;">	
				<?php foreach( $errors as $error )
					echo '<li><div class="arferrmsgicon"></div><div id="error_message">' . stripslashes($error) . '</div></li>';
				?>	
			</ul>	
		</div>
	<?php } ?>
			<div class="alignleft actions">
				<?php 
				$two = '1';
				echo "<div class='sltstandard'><select style='width:120px;' data-width='120px' name='action$two'>\n";
				echo "<option value='-1' selected='selected'>" . __('Bulk Actions','ARForms-Stripe') . "</option>\n";
		
				foreach ( $actions as $name => $title ) {
					$class = 'edit' == $name ? ' class="hide-if-no-js"' : '';
		
					echo "\t<option value='$name'$class>$title</option>\n";
				}
		
				echo "</select></div>\n";
				
				echo '<input type="submit" id="doaction'.$two.'" class="arfbulkbtn arfemailaddbtn" value="'.__('Apply','ARForms-Stripe').'" />';
				echo "\n";
				
				?>
			</div>
		   <table cellpadding="0" cellspacing="0" border="0" class="display" id="example">
			  <thead>
				<tr>
					<th class="center" style="width:50px;"><div style="display:inline-block; position:relative;"><input id="cb-select-all-1" type="checkbox" class="chkstanard"><label for="cb-select-all-1"  class="cb-select-all"><span></span></label></div></th>
					<th class=""><?php _e('Transaction ID / Subscription ID', 'ARForms-Stripe'); ?></th>                
					<th class=""><?php _e('Payment Status', 'ARForms-Stripe'); ?></th>
					<th class=""><?php _e('Total Amount', 'ARForms-Stripe'); ?></th>
                    <th class=""><?php _e('Payment Type', 'ARForms-Stripe'); ?></th>
					<th class=""><?php _e('Payment Date', 'ARForms-Stripe'); ?></th>
					<th class="col_action" style="width:110px;"><?php _e('Action', 'ARForms-Stripe'); ?></th>
				</tr> 
			  </thead>
			  </tbody>        
		   <?php
		   if(isset($form_id) and $form_id != '')
		   {
		   		if($datequery!="")
				{
		   			$orders = $wpdb->get_results( $wpdb->prepare("SELECT * FROM ".$wpdb->prefix."arf_stripe_order WHERE form_id = %d ".$datequery." ORDER BY id DESC", $form_id) );	
				}else {
					$orders = $wpdb->get_results( $wpdb->prepare("SELECT * FROM ".$wpdb->prefix."arf_stripe_order WHERE form_id = %d ORDER BY id DESC", $form_id) );	
				}
		   }
		   else {
		   		if($datequery!="")
				{
					$orders = $wpdb->get_results( "SELECT * FROM ".$wpdb->prefix."arf_stripe_order WHERE id!='' ".$datequery." ORDER BY id DESC" );
				}else {
		   			$orders = $wpdb->get_results( "SELECT * FROM ".$wpdb->prefix."arf_stripe_order ORDER BY id DESC" );	    
				}
		   }
		   
		   if( count($orders) > 0 ){
		   foreach( $orders as $order ){ ?>     
				<tr>
					  <td class="center"><input id="cb-item-action-<?php echo $order->id;?>" class="chkstanard" type="checkbox" value="<?php echo $order->id;?>" name="item-action[]"><label for="cb-item-action-<?php echo $order->id;?>"><span></span></label></td>
					<td><?php echo $order->txn_id; ?></td>                
					<td><?php echo ($order->payment_status == 'Completed') ? '<font style="color:#008000">'.$order->payment_status.'</font>' : '<font style="color:#FFA500">'.$order->payment_status.'</font>'; ?></td>
					<td><?php echo $order->mc_gross.' '.$order->mc_currency; ?></td>
                    <td class=""><?php if( isset($order->payment_type) and $order->payment_type == 1 ) { _e('Subscription', 'ARForms-Stripe'); }else { _e('Product / Service', 'ARForms-Stripe'); }?></td>
					<td><?php echo date(get_option('date_format'), strtotime($order->created_at)); ?></td>                
					<td><?php echo "<a href='javascript:void(0);' onclick='open_entry_thickbox({$order->entry_id});'><img src='".ARFIMAGESURL."/view_icon23.png' title='".__("View Entry","ARForms-Stripe")."' onmouseover=\"this.src='".ARFIMAGESURL."/view_icon23_hover.png';\" onmouseout=\"this.src='".ARFIMAGESURL."/view_icon23.png';\" class='arfhelptip' /></a>";
																		
								echo "<img src='".ARFIMAGESURL."/delete_icon223.png' title='".__("Delete","ARForms-Stripe")."' onmouseover=\"this.src='".ARFIMAGESURL."/delete_icon223_hover.png';\" onmouseout=\"this.src='".ARFIMAGESURL."/delete_icon223.png';\" onclick=\"arf_ChangeID({$order->id})\" data-toggle='arfmodal' href='#delete_form_message' style='cursor:pointer;' class='arfhelptip' />";
								
								echo "<div id='view_entry_{$order->entry_id}' style='display:none; max-height:540px; width:800px; left:20%;' class='arfviewentrymodal arfmodal arfhide arffade'>
										<div class='arfnewmodalclose' data-dismiss='arfmodal'><img src='".ARFIMAGESURL."/close-button.png' align='absmiddle' /></div>
    
                                        <div class='newform_modal_title_container'>
                                            <div class='newform_modal_title' style='text-align:center;'><img src='".ARFIMAGESURL."/view-entry-icon.png' align='absmiddle' />&nbsp;".__('VIEW ENTRY','ARForms-Stripe')."</div>
                                        </div>	
    
								   		<div class='arfentry_modal_content'>" . $arrecordcontroller->get_entries_list($order->entry_id) . "</div>
										
										<div style='clear:both;'></div>
										
										<div class='arfviewentryclose' data-dismiss='arfmodal'><img src='".ARFIMAGESURL."/close-btnicon.png' align='absmiddle' style='margin-right:10px;' />".__('Close', 'ARForms-Stripe')."</div>
                                        
									</div>";
	
					 ?></td>
				</tr>
		   <?php } } ?>
				</tbody>     
		   </table>
				<div class="clear"></div>
				<input type="hidden" name="show_hide_columns" id="show_hide_columns" value="<?php _e('Show / Hide columns','ARForms-Stripe');?>"/>
				<input type="hidden" name="search_grid" id="search_grid" value="<?php _e('Search','ARForms-Stripe');?>"/>
				<input type="hidden" name="entries_grid" id="entries_grid" value="<?php _e('entries','ARForms-Stripe');?>"/>
				<input type="hidden" name="show_grid" id="show_grid" value="<?php _e('Show','ARForms-Stripe');?>"/>
				<input type="hidden" name="showing_grid" id="showing_grid" value="<?php _e('Showing','ARForms-Stripe');?>"/>
				<input type="hidden" name="to_grid" id="to_grid" value="<?php _e('to','ARForms-Stripe');?>"/>
				<input type="hidden" name="of_grid" id="of_grid" value="<?php _e('of','ARForms-Stripe');?>"/>
				<input type="hidden" name="no_match_record_grid" id="no_match_record_grid" value="<?php _e('No matching records found','ARForms-Stripe');?>"/>
				<input type="hidden" name="no_record_grid" id="no_record_grid" value="<?php _e('No data available in table','ARForms-Stripe');?>"/>
				<input type="hidden" name="filter_grid" id="filter_grid" value="<?php _e('filtered from','ARForms-Stripe');?>"/>
				<input type="hidden" name="totalwd_grid" id="totalwd_grid" value="<?php _e('total','ARForms-Stripe');?>"/>
				
				<div class="alignleft actions2">
						<?php 
						$two = '2';
						echo "<div class='sltstandard'><select style='width:120px;' data-width='120px' name='action$two'>\n";
						echo "<option value='-1' selected='selected'>" . __('Bulk Actions','ARForms-Stripe') . "</option>\n";
				
						foreach ( $actions as $name => $title ) {
							$class = 'edit' == $name ? ' class="hide-if-no-js"' : '';
				
							echo "\t<option value='$name'$class>$title</option>\n";
						}
				
						echo "</select></div>\n";
						
						echo '<input type="submit" id="doaction'.$two.'" class="arfbulkbtn arfemailaddbtn" value="'.__('Apply','ARForms-Stripe').'" />'; 
						echo "\n";
						
						?>
				</div>
				<div class="footer_grid"></div>
		  
		<?php	
	}

	

	function arf_stripe_payment_detail($var, $entry_id){
				 	
		if( !empty($entry_id) ) {
            global $wpdb, $armainhelper,$arf_stripe,$arformcontroller,$is_version_compatible;
			$payment_detail = $wpdb->get_results( $wpdb->prepare("SELECT * FROM ".$arf_stripe->db_stripe_order." WHERE entry_id = %d", $entry_id) );
			$payment_detail = isset($payment_detail[0]) ? $payment_detail[0] : '';
					
			if( !empty($payment_detail) ){
					
				$var .= '</tbody></table><div class="arfentrydivider">'.__('Payment Details', 'ARForms-Stripe').'</div><table class="form-table"><tbody>';
								
				$var .= '<tr class="arfviewentry_row" scope="row"><td class="arfviewentry_left"><strong>'.__('Transaction ID', 'ARForms-Stripe').':</strong></td><td class="arfviewentry_right">'.$payment_detail->txn_id.'</td></tr>';
				
				$var .= '<tr class="arfviewentry_row" scope="row"><td class="arfviewentry_left"><strong>'.__('Payment Status', 'ARForms-Stripe').':</strong></td><td class="arfviewentry_right">'.( ($payment_detail->payment_status == 'Completed') ? '<font style="color:#008000">'.$payment_detail->payment_status.'</font>' : '<font style="color:#FFA500">'.$payment_detail->payment_status.'</font>' ).'</td></tr>';

				if($is_version_compatible){
					$var .= '<tr class="arfviewentry_row" scope="row"><td class="arfviewentry_left"><strong>'.__('Total Amount', 'ARForms-Stripe').':</strong></td><td class="arfviewentry_right">'.$arformcontroller->arfdeciamlseparator($payment_detail->mc_gross).' '.$payment_detail->mc_currency.'</td></tr>';

				}else{

					$var .= '<tr class="arfviewentry_row" scope="row"><td class="arfviewentry_left"><strong>'.__('Total Amount', 'ARForms-Stripe').':</strong></td><td class="arfviewentry_right">'.$payment_detail->mc_gross.' '.$payment_detail->mc_currency.'</td></tr>';
				}	
				
				$date_format = get_option('date_format');        	
				$time_format = get_option('time_format');			
                $payment_date = $armainhelper->get_formatted_time($payment_detail->created_at, $date_format, $time_format);
				
				$var .= '<tr class="arfviewentry_row" scope="row"><td class="arfviewentry_left"><strong>'.__('Payment at', 'ARForms-Stripe').':</strong></td><td class="arfviewentry_right">'.$payment_date.'</td></tr>';			
			}
				
		}
		
		return $var;
	}
	
	function currency_list(){
		$currency = array( 'USD', 'AUD','BRL','CAD','CZK','DKK','EUR','HKD','HUF','ILS','JPY','MYR','MXN','NOK','NZD','PHP','PLN','GBP','RUB','SGD','SEK','CHF','TWD','THB','TRY' );
		
		return $currency;
	}

	function currency_symbol($currency_code = 'USD'){
		$currency_symbol = array(
						'AED' =>    'AED   &nbsp;(&nbsp;&nbsp;&#x62f;&#x2e;&#x625;&nbsp;&nbsp;)',
						'ALL' =>    'ALL   &nbsp;(&nbsp;&nbsp;L&nbsp;&nbsp;)',
						'ANG' =>    'ANG   &nbsp;(&nbsp;&nbsp;$&nbsp;&nbsp;)',
						'ARS' =>    'ARS   &nbsp;(&nbsp;&nbsp;&#36;&nbsp;&nbsp;)',
						'AUD' => 	'AUD   &nbsp;(&nbsp;&nbsp;$&nbsp;&nbsp;)',						
						'AWG' => 	'AWG   &nbsp;(&nbsp;&nbsp;&#x192;&nbsp;&nbsp;)',
						'BBD' => 	'BBD   &nbsp;(&nbsp;&nbsp;Bds&#36;&nbsp;&nbsp;)',
						'BDT' => 	'BDT   &nbsp;(&nbsp;&nbsp;&#2547;&nbsp;&nbsp;)',
						'BIF' => 	'BIF   &nbsp;(&nbsp;&nbsp;FBu&nbsp;&nbsp;)',
						'BMD' => 	'BMD   &nbsp;(&nbsp;&nbsp;BD$&nbsp;&nbsp;)',
						'BND' => 	'BND   &nbsp;(&nbsp;&nbsp;B$&nbsp;&nbsp;)',
						'BOB' => 	'BOB   &nbsp;(&nbsp;&nbsp;Bs.&nbsp;&nbsp;)',
						'BRL' => 	'BRL   &nbsp;(&nbsp;&nbsp;R$&nbsp;&nbsp;)',
						'BSD' => 	'BSD   &nbsp;(&nbsp;&nbsp;&#x0024;&nbsp;&nbsp;)',
						'BWP' => 	'BWP   &nbsp;(&nbsp;&nbsp;P&nbsp;&nbsp;)',
						'BZD' => 	'BZD   &nbsp;(&nbsp;&nbsp;BZ$&nbsp;&nbsp;)',
						'CAD' => 	'CAD   &nbsp;(&nbsp;&nbsp;$&nbsp;&nbsp;)',
						'CHF' => 	'CHF   &nbsp;(&nbsp;&nbsp;&#67;&#72;&#70;&nbsp;&nbsp;)',						
						'CLP' => 	'CLP   &nbsp;(&nbsp;&nbsp;&#36;&nbsp;&nbsp;)',
						'CNY' => 	'CNY   &nbsp;(&nbsp;&nbsp;&#165;&nbsp;&nbsp;)',
						'COP' => 	'COP   &nbsp;(&nbsp;&nbsp;&#36;&nbsp;&nbsp;)',
						'CRC' => 	'CRC   &nbsp;(&nbsp;&nbsp;&#8353;&nbsp;&nbsp;)',
						'CVE' => 	'CVE   &nbsp;(&nbsp;&nbsp;Esc&nbsp;&nbsp;)',
						'CZK' => 	'CZK   &nbsp;(&nbsp;&nbsp;&#75;&#269;&nbsp;&nbsp;)',
						'DJF' => 	'DJF   &nbsp;(&nbsp;&nbsp;Fdj&nbsp;&nbsp;)',
						'DKK' => 	'DKK   &nbsp;(&nbsp;&nbsp;&#107;&#114;&nbsp;&nbsp;)',
						'DOP' => 	'DOP   &nbsp;(&nbsp;&nbsp;RD$&nbsp;&nbsp;)',
						'DZD' => 	'DZD   &nbsp;(&nbsp;&nbsp;DA&nbsp;&nbsp;)',
						'EGP' => 	'EGP   &nbsp;(&nbsp;&nbsp;E&#163;&nbsp;&nbsp;)',
						'ETB' => 	'ETB   &nbsp;(&nbsp;&nbsp;Br&nbsp;&nbsp;)',
						'EUR' => 	'EUR   &nbsp;(&nbsp;&nbsp;&#128;&nbsp;&nbsp;)',
						'FJD' => 	'FJD   &nbsp;(&nbsp;&nbsp;FJ$&nbsp;&nbsp;)',
						'FKP' => 	'FKP   &nbsp;(&nbsp;&nbsp;&#xa3;&nbsp;&nbsp;)',
						'GBP' => 	'GBP   &nbsp;(&nbsp;&nbsp;&#163;&nbsp;&nbsp;)',
						'GIP' => 	'GIP   &nbsp;(&nbsp;&nbsp;&#xa3;&nbsp;&nbsp;)',
						'GMD' => 	'GMD   &nbsp;(&nbsp;&nbsp;D&nbsp;&nbsp;)',
						'GNF' => 	'GNF   &nbsp;(&nbsp;&nbsp;FG&nbsp;&nbsp;)',
						'GTQ' => 	'GTQ   &nbsp;(&nbsp;&nbsp;Q&nbsp;&nbsp;)',
						'GYD' => 	'GYD   &nbsp;(&nbsp;&nbsp;&#x24;&nbsp;&nbsp;)',
						'HKD' => 	'HKD   &nbsp;(&nbsp;&nbsp;&#20803;&nbsp;&nbsp;)',
						'HNL' => 	'HNL   &nbsp;(&nbsp;&nbsp;L&nbsp;&nbsp;)',
						'HRK' => 	'HRK   &nbsp;(&nbsp;&nbsp;kn&nbsp;&nbsp;)',
						'HTG' => 	'HTG   &nbsp;(&nbsp;&nbsp;G&nbsp;&nbsp;)',
						'HUF' => 	'HUF   &nbsp;(&nbsp;&nbsp;&#70;&#116;&nbsp;&nbsp;)',
						'IDR' => 	'IDR   &nbsp;(&nbsp;&nbsp;Rp&nbsp;&nbsp;)',
						'ILS' => 	'ILS   &nbsp;(&nbsp;&nbsp;&#8362;&nbsp;&nbsp;)',
						'INR' => 	'INR   &nbsp;(&nbsp;&nbsp;&#8377;&nbsp;&nbsp;)',
						'ISK' => 	'ISK   &nbsp;(&nbsp;&nbsp;&#x6b;&#x72;&nbsp;&nbsp;)',
						'JMD' => 	'JMD   &nbsp;(&nbsp;&nbsp;J$&nbsp;&nbsp;)',
						'JPY' => 	'JPY   &nbsp;(&nbsp;&nbsp;&#165;&nbsp;&nbsp;)',
						'KES' => 	'KES   &nbsp;(&nbsp;&nbsp;KSh&nbsp;&nbsp;)',
						'KHR' => 	'KHR   &nbsp;(&nbsp;&nbsp;&#x17db;&nbsp;&nbsp;)',
						'KMF' => 	'KMF   &nbsp;(&nbsp;&nbsp;CF&nbsp;&nbsp;)',
						'KRW' => 	'KRW   &nbsp;(&nbsp;&nbsp;&#8361;&nbsp;&nbsp;)',
						'KYD' => 	'KYD   &nbsp;(&nbsp;&nbsp;$&nbsp;&nbsp;)',
						'KZT' => 	'KZT   &nbsp;(&nbsp;&nbsp;&#8376;&nbsp;&nbsp;)',
						'LAK' => 	'LAK   &nbsp;(&nbsp;&nbsp;&#8365;&nbsp;&nbsp;)',
						'LBP' => 	'LBP   &nbsp;(&nbsp;&nbsp;L&#163;&nbsp;&nbsp;)',
						'LKR' => 	'LKR   &nbsp;(&nbsp;&nbsp;&#8360;&nbsp;&nbsp;)',
						'LRD' => 	'LRD   &nbsp;(&nbsp;&nbsp;L$&nbsp;&nbsp;)',
						'MAD' => 	'MAD   &nbsp;(&nbsp;&nbsp;&#x2e;&#x62f;&#x2e;&#x645;&nbsp;&nbsp;)',
						'MDL' => 	'MDL   &nbsp;(&nbsp;&nbsp;MDL&nbsp;&nbsp;)',
						'MNT' => 	'MNT   &nbsp;(&nbsp;&nbsp;&#x20ae;&nbsp;&nbsp;)',
						'MOP' => 	'MOP   &nbsp;(&nbsp;&nbsp;P&nbsp;&nbsp;)',
						'MRO' => 	'MRO   &nbsp;(&nbsp;&nbsp;UM&nbsp;&nbsp;)',
						'MUR' => 	'MUR   &nbsp;(&nbsp;&nbsp;&#8360;&nbsp;&nbsp;)',
						'MVR' => 	'MVR   &nbsp;(&nbsp;&nbsp;Rf&nbsp;&nbsp;)',
						'MWK' => 	'MWK   &nbsp;(&nbsp;&nbsp;MK&nbsp;&nbsp;)',
						'MXN' => 	'MXN   &nbsp;(&nbsp;&nbsp;&#36;&nbsp;&nbsp;)',
						'MYR' => 	'MYR   &nbsp;(&nbsp;&nbsp;&#82;&#77;&nbsp;&nbsp;)',
						'NAD' => 	'NAD   &nbsp;(&nbsp;&nbsp;$&nbsp;&nbsp;)',
						'NGN' => 	'NGN   &nbsp;(&nbsp;&nbsp;&#x20a6;&nbsp;&nbsp;)',
						'NIO' => 	'NIO   &nbsp;(&nbsp;&nbsp;C$&nbsp;&nbsp;)',
						'NOK' => 	'NOK   &nbsp;(&nbsp;&nbsp;&#107;&#114;&nbsp;&nbsp;)',
						'NPR' => 	'NPR   &nbsp;(&nbsp;&nbsp;&#8360;&nbsp;&nbsp;)',
						'NZD' => 	'NZD   &nbsp;(&nbsp;&nbsp;&#36;&nbsp;&nbsp;)',
						'PAB' => 	'PAB   &nbsp;(&nbsp;&nbsp;B/.&nbsp;&nbsp;)',
						'PEN' => 	'PEN   &nbsp;(&nbsp;&nbsp;S/.&nbsp;&nbsp;)',
						'PGK' => 	'PGK   &nbsp;(&nbsp;&nbsp;K&nbsp;&nbsp;)',
						'PHP' => 	'PHP   &nbsp;(&nbsp;&nbsp;&#80;&#104;&#8369;&nbsp;&nbsp;)',
						'PKR' => 	'PKR   &nbsp;(&nbsp;&nbsp;&#8360;&nbsp;&nbsp;)',
						'PLN' => 	'PLN   &nbsp;(&nbsp;&nbsp;&#122;&#322;&nbsp;&nbsp;)',
						'PYG' => 	'PYG   &nbsp;(&nbsp;&nbsp;Gs&nbsp;&nbsp;)',
						'QAR' => 	'QAR   &nbsp;(&nbsp;&nbsp;&#65020;&nbsp;&nbsp;)',
						'RUB' => 	'RUB   &nbsp;(&nbsp;&nbsp;&#1088;&#1091;&nbsp;&nbsp;)',
						'SAR' => 	'SAR   &nbsp;(&nbsp;&nbsp;&#65020;&nbsp;&nbsp;)',
						'SBD' => 	'SBD   &nbsp;(&nbsp;&nbsp;SI$&nbsp;&nbsp;)',
						'SCR' => 	'SCR   &nbsp;(&nbsp;&nbsp;&#8360;&nbsp;&nbsp;)',
						'SEK' => 	'SEK   &nbsp;(&nbsp;&nbsp;&#107;&#114;&nbsp;&nbsp;)',
						'SGD' => 	'SGD   &nbsp;(&nbsp;&nbsp;&#36;&nbsp;&nbsp;)',
						'SHP' => 	'SHP   &nbsp;(&nbsp;&nbsp;&#xa3;&nbsp;&nbsp;)',
						'SLL' => 	'SLL   &nbsp;(&nbsp;&nbsp;Le&nbsp;&nbsp;)',
						'SOS' => 	'SOS   &nbsp;(&nbsp;&nbsp;S&nbsp;&nbsp;)',
						'STD' => 	'STD   &nbsp;(&nbsp;&nbsp;Db&nbsp;&nbsp;)',
						'SVC' => 	'SVC   &nbsp;(&nbsp;&nbsp;$&nbsp;&nbsp;)',
						'SZL' => 	'SZL   &nbsp;(&nbsp;&nbsp;SZL&nbsp;&nbsp;)',
						'THB' => 	'THB   &nbsp;(&nbsp;&nbsp;&#3647;&nbsp;&nbsp;)',
						'TOP' => 	'TOP   &nbsp;(&nbsp;&nbsp;T$&nbsp;&nbsp;)',
						'TTD' => 	'TTD   &nbsp;(&nbsp;&nbsp;TT$&nbsp;&nbsp;)',
						'TWD' => 	'TWD   &nbsp;(&nbsp;&nbsp;&#36;&nbsp;&nbsp;)',
						'TZS' => 	'TZS   &nbsp;(&nbsp;&nbsp;x&nbsp;&nbsp;)',
						'UAH' => 	'UAH   &nbsp;(&nbsp;&nbsp;&#8372;&nbsp;&nbsp;)',
						'UGX' => 	'UGX   &nbsp;(&nbsp;&nbsp;USh&nbsp;&nbsp;)',
						'USD' =>	'USD   &nbsp;(&nbsp;&nbsp;$&nbsp;&nbsp;)',										
						'UYU' => 	'UYU   &nbsp;(&nbsp;&nbsp;$U&nbsp;&nbsp;)',
						'UZS' => 	'UZS   &nbsp;(&nbsp;&nbsp;&#x43b;&#x432;&nbsp;&nbsp;)',
						'VND' => 	'VND   &nbsp;(&nbsp;&nbsp;&#8363;&nbsp;&nbsp;)',
						'VUV' => 	'VUV   &nbsp;(&nbsp;&nbsp;VT&nbsp;&nbsp;)',
						'WST' => 	'WST   &nbsp;(&nbsp;&nbsp;T&nbsp;&nbsp;)',
						'XAF' => 	'XAF   &nbsp;(&nbsp;&nbsp;FCFA&nbsp;&nbsp;)',
						'XOF' => 	'XOF   &nbsp;(&nbsp;&nbsp;CFA&nbsp;&nbsp;)',
						'XPF' => 	'XPF   &nbsp;(&nbsp;&nbsp;F&nbsp;&nbsp;)',
						'YER' => 	'YER   &nbsp;(&nbsp;&nbsp;&#65020;&nbsp;&nbsp;)',
						'ZAR' => 	'ZAR   &nbsp;(&nbsp;&nbsp;Z&nbsp;&nbsp;)',

						);
						
		return $currency_symbol;
	}
	
	function arf_stripe_delete_order(){
		$id = $_POST['id'];
		$action = $_POST['act'];
		$form_id = $_POST['form_id'];
		
		$startdate = $_POST['start_date'];
		$enddate = $_POST['end_date'];
		
		global $style_settings, $wp_scripts;
		$wp_format_date = get_option('date_format');

		if( $wp_format_date == 'F j, Y' || $wp_format_date =='m/d/Y' ) {
			$date_format_new = 'mm/dd/yy';
		} else if( $wp_format_date == 'd/m/Y' ) {
			$date_format_new = 'dd/mm/yy';
		} else if( $wp_format_date == 'Y/m/d' ) {
			$date_format_new = 'dd/mm/yy';
		} else {
			$date_format_new = 'mm/dd/yy';
		}
		
		$datequery = "";
		if( $startdate != '' and $enddate != '' ) {
			if($date_format_new=='dd/mm/yy')
			{
				$startdate = str_replace('/', '-', $startdate);
				$enddate = str_replace('/', '-', $enddate);
			}
			$new_start_date_var = date('Y-m-d', strtotime($startdate));
			$new_end_date_var = date('Y-m-d', strtotime($enddate));
			
			$datequery .= " and DATE(created_at) >= '".$new_start_date_var."' and DATE(created_at) <= '".$new_end_date_var."'";
		
		} else if( $startdate != '' and $enddate == '' ) {
			if($date_format_new=='dd/mm/yy')
			{	
				$startdate = str_replace('/', '-', $startdate);
			}
			$new_start_date_var = date('Y-m-d', strtotime($startdate));
			
			$datequery .= " and DATE(created_at) >= '".$new_start_date_var."'";
		
		} else if( $startdate == '' and $enddate != '' ) {
			if($date_format_new=='dd/mm/yy')
			{
				$enddate = str_replace('/', '-', $enddate);
			}
			$new_end_date_var = date('Y-m-d', strtotime($enddate));
			
			$datequery .= " and DATE(created_at) <= '".$new_end_date_var."'";
		}
		
		if( $action == 'delete' && $id ){
            $res = $this->delete_orders($id);
			$message = __('Record is deleted successfully.', 'ARForms-Stripe');
			$errors = array();
			global $is_version_compatible;
		    if($is_version_compatible){
	        	$this->arf_stripe_order_new($message, $errors, $form_id, $datequery, $start_date, $end_date);
	        }
	        else{
	        	$this->arf_stripe_order($message, $errors, $form_id, $datequery, $start_date, $end_date);
	        }
		}
	die();	
	}
	
	function delete_orders($id = 0){
		if( $id == 0 )
			return;
		
		if( $id ){
			global $wpdb,$arf_stripe;			
			$res = $wpdb->query( $wpdb->prepare("DELETE FROM ".$arf_stripe->db_stripe_order." WHERE id = %d", $id) );
			
			return $res;
		}	
	}
	
	function arf_stripe_order_bulk_act(){
		
        if(!isset($_POST)) return;

        global $arfform, $armainhelper;

        $bulkaction = $armainhelper->get_param('action1');
		
		$message = '';
		
		$errors = array();
		
        if($bulkaction == -1)

            $bulkaction = $armainhelper->get_param('action2');


        if(!empty($bulkaction) and strpos($bulkaction, 'bulk_') === 0){

            if(isset($_GET) and isset($_GET['action1']))

                $_SERVER['REQUEST_URI'] = str_replace('&action='.$_GET['action1'], '', $_SERVER['REQUEST_URI']);

            if(isset($_GET) and isset($_GET['action2']))

                $_SERVER['REQUEST_URI'] = str_replace('&action='.$_GET['action2'], '', $_SERVER['REQUEST_URI']);

            $bulkaction = str_replace('bulk_', '', $bulkaction);

        }else{

            $bulkaction = '-1';

            if(isset($_POST['bulkaction']) and $_POST['bulkaction1'] != '-1')

                $bulkaction = $_POST['bulkaction1'];

            else if(isset($_POST['bulkaction2']) and $_POST['bulkaction2'] != '-1')

                $bulkaction = $_POST['bulkaction2'];
        }

        $ids = $armainhelper->get_param('item-action', '');

        if (empty($ids)){
            $errors[] = __('Please select one or more records.', 'ARForms-Stripe');
        }else{                
			if(!is_array($ids))
				$ids = explode(',', $ids);

			if(is_array($ids)){
				if($bulkaction == 'delete'){
				
					foreach($ids as $oid)
                        $res_var = $this->delete_orders($oid);
				
					if($res_var) { $message = __('Record is deleted successfully.', 'ARForms-Stripe'); }
					
				} 
				else if( $bulkaction == 'csv' )
				{
                        echo '<script data-cfasync="false" type="text/javascript">location.href="' . ARFSCRIPTURL . '-Stripe&arfaction=csv&entry_id=' . implode(',', $ids) . '";</script>';
				}

			}

        }
		
		$form_id = $_POST['p_form_id'];
		$startdate = $_POST['start_date'];
		$enddate = $_POST['end_date'];
		
		global $style_settings, $wp_scripts;
		$wp_format_date = get_option('date_format');

		if( $wp_format_date == 'F j, Y' || $wp_format_date =='m/d/Y' ) {
			$date_format_new = 'mm/dd/yy';
		} else if( $wp_format_date == 'd/m/Y' ) {
			$date_format_new = 'dd/mm/yy';
		} else if( $wp_format_date == 'Y/m/d' ) {
			$date_format_new = 'dd/mm/yy';
		} else {
			$date_format_new = 'mm/dd/yy';
		}
		
		$datequery = "";
		if( $startdate != '' and $enddate != '' ) {
			if($date_format_new=='dd/mm/yy')
			{
				$startdate = str_replace('/', '-', $startdate);
				$enddate = str_replace('/', '-', $enddate);
			}
			$new_start_date_var = date('Y-m-d', strtotime($startdate));
			$new_end_date_var = date('Y-m-d', strtotime($enddate));
			
			$datequery .= " and DATE(created_at) >= '".$new_start_date_var."' and DATE(created_at) <= '".$new_end_date_var."'";
		
		} else if( $startdate != '' and $enddate == '' ) {
			if($date_format_new=='dd/mm/yy')
			{	
				$startdate = str_replace('/', '-', $startdate);
			}
			$new_start_date_var = date('Y-m-d', strtotime($startdate));
			
			$datequery .= " and DATE(created_at) >= '".$new_start_date_var."'";
		
		} else if( $startdate == '' and $enddate != '' ) {
			if($date_format_new=='dd/mm/yy')
			{
				$enddate = str_replace('/', '-', $enddate);
			}
			$new_end_date_var = date('Y-m-d', strtotime($enddate));
			
			$datequery .= " and DATE(created_at) <= '".$new_end_date_var."'";
		}
		global $is_version_compatible;
	    if($is_version_compatible){
        	$this->arf_stripe_order_new($message, $errors, $form_id, $datequery, $start_date, $end_date);
        }
        else{
        	$this->arf_stripe_order($message, $errors, $form_id, $datequery, $start_date, $end_date);
        }

	die();
	}
	
	function list_forms($message = ''){
	    global $is_version_compatible;
	    if($is_version_compatible){
		$file = 'list_forms_3.0.php';
	    }else{
		$file = 'list_forms.php';
	    }
	    require(ARF_STRIPE_DIR.'/core/'.$file);	
	}
	
	function arf_stripe_delete_form(){
		$id = $_POST['id'];
		$action = $_POST['act'];
		if( $action == 'delete' && $id ){
            $res = $this->delete_forms($id);
			$message = __('Record is deleted successfully.', 'ARForms-Stripe');
			$errors = array();
			global $is_version_compatible;
	    	if($is_version_compatible){
            	$this->arf_stripe_forms_new($message, $errors);
            }
            else
            {
            	$this->arf_stripe_forms($message, $errors);
            }
		}
	die();	
	}
	
	function delete_forms($id = 0){
		if( $id == 0 )
			return;
		
		if( $id ){
			global $wpdb,$arf_stripe;
			$form = $wpdb->get_results( $wpdb->prepare("SELECT form_id FROM ".$arf_stripe->db_stripe_forms." WHERE id = %d", $id) );
			$form = $form[0];
			
			if(isset($form->form_id) and $form->form_id != '' )
				$res = $wpdb->query( $wpdb->prepare("DELETE FROM ".$arf_stripe->db_stripe_order." WHERE form_id = %d", $form->form_id) );			
			
			$res = $wpdb->query( $wpdb->prepare("DELETE FROM ".$arf_stripe->db_stripe_forms." WHERE id = %d", $id) );
			
			return $res;
		}	
	}

	function arf_stripe_form_bulk_act(){
		
        if(!isset($_POST)) return;

        global $arfform, $armainhelper;

        $bulkaction = $armainhelper->get_param('action1');
		
		$message = '';
		
		$errors = array();
		
        if($bulkaction == -1)

            $bulkaction = $armainhelper->get_param('action2');


        if(!empty($bulkaction) and strpos($bulkaction, 'bulk_') === 0){

            if(isset($_GET) and isset($_GET['action1']))

                $_SERVER['REQUEST_URI'] = str_replace('&action='.$_GET['action1'], '', $_SERVER['REQUEST_URI']);

            if(isset($_GET) and isset($_GET['action2']))

                $_SERVER['REQUEST_URI'] = str_replace('&action='.$_GET['action2'], '', $_SERVER['REQUEST_URI']);

            $bulkaction = str_replace('bulk_', '', $bulkaction);

        }else{

            $bulkaction = '-1';

            if(isset($_POST['bulkaction']) and $_POST['bulkaction1'] != '-1')

                $bulkaction = $_POST['bulkaction1'];

            else if(isset($_POST['bulkaction2']) and $_POST['bulkaction2'] != '-1')

                $bulkaction = $_POST['bulkaction2'];
        }

        $ids = $armainhelper->get_param('item-action', '');

        if (empty($ids)){
            $errors[] = __('Please select one or more records.', 'ARForms-Stripe');
        }else{                
			if(!is_array($ids))
				$ids = explode(',', $ids);

			if(is_array($ids)){
				if($bulkaction == 'delete'){
				
					foreach($ids as $fid)
                        $res_var = $this->delete_forms($fid);
				
					if($res_var) { $message = __('Record is deleted successfully.', 'ARForms-Stripe'); }
					
				}

			}

        }
        global $is_version_compatible;
    	if($is_version_compatible){
        	$this->arf_stripe_forms_new($message, $errors);
        }
        else
        {
        	$this->arf_stripe_forms($message, $errors);
        }

	die();
	}
	
	function arf_stripe_forms_new($message='', $errors = array()){
		global $wpdb,$arformcontroller;
		$actions['bulk_delete'] = __('Delete', 'ARForms-Stripe');

		?>
        <script data-cfasync="false" type="text/javascript" charset="utf-8">
// <![CDATA[
jQuery(document).ready( function () {

	jQuery('.arf_stripe_delete').click(function(event) {
		var id = jQuery(this).attr('data-id');
		if (id == null || id == 'undefined') {
		return;
	    }
	    var delete_popup_html ='';
	    delete_popup_html +='<div class="delete_popup arfactive delete_form_message_'+id+'" id="delete_form_message">';
		delete_popup_html +='<input type="hidden" value="'+id+'" id="delete_entry_id"/>';
		delete_popup_html +='<div class="delete_column_arrow" style="position:absolute;"></div>';
		delete_popup_html +='<div class="delete_title"><div class="delete_confirm_message">Are you sure you want to </br> delete this configuration?</div>';
		delete_popup_html +='<div class="delete_popup_footer">';
	    delete_popup_html +='<button type="button" class="rounded_button add_button arf_delete_modal_left arfdelete_color_red" onclick="arfstripeformactionfunc(\'delete\','+id+');">Delete</button>&nbsp;&nbsp;';
	    delete_popup_html +='<button type="button" class="rounded_button delete_button arfdelete_color_gray" onclick="arf_delete_close_popup('+id+');">Cancel</button>';
		delete_popup_html +='</div>';
		delete_popup_html +='</div>';
		delete_popup_html +='</div>';
		var select_content = jQuery(this).parent().parent('.arf-row-actions');
	    jQuery(delete_popup_html).insertAfter(select_content);
	    jQuery('.delete_form_message_'+id).show();
	});

	jQuery.fn.dataTableExt.oPagination.four_button = {

	"fnInit": function ( oSettings, nPaging, fnCallbackDraw )
	{
		nFirst = document.createElement( 'span' );
		nPrevious = document.createElement( 'span' );



		var nInput = document.createElement( 'input' );
		var nPage = document.createElement( 'span' );
		var nOf = document.createElement( 'span' );
		nOf.className = "paginate_of";
		nInput.className = "current_page_no";
		nPage.className = "paginate_page";
		nInput.type = "text";
		nInput.style.width = "40px";
		nInput.style.height = "26px";
		nInput.style.display = "inline";


		nPaging.appendChild( nPage );



		jQuery(nInput).keyup( function (e) {

			if ( e.which == 38 || e.which == 39 )
			{
				this.value++;
			}
			else if ( (e.which == 37 || e.which == 40) && this.value > 1 )
			{
				this.value--;
			}

			if ( this.value == "" || this.value.match(/[^0-9]/) )
			{

				return;
			}

			var iNewStart = oSettings._iDisplayLength * (this.value - 1);
			if ( iNewStart > oSettings.fnRecordsDisplay() )
			{

				oSettings._iDisplayStart = (Math.ceil((oSettings.fnRecordsDisplay()-1) /
					oSettings._iDisplayLength)-1) * oSettings._iDisplayLength;
				fnCallbackDraw( oSettings );
				return;
			}

			oSettings._iDisplayStart = iNewStart;
			fnCallbackDraw( oSettings );
		} );




		nNext = document.createElement( 'span' );
		nLast = document.createElement( 'span' );
		var nFirst = document.createElement( 'span' );
		var nPrevious = document.createElement( 'span' );
		var nPage = document.createElement( 'span' );
		var nOf = document.createElement( 'span' );

		nNext.style.backgroundRepeat = "no-repeat";
                nNext.style.backgroundPosition = "center";
                nNext.title = "Next";

                nLast.style.backgroundRepeat = "no-repeat";
                nLast.style.backgroundPosition = "center";
                nLast.title = "Last";

                nFirst.style.backgroundRepeat = "no-repeat";
                nFirst.style.backgroundPosition = "center";
                nFirst.title = "First";

                nPrevious.style.backgroundRepeat = "no-repeat";
                nPrevious.style.backgroundPosition = "center";
                nPrevious.title = "Previous";

		nFirst.appendChild( document.createTextNode( ' ' ) );
		nPrevious.appendChild( document.createTextNode( ' ' ) );

		nLast.appendChild( document.createTextNode( ' ' ) );
		nNext.appendChild( document.createTextNode( ' ' ) );


		nOf.className = "paginate_button nof";

		nPaging.appendChild( nFirst );
		nPaging.appendChild( nPrevious );

		nPaging.appendChild( nInput );
		nPaging.appendChild( nOf );

		nPaging.appendChild( nNext );
		nPaging.appendChild( nLast );

		jQuery(nFirst).click( function () {
			oSettings.oApi._fnPageChange( oSettings, "first" );
			fnCallbackDraw( oSettings );
		} );

		jQuery(nPrevious).click( function() {
			oSettings.oApi._fnPageChange( oSettings, "previous" );
			fnCallbackDraw( oSettings );
		} );

		jQuery(nNext).click( function() {
			oSettings.oApi._fnPageChange( oSettings, "next" );
			fnCallbackDraw( oSettings );
		} );

		jQuery(nLast).click( function() {
			oSettings.oApi._fnPageChange( oSettings, "last" );
			fnCallbackDraw( oSettings );
		} );


		jQuery(nFirst).bind( 'selectstart', function () { return false; } );
		jQuery(nPrevious).bind( 'selectstart', function () { return false; } );
		jQuery('span', nPaging).bind( 'mousedown', function () { return false; } );
		jQuery('span', nPaging).bind( 'selectstart', function () { return false; } );
		jQuery(nNext).bind( 'selectstart', function () { return false; } );
		jQuery(nLast).bind( 'selectstart', function () { return false; } );
	},


	"fnUpdate": function ( oSettings, fnCallbackDraw )
	{
		if ( !oSettings.aanFeatures.p )
		{
			return;
		}


		var an = oSettings.aanFeatures.p;
		for ( var i=0, iLen=an.length ; i<iLen ; i++ )
		{
			var buttons = an[i].getElementsByTagName('span');


			if ( oSettings._iDisplayStart === 0 )
			{

				buttons[1].className = "paginate_disabled_first arfhelptip";
				buttons[2].className = "paginate_disabled_previous arfhelptip";
			}
			else
			{

				buttons[1].className = "paginate_enabled_first arfhelptip";
				buttons[2].className = "paginate_enabled_previous arfhelptip";
			}

			if ( oSettings.fnDisplayEnd() == oSettings.fnRecordsDisplay() )
			{
				buttons[4].className = "paginate_disabled_next arfhelptip";
				buttons[5].className = "paginate_disabled_last arfhelptip";
			}
			else
			{

				buttons[4].className = "paginate_enabled_next arfhelptip";
				buttons[5].className = "paginate_enabled_last arfhelptip";
			}



			if ( !oSettings.aanFeatures.p )
			{
				return;
			}
			var iPages = Math.ceil((oSettings.fnRecordsDisplay()) / oSettings._iDisplayLength);
			var iCurrentPage = Math.ceil(oSettings._iDisplayStart / oSettings._iDisplayLength) + 1;

			if(document.getElementById('of_grid'))
				of_grid = document.getElementById('of_grid').value;
			else
				of_grid = 'of';

			var an = oSettings.aanFeatures.p;
			for ( var i=0, iLen=an.length ; i<iLen ; i++ )
			{
				var spans = an[i].getElementsByTagName('span');
				var inputs = an[i].getElementsByTagName('input');
				spans[spans.length-3].innerHTML =" "+of_grid+" "+iPages
				inputs[0].value = iCurrentPage;
			}
		}
	}
}

jQuery('#example').dataTable( {
	"sDom": '<"H"lfr>t<"footer"ip>',
	"sPaginationType": "four_button",
	"bJQueryUI": true,
	"bPaginate": true,
	"bAutoWidth" : false,
	"aoColumnDefs": [
		{ "bVisible": false, "aTargets": [] },
		{ "bSortable": false, "aTargets": [ 0, 6 ] }
	],
	"oColVis": {
	   "aiExclude": [ 0, 6 ]
	},

	});
});

// ]]>

jQuery(document).ready( function () {

jQuery("#cb-select-all-1").click(function () {
	  jQuery('input[name="item-action[]"]').attr('checked', this.checked);
});


jQuery('input[name="item-action[]"]').click(function(){

	if(jQuery('input[name="item-action[]"]').length == jQuery('input[name="item-action[]"]:checked').length) {
		jQuery("#cb-select-all-1").attr("checked", "checked");
	} else {
		jQuery("#cb-select-all-1").removeAttr("checked");
	}

});

});

</script>

<?php
	if (isset($message) && $message != ''){ if(is_admin()){ ?>
        <script type="text/javascript" language="javascript"> setTimeout( function(){ success_msg(); },10); </script>
        <div id="success_message" class="arf_success_message">
            <div class="message_descripiton">
                <div style="float: left; margin-right: 15px;"><?php  echo $message; ?></div>
                <div class="message_svg_icon">
                    <svg style="height: 14px;stroke-width: 14px;">
                        <path fill-rule="evenodd" clip-rule="evenodd" fill="#FFFFFF" d="M6.075,14.407l-5.852-5.84l1.616-1.613l4.394,4.385L17.181,0.411
                                                                        l1.616,1.613L6.392,14.407H6.075z"></path></svg>
                </div>
            </div>
        </div>
        <?php } }

	if( isset($errors) && is_array($errors) && count($errors) > 0 ){ ?>
	<?php
        foreach ($errors as $error) {
            ?><script type="text/javascript" language="javascript"> setTimeout( function(){ error_msg(); },10); </script>
            <div id="error_message" class="arf_error_message">
            <div class="message_descripiton">
                    <div style="float: left; margin-right: 15px;"><?php echo stripslashes($error); ?></div>
                    <div class="message_svg_icon">
                            <svg style="height: 14px;stroke-width: 14px;"><path fill-rule="evenodd" clip-rule="evenodd" fill="#ffffff" d="M10.702,10.909L6.453,6.66l-4.249,4.249L1.143,9.848l4.249-4.249L1.154,1.361l1.062-1.061l4.237,4.237l4.238-4.237l1.061,1.061L7.513,5.599l4.249,4.249L10.702,10.909z"></path></svg>
                    </div>
            </div>
            </div>
        <?php } ?>
        <?php } ?>

<div style="position:absolute;right:50px;margin-top: 21px;">
    <button class="rounded_button arf_btn_dark_blue" type="button" onclick="location.href='<?php echo admin_url('admin.php?page=ARForms-Stripe&arfaction=new');?>';" style="width:205px !important;"><svg width="20px" height="20px" style="vertical-align: middle;"><path fill-rule="evenodd" clip-rule="evenodd" fill="#FFFFFF" d="M16.997,7.32v2h-7v6.969h-2V9.32h-7v-2h7V0.289h2V7.32H16.997z"/></svg>&nbsp;<?php _e('Configure New Form', 'ARForms-Stripe'); ?></button>
</div>

<?php $two = '1';?>
<div class="alignleft actions">
    <div class="arf_list_bulk_action_wrapper">
	<input id="arf_bulk_action_one" name="action<?php echo $two; ?>" value="-1" type="hidden">
	<dl class="arf_selectbox" data-name="action<?php echo $two; ?>" data-id="arf_bulk_action_one">
	    <dt style="width:121px;"><span><?php echo __('Bulk Actions', 'ARForms-Stripe'); ?></span>
		<input value="<?php echo __('Bulk Actions', 'ARForms-Stripe'); ?>" style="display:none;" class="" type="text">
		<svg viewBox="0 0 2000 1000" width="15px" height="15px">
		<g fill="#000">
		    <path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"/>
		</g>
		</svg>
	    </dt>
	    <dd>
		<ul style="display: none;width: 121px;" data-id="arf_bulk_action_one">
		    <li data-value='-1' data-label='<?php _e('Bulk Actions', 'ARForms-Stripe'); ?>'><?php _e('Bulk Actions', 'ARForms-Stripe'); ?></li>
		    <?php
		    foreach ($actions as $name => $title) {
		    $class = 'edit' == $name ? ' class="hide-if-no-js" ' : '';?>
			<li <?php echo $class; ?> data-value='<?php echo $name; ?>' data-label='<?Php echo $title; ?>'><?php echo $title; ?></li>
		    <?php }?>
		</ul>
	    </dd>
	</dl>
    </div>
    <?php
	echo '<input type="submit" id="doaction'.$two.'" class="arf_bulk_action_btn rounded_button btn_green" value="'.__('Apply','ARForms-Stripe').'" />';
	echo "\n";
    ?>
</div>

<table cellpadding="0" cellspacing="0" border="0" class="display table_grid" id="example">
  <thead>
    <tr>
        <th class="center" style="width:50px;">
	    <div class="arf_custom_checkbox_div">
	    <div class="arf_custom_checkbox_wrapper" style="margin-left:15px;">
	    <input id="cb-select-all-1" type="checkbox" class="">
	    <svg width="18px" height="18px">
		<path id="arfcheckbox_unchecked" d="M15.205,16.852H3.774c-1.262,0-2.285-1.023-2.285-2.286V3.136  c0-1.263,1.023-2.286,2.285-2.286h11.431c1.263,0,2.286,1.023,2.286,2.286v11.43C17.491,15.829,16.467,16.852,15.205,16.852z   M15.49,2.851h-12v12h12V2.851z"></path><path id="arfcheckbox_checked" d="M15.205,16.852H3.774c-1.262,0-2.285-1.023-2.285-2.286V3.136  c0-1.263,1.023-2.286,2.285-2.286h11.431c1.263,0,2.286,1.023,2.286,2.286v11.43C17.491,15.829,16.467,16.852,15.205,16.852z   M15.49,2.851h-12v12h12V2.851z M5.93,6.997l2.557,2.558l4.843-4.843l1.617,1.616l-4.844,4.843l0.007,0.007l-1.616,1.616  l-0.007-0.007l-0.006,0.007l-1.617-1.616l0.007-0.007L4.314,8.614L5.93,6.997z"></path></svg>
		</div>
	    <label for="cb-select-all-1"  class="cb-select-all"><span></span></label></div>
	</th>
        <th class=""><?php _e('Form ID', 'ARForms-Stripe'); ?></th>
        <th class=""><?php _e('Form Title', 'ARForms-Stripe'); ?></th>
        <th class="" style="text-align:center"><?php _e('Transactions', 'ARForms-Stripe'); ?></th>
        <th class="" style="text-align:center"><?php _e('Total Amount', 'ARForms-Stripe'); ?></th>
        <th class=""><?php _e('Created Date', 'ARForms-Stripe'); ?></th>
        <th class="arf_col_action arf_action_cell"><?php _e('Action', 'ARForms-Stripe'); ?></th>
    </tr>
  </thead>
  </tbody>
<?php
global $arf_stripe,$MdlDb;
$forms = $wpdb->get_results( "SELECT * FROM ".$arf_stripe->db_stripe_forms." ORDER BY id DESC" );
if( count($forms) > 0 ){
foreach( $forms as $form ){
	$options = maybe_unserialize($form->options);
	?>
    <tr style="height: 50px;">
        <td class="center">
	    <div class="arf_custom_checkbox_div">
	    <div class="arf_custom_checkbox_wrapper" style="margin-left:15px;">
	    <input id="cb-item-action-<?php echo $form->id;?>" type="checkbox" value="<?php echo $form->id;?>" name="item-action[]">
	    <svg width="18px" height="18px">
		<path id="arfcheckbox_unchecked" d="M15.205,16.852H3.774c-1.262,0-2.285-1.023-2.285-2.286V3.136  c0-1.263,1.023-2.286,2.285-2.286h11.431c1.263,0,2.286,1.023,2.286,2.286v11.43C17.491,15.829,16.467,16.852,15.205,16.852z   M15.49,2.851h-12v12h12V2.851z"></path><path id="arfcheckbox_checked" d="M15.205,16.852H3.774c-1.262,0-2.285-1.023-2.285-2.286V3.136  c0-1.263,1.023-2.286,2.285-2.286h11.431c1.263,0,2.286,1.023,2.286,2.286v11.43C17.491,15.829,16.467,16.852,15.205,16.852z   M15.49,2.851h-12v12h12V2.851z M5.93,6.997l2.557,2.558l4.843-4.843l1.617,1.616l-4.844,4.843l0.007,0.007l-1.616,1.616  l-0.007-0.007l-0.006,0.007l-1.617-1.616l0.007-0.007L4.314,8.614L5.93,6.997z"></path></svg>
		</div>
		<label for="cb-item-action-<?php echo $form->id;?>"><span></span></label></div></td>
        <td><?php echo $form->form_id; ?></td>
        <td class="form_name"><a class="row-title" href="<?php echo wp_nonce_url( "?page=ARForms-Stripe&arfaction=edit&id={$form->id}" ); ?>"><?php
		//$form_name = $wpdb->get_results( $wpdb->prepare("SELECT name FROM ".$MdlDb->forms." WHERE id = %d", $form->form_id) );
		//$form_name = $form_name[0];
		echo $form->form_name; ?></a></td>
        <td class="center"><?php
		$record_count = $wpdb->get_results( $wpdb->prepare("SELECT count(*) AS record_count FROM ".$arf_stripe->db_stripe_order." WHERE form_id = %d", $form->form_id) );
		$record_count = $record_count[0];
		echo "<a href='" . wp_nonce_url( "?page=ARForms-Stripe-order&form={$form->form_id}" ) . "'>".$record_count->record_count."</a>"; ?></td>
        <td class="center"><?php
		$total_amount = $wpdb->get_results( $wpdb->prepare("SELECT SUM(mc_gross) AS total_amount FROM ".$arf_stripe->db_stripe_order." WHERE form_id = %d", $form->form_id) );
		$total_amount = $total_amount[0];
		echo ((isset($total_amount->total_amount)) ? $arformcontroller->arfdeciamlseparator($total_amount->total_amount) : $arformcontroller->arfdeciamlseparator(0)).' '.$options['currency']; ?></td>
        <td><?php echo date(get_option('date_format'), strtotime($form->created_at)); ?></td>
        <td class="arf_action_cell">
        <div class="arf-row-actions" style="padding-top: 0px !important;">
        <?php
				$edit_link = "?page=ARForms-Stripe&arfaction=edit&id={$form->id}";

				echo "<div class='arfformicondiv arfhelptip' title='" .__('Edit Configuration','ARForms-Stripe') . "'><a href='" . wp_nonce_url($edit_link) . "'><svg width='30px' height='30px' viewBox='-5 -4 30 30' class='arfsvgposition'><path fill='#ffffff' d='M17.469,7.115v10.484c0,1.25-1.014,2.264-2.264,2.264H3.75c-1.25,0-2.262-1.014-2.262-2.264V5.082  c0-1.25,1.012-2.264,2.262-2.264h9.518l-2.264,2.001H3.489v13.042h11.979V9.379L17.469,7.115z M15.532,2.451l-0.801,0.8l2.4,2.401  l0.801-0.8L15.532,2.451z M17.131,0.85l-0.799,0.801l2.4,2.4l0.801-0.801L17.131,0.85z M6.731,11.254l2.4,2.4l7.201-7.202  l-2.4-2.401L6.731,11.254z M5.952,14.431h2.264l-2.264-2.264V14.431z'></path></svg></a></div>";
				   //echo "<a href='" .wp_nonce_url( $edit_link ). "'><img src='".ARFIMAGESURL."/edit-icon22.png' onmouseover=\"this.src='".ARFIMAGESURL."/edit-icon_hover22.png';\" class=' arfhelptip' title='".__('Edit Configuration','ARForms-Stripe')."' onmouseout=\"this.src='".ARFIMAGESURL."/edit-icon22.png';\" /></a>";


					echo "<div class='arfformicondiv arfhelptip' title='".__('Transactions','ARForms-Stripe')."'><a href='" . wp_nonce_url( "?page=ARForms-Stripe-order&form={$form->form_id}" ). "'><svg width='30px' height='30px' viewBox='-5 -4 30 30' class='arfsvgposition'><path fill='#ffffff' d='M12.32,5.952c1.696-1.316,2.421-2.171,2.747-3.272c0.307-1.039-0.35-2.396-1.703-2.576    c-0.881-0.114-2.071,0.374-3.53,0.811c-0.477,0.143-0.979,0.143-1.451,0c-1.459-0.432-2.653-0.965-3.53-0.811    C3.234,0.389,2.892,1.73,3.149,2.68C3.45,3.789,4.2,4.635,5.896,5.952c-2.319,1.745-4.889,6.095-4.889,8.504    c0,3.314,3.854,5.647,8.101,5.647s8.141-2.333,8.141-5.647C17.249,12.047,14.639,7.696,12.32,5.952z M4.762,2.231    c-0.04-0.143-0.068-0.399,0.311-0.469c0.444-0.082,1.3-0.227,2.837,0.229c0.786,0.232,1.618,0.232,2.405,0    c1.536-0.457,2.393-0.307,2.837-0.229c0.313,0.053,0.346,0.326,0.31,0.469c-0.285,1.019-1.02,1.817-2.797,2.824    C10.167,4.884,9.65,4.79,9.116,4.79c-0.533,0-1.056,0.094-1.549,0.265C5.778,4.048,5.043,3.247,4.762,2.231z M9.108,18.093    c-2.462,0-5.51-0.747-5.51-3.637c0-2.633,2.624-8.007,5.51-8.007s5.471,5.374,5.471,8.007    C14.579,17.346,11.615,18.093,9.108,18.093z M9.202,12.316c-0.408,0-0.742-0.334-0.742-0.742s0.334-0.742,0.742-0.742    c0.208,0,0.399,0.082,0.542,0.232c0.27,0.286,0.722,0.302,1.007,0.033s0.302-0.721,0.033-1.007    c-0.241-0.257-0.539-0.448-0.869-0.563H8.489c-0.849,0.298-1.456,1.101-1.456,2.046c0,1.194,0.975,2.168,2.169,2.168    c0.407,0,0.742,0.334,0.742,0.742c0,0.408-0.335,0.742-0.742,0.742c-0.208,0-0.399-0.082-0.542-0.232    c-0.27-0.285-0.722-0.302-1.007-0.033s-0.302,0.722-0.033,1.007c0.241,0.257,0.538,0.449,0.869,0.563c0,0,0.738,0.281,1.426,0    c0.849-0.297,1.455-1.101,1.455-2.046C11.37,13.286,10.396,12.316,9.202,12.316z'/></svg></a></div>";
				   //echo "<a href='" . wp_nonce_url( "?page=ARForms-Stripe-order&form={$form->form_id}" ) . "'><img src='".ARF_STRIPE_URL."/images/trans.png' title='".__('Transaction','ARForms-Stripe')."' class=' arfhelptip' onmouseover=\"this.src='".ARF_STRIPE_URL."/images/trans_hover.png';\" onmouseout=\"this.src='".ARF_STRIPE_URL."/images/trans.png';\" /></a>";
					echo "<div class='arfformicondiv arfhelptip arfdeleteform_div_".$form->id."' title='" . __("Delete","ARForms-Stripe"). "'><a class='arf_stripe_delete' data-id='".$form->id."' style='cursor:pointer'><svg width='30px' height='30px' viewBox='-5 -5 32 32' class='arfsvgposition'><path fill-rule='evenodd' clip-rule='evenodd' fill='#ffffff' d='M18.435,4.857L18.413,19.87L3.398,19.88L3.394,4.857H1.489V2.929  h1.601h3.394V0.85h8.921v2.079h3.336h1.601l0,0v1.928H18.435z M15.231,4.857H6.597H5.425l0.012,13.018h10.945l0.005-13.018H15.231z   M11.4,6.845h2.029v9.065H11.4V6.845z M8.399,6.845h2.03v9.065h-2.03V6.845z' /></svg></a></div>";


                   //echo "<img src='".ARFIMAGESURL."/delete_icon223.png' title='".__("Delete","ARForms-Stripe")."' class=' arfhelptip' onmouseover=\"this.src='".ARFIMAGESURL."/delete_icon223_hover.png';\" onmouseout=\"this.src='".ARFIMAGESURL."/delete_icon223.png';\" onclick=\"arf_ChangeID({$form->id})\" data-toggle='arfmodal' href='#delete_form_message' style='cursor:pointer'/></a>";

         ?>
        </div>
        </td>
    </tr>
<?php } } ?>
    </tbody>
</table>
    <div class="clear"></div>
    <input type="hidden" name="show_hide_columns" id="show_hide_columns" value="<?php _e('Show / Hide columns','ARForms-Stripe');?>"/>
    <input type="hidden" name="search_grid" id="search_grid" value="<?php _e('Search','ARForms-Stripe');?>"/>
    <input type="hidden" name="entries_grid" id="entries_grid" value="<?php _e('entries','ARForms-Stripe');?>"/>
    <input type="hidden" name="show_grid" id="show_grid" value="<?php _e('Show','ARForms-Stripe');?>"/>
    <input type="hidden" name="showing_grid" id="showing_grid" value="<?php _e('Showing','ARForms-Stripe');?>"/>
    <input type="hidden" name="to_grid" id="to_grid" value="<?php _e('to','ARForms-Stripe');?>"/>
    <input type="hidden" name="of_grid" id="of_grid" value="<?php _e('of','ARForms-Stripe');?>"/>
    <input type="hidden" name="no_match_record_grid" id="no_match_record_grid" value="<?php _e('No matching records found','ARForms-Stripe');?>"/>
    <input type="hidden" name="no_record_grid" id="no_record_grid" value="<?php _e('No data available in table','ARForms-Stripe');?>"/>
    <input type="hidden" name="filter_grid" id="filter_grid" value="<?php _e('filtered from','ARForms-Stripe');?>"/>
    <input type="hidden" name="totalwd_grid" id="totalwd_grid" value="<?php _e('total','ARForms-Stripe');?>"/>

    <?php $two = '2';?>
    <div class="alignleft actions2">
	<div class="arf_list_bulk_action_wrapper">
	    <input id="arf_bulk_action_two" name="action<?php echo $two; ?>" value="-1" type="hidden">
	    <dl class="arf_selectbox" data-name="action<?php echo $two; ?>" data-id="arf_bulk_action_two">
		<dt style="width:121px;"><span><?php echo __('Bulk Actions', 'ARForms-Stripe'); ?></span>
		    <input value="<?php echo __('Bulk Actions', 'ARForms-Stripe'); ?>" style="display:none;" class="" type="text">
		    <svg viewBox="0 0 2000 1000" width="15px" height="15px">
		    <g fill="#000">
			<path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"/>
		    </g>
		    </svg>
		</dt>
		<dd>
		    <ul style="display: none;width: 121px;" data-id="arf_bulk_action_two">
			<li data-value='-1' data-label='<?php _e('Bulk Actions', 'ARForms-Stripe'); ?>'><?php _e('Bulk Actions', 'ARForms-Stripe'); ?></li>
			<?php
			foreach ($actions as $name => $title) {
			$class = 'edit' == $name ? ' class="hide-if-no-js" ' : '';?>
			    <li <?php echo $class; ?> data-value='<?php echo $name; ?>' data-label='<?Php echo $title; ?>'><?php echo $title; ?></li>
			<?php }?>
		    </ul>
		</dd>
	    </dl>
	</div>
	<?php
	    echo '<input type="submit" id="doaction'.$two.'" class="arf_bulk_action_btn rounded_button btn_green" value="'.__('Apply','ARForms-Stripe').'" />';
	    echo "\n";
	?>
    </div>
    <div class="footer_grid"></div>

    <?php

	}
	
	function arf_stripe_forms($message='', $errors = array()){
		global $wpdb;
		$actions['bulk_delete'] = __('Delete', 'ARForms-Stripe');
		
		?>
        <script data-cfasync="false" type="text/javascript" charset="utf-8">
// <![CDATA[
jQuery(document).ready( function () {
	
	jQuery.fn.dataTableExt.oPagination.four_button = {
	
	"fnInit": function ( oSettings, nPaging, fnCallbackDraw )
	{	
		nFirst = document.createElement( 'span' );
		nPrevious = document.createElement( 'span' );
		
		
		
		var nInput = document.createElement( 'input' );
		var nPage = document.createElement( 'span' );
		var nOf = document.createElement( 'span' );
		nOf.className = "paginate_of";
		nInput.className = "current_page_no";
		nPage.className = "paginate_page";
		nInput.type = "text";
		nInput.style.width = "40px";
		nInput.style.height = "26px";
		nInput.style.display = "inline";
		
		 
		nPaging.appendChild( nPage );
		
		
		 
		jQuery(nInput).keyup( function (e) {
					 
			if ( e.which == 38 || e.which == 39 )
			{
				this.value++;
			}
			else if ( (e.which == 37 || e.which == 40) && this.value > 1 )
			{
				this.value--;
			}
 
			if ( this.value == "" || this.value.match(/[^0-9]/) )
			{
				
				return;
			}
 
			var iNewStart = oSettings._iDisplayLength * (this.value - 1);
			if ( iNewStart > oSettings.fnRecordsDisplay() )
			{
				
				oSettings._iDisplayStart = (Math.ceil((oSettings.fnRecordsDisplay()-1) /
					oSettings._iDisplayLength)-1) * oSettings._iDisplayLength;
				fnCallbackDraw( oSettings );
				return;
			}
 
			oSettings._iDisplayStart = iNewStart;
			fnCallbackDraw( oSettings );
		} );
 
		
		
		
		nNext = document.createElement( 'span' );
		nLast = document.createElement( 'span' );
		var nFirst = document.createElement( 'span' );
		var nPrevious = document.createElement( 'span' );
		var nPage = document.createElement( 'span' );
		var nOf = document.createElement( 'span' );
		
		nNext.style.backgroundImage = "url('<?php echo ARFURL; ?>/images/next_normal-icon.png')";
		nNext.style.backgroundRepeat = "no-repeat";
		nNext.style.backgroundPosition = "center";
		nNext.title = "Next";
		
		nLast.style.backgroundImage = "url('<?php echo ARFURL; ?>/images/last_normal-icon.png')";
		nLast.style.backgroundRepeat = "no-repeat";
		nLast.style.backgroundPosition = "center";
		nLast.title = "Last";
		
		nFirst.style.backgroundImage = "url('<?php echo ARFURL; ?>/images/first_normal-icon.png')";
		nFirst.style.backgroundRepeat = "no-repeat";
		nFirst.style.backgroundPosition = "center";
		nFirst.title = "First";
		
		nPrevious.style.backgroundImage = "url('<?php echo ARFURL; ?>/images/previous_normal-icon.png')";
		nPrevious.style.backgroundRepeat = "no-repeat";
		nPrevious.style.backgroundPosition = "center";		
		nPrevious.title = "Previous";		
		
		nFirst.appendChild( document.createTextNode( ' ' ) );
		nPrevious.appendChild( document.createTextNode( ' ' ) );
		
		nLast.appendChild( document.createTextNode( ' ' ) );
		nNext.appendChild( document.createTextNode( ' ' ) );
		
		 
		nOf.className = "paginate_button nof";
		 
		nPaging.appendChild( nFirst );
		nPaging.appendChild( nPrevious );
		
		nPaging.appendChild( nInput );
		nPaging.appendChild( nOf );
		
		nPaging.appendChild( nNext );
		nPaging.appendChild( nLast );
		 
		jQuery(nFirst).click( function () {
			oSettings.oApi._fnPageChange( oSettings, "first" );
			fnCallbackDraw( oSettings );
		} );
		 
		jQuery(nPrevious).click( function() {
			oSettings.oApi._fnPageChange( oSettings, "previous" );
			fnCallbackDraw( oSettings );
		} );
		 
		jQuery(nNext).click( function() {
			oSettings.oApi._fnPageChange( oSettings, "next" );
			fnCallbackDraw( oSettings );
		} );
		 
		jQuery(nLast).click( function() {
			oSettings.oApi._fnPageChange( oSettings, "last" );
			fnCallbackDraw( oSettings );
		} );
		 
		
		jQuery(nFirst).bind( 'selectstart', function () { return false; } );
		jQuery(nPrevious).bind( 'selectstart', function () { return false; } );
		jQuery('span', nPaging).bind( 'mousedown', function () { return false; } );
		jQuery('span', nPaging).bind( 'selectstart', function () { return false; } );
		jQuery(nNext).bind( 'selectstart', function () { return false; } );
		jQuery(nLast).bind( 'selectstart', function () { return false; } );
	},
	 
	
	"fnUpdate": function ( oSettings, fnCallbackDraw )
	{
		if ( !oSettings.aanFeatures.p )
		{
			return;
		}
		 
		
		var an = oSettings.aanFeatures.p;
		for ( var i=0, iLen=an.length ; i<iLen ; i++ )
		{
			var buttons = an[i].getElementsByTagName('span');
			
			
			if ( oSettings._iDisplayStart === 0 )
			{
				
				buttons[1].className = "paginate_disabled_first arfhelptip";
				buttons[2].className = "paginate_disabled_previous arfhelptip";
			}
			else
			{
				
				buttons[1].className = "paginate_enabled_first arfhelptip";
				buttons[2].className = "paginate_enabled_previous arfhelptip";
			}

			if ( oSettings.fnDisplayEnd() == oSettings.fnRecordsDisplay() )
			{
				buttons[4].className = "paginate_disabled_next arfhelptip";
				buttons[5].className = "paginate_disabled_last arfhelptip";
			}
			else
			{
				
				buttons[4].className = "paginate_enabled_next arfhelptip";
				buttons[5].className = "paginate_enabled_last arfhelptip";
			}


			
			if ( !oSettings.aanFeatures.p )
			{
				return;
			}
			var iPages = Math.ceil((oSettings.fnRecordsDisplay()) / oSettings._iDisplayLength);
			var iCurrentPage = Math.ceil(oSettings._iDisplayStart / oSettings._iDisplayLength) + 1;
			
			if(document.getElementById('of_grid'))
				of_grid = document.getElementById('of_grid').value;
			else
				of_grid = 'of';
			
			var an = oSettings.aanFeatures.p;
			for ( var i=0, iLen=an.length ; i<iLen ; i++ )
			{
				var spans = an[i].getElementsByTagName('span');
				var inputs = an[i].getElementsByTagName('input');
				spans[spans.length-3].innerHTML =" "+of_grid+" "+iPages
				inputs[0].value = iCurrentPage;
			}
		}
	}
}
	
jQuery('#example').dataTable( {
	"sDom": '<"H"lfr>t<"footer"ip>',	
	"sPaginationType": "four_button",
	"bJQueryUI": true,
	"bPaginate": true,
	"bAutoWidth" : false,					
	"aoColumnDefs": [
		{ "bVisible": false, "aTargets": [] },
		{ "bSortable": false, "aTargets": [ 0, 6 ] }
	],
	"oColVis": {
	   "aiExclude": [ 0, 6 ]
	},
	
	});
});
		
// ]]>

jQuery(document).ready( function () { 	

jQuery("#cb-select-all-1").click(function () {
	  jQuery('input[name="item-action[]"]').attr('checked', this.checked);
});


jQuery('input[name="item-action[]"]').click(function(){

	if(jQuery('input[name="item-action[]"]').length == jQuery('input[name="item-action[]"]:checked').length) {
		jQuery("#cb-select-all-1").attr("checked", "checked");
	} else {
		jQuery("#cb-select-all-1").removeAttr("checked");
	}

});

});
						
</script>

<?php
	if (isset($message) && $message != ''){ if(is_admin()){ ?><div id="success_message" style="margin-bottom:0px; margin-top:15px; width:95%;"><div class="arfsuccessmsgicon"></div><div class="arf_success_message"><?php } echo $message; if(is_admin()){ ?></div></div><?php } }
	
	if( isset($errors) && is_array($errors) && count($errors) > 0 ){ ?>	
	<div style="margin-bottom:0px; margin-top:8px;">	
		<ul id="frm_errors" style="margin-bottom: 0px; margin-top: 0px;">	
			<?php foreach ($errors as $error )
				echo '<li><div class="arferrmsgicon"></div><div id="error_message">' . stripslashes($error) . '</div></li>';
			?>	
		</ul>	
	</div>
<?php } ?>

<div style="position:absolute;right:50px;">
    <button class="greensavebtn" type="button" onclick="location.href='<?php echo admin_url('admin.php?page=ARForms-Stripe&arfaction=new');?>';" style="width:205px; border:0px; color:#FFFFFF; height:40px; border-radius:3px;"><img align="absmiddle" src="<?php echo ARFIMAGESURL ?>/plus-icon.png">&nbsp;&nbsp;<?php _e('Configure New Form', 'ARForms-Stripe'); ?></button>
</div>

<div class="alignleft actions">
    <?php 
    $two = '1';
    echo "<div class='sltstandard'><select style='width:120px;' data-width='120px' name='action$two'>\n";
    echo "<option value='-1' selected='selected'>" . __('Bulk Actions','ARForms-Stripe') . "</option>\n";

    foreach ( $actions as $name => $title ) {
        $class = 'edit' == $name ? ' class="hide-if-no-js"' : '';

        echo "\t<option value='$name'$class>$title</option>\n";
    }

    echo "</select></div>\n";
    
    echo '<input type="submit" id="doaction'.$two.'" class="arfbulkbtn arfemailaddbtn" value="'.__('Apply','ARForms-Stripe').'" />';
    echo "\n";
    
    ?>
</div>
<table cellpadding="0" cellspacing="0" border="0" class="display" id="example">
  <thead>
    <tr>
        <th class="center" style="width:50px;"><div style="display:inline-block; position:relative;"><input id="cb-select-all-1" type="checkbox" class="chkstanard"><label for="cb-select-all-1"  class="cb-select-all"><span></span></label></div></th>
        <th class=""><?php _e('Form ID', 'ARForms-Stripe'); ?></th>                
        <th class=""><?php _e('Form Name', 'ARForms-Stripe'); ?></th>
        <th class=""><?php _e('Transactions', 'ARForms-Stripe'); ?></th>
        <th class=""><?php _e('Total Amount', 'ARForms-Stripe'); ?></th>
        <th class=""><?php _e('Created Date', 'ARForms-Stripe'); ?></th>
        <th class="col_action" style="width:150px;"><?php _e('Action', 'ARForms-Stripe'); ?></th>
    </tr> 
  </thead>
  </tbody>        
<?php
$forms = $wpdb->get_results( "SELECT * FROM ".$wpdb->prefix."arf_stripe_forms ORDER BY id DESC" );	    
if( count($forms) > 0 ){
foreach( $forms as $form ){ 
	$options = maybe_unserialize($form->options);
	?>     
    <tr>
        <td class="center"><input id="cb-item-action-<?php echo $form->id;?>" class="chkstanard" type="checkbox" value="<?php echo $form->id;?>" name="item-action[]"><label for="cb-item-action-<?php echo $form->id;?>"><span></span></label></td>
        <td><?php echo $form->form_id; ?></td>                
        <td class="form_name"><a class="row-title" href="<?php echo wp_nonce_url( "?page=ARForms-Stripe&arfaction=edit&id={$form->id}" ); ?>"><?php
		$form_name = $wpdb->get_results( $wpdb->prepare("SELECT name FROM ".$wpdb->prefix."arf_forms WHERE id = %d", $form->form_id) );	
		$form_name = $form_name[0];
		echo $form_name->name; ?></a></td>
        <td class="center"><?php 
		$record_count = $wpdb->get_results( $wpdb->prepare("SELECT count(*) AS record_count FROM ".$wpdb->prefix."arf_stripe_order WHERE form_id = %d", $form->form_id) );	
		$record_count = $record_count[0];
		echo "<a href='" . wp_nonce_url( "?page=ARForms-Stripe-order&form={$form->form_id}" ) . "'>".$record_count->record_count."</a>"; ?></td>
        <td class="center"><?php
		$total_amount = $wpdb->get_results( $wpdb->prepare("SELECT SUM(mc_gross) AS total_amount FROM ".$wpdb->prefix."arf_stripe_order WHERE form_id = %d", $form->form_id) );	
		$total_amount = $total_amount[0];
		echo ((isset($total_amount->total_amount)) ? number_format((float)$total_amount->total_amount, 2) : '0.00').' '.$options['currency']; ?></td>
        <td><?php echo date(get_option('date_format'), strtotime($form->created_at)); ?></td>                
        <td><?php 
				$edit_link = "?page=ARForms-Stripe&arfaction=edit&id={$form->id}";
					
				   echo "<a href='" .wp_nonce_url( $edit_link ). "'><img src='".ARFIMAGESURL."/edit-icon22.png' onmouseover=\"this.src='".ARFIMAGESURL."/edit-icon_hover22.png';\" class=' arfhelptip' title='".__('Edit Configuration','ARForms-Stripe')."' onmouseout=\"this.src='".ARFIMAGESURL."/edit-icon22.png';\" /></a>";
				   
				   echo "<a href='" . wp_nonce_url( "?page=ARForms-Stripe-order&form={$form->form_id}" ) . "'><img src='".ARF_STRIPE_URL."/images/trans.png' title='".__('Transaction','ARForms-Stripe')."' class=' arfhelptip' onmouseover=\"this.src='".ARF_STRIPE_URL."/images/trans_hover.png';\" onmouseout=\"this.src='".ARF_STRIPE_URL."/images/trans.png';\" /></a>";
                                                            
                   echo "<img src='".ARFIMAGESURL."/delete_icon223.png' title='".__("Delete","ARForms-Stripe")."' class=' arfhelptip' onmouseover=\"this.src='".ARFIMAGESURL."/delete_icon223_hover.png';\" onmouseout=\"this.src='".ARFIMAGESURL."/delete_icon223.png';\" onclick=\"arf_ChangeID({$form->id})\" data-toggle='arfmodal' href='#delete_form_message' style='cursor:pointer'/></a>";

         ?></td>
    </tr>
<?php } } ?>
    </tbody>     
</table>
    <div class="clear"></div>
    <input type="hidden" name="show_hide_columns" id="show_hide_columns" value="<?php _e('Show / Hide columns','ARForms-Stripe');?>"/>
    <input type="hidden" name="search_grid" id="search_grid" value="<?php _e('Search','ARForms-Stripe');?>"/>
    <input type="hidden" name="entries_grid" id="entries_grid" value="<?php _e('entries','ARForms-Stripe');?>"/>
    <input type="hidden" name="show_grid" id="show_grid" value="<?php _e('Show','ARForms-Stripe');?>"/>
    <input type="hidden" name="showing_grid" id="showing_grid" value="<?php _e('Showing','ARForms-Stripe');?>"/>
    <input type="hidden" name="to_grid" id="to_grid" value="<?php _e('to','ARForms-Stripe');?>"/>
    <input type="hidden" name="of_grid" id="of_grid" value="<?php _e('of','ARForms-Stripe');?>"/>
    <input type="hidden" name="no_match_record_grid" id="no_match_record_grid" value="<?php _e('No matching records found','ARForms-Stripe');?>"/>
    <input type="hidden" name="no_record_grid" id="no_record_grid" value="<?php _e('No data available in table','ARForms-Stripe');?>"/>
    <input type="hidden" name="filter_grid" id="filter_grid" value="<?php _e('filtered from','ARForms-Stripe');?>"/>
    <input type="hidden" name="totalwd_grid" id="totalwd_grid" value="<?php _e('total','ARForms-Stripe');?>"/>
    
    <div class="alignleft actions2">
            <?php 
            $two = '2';
            echo "<div class='sltstandard'><select style='width:120px;' data-width='120px' name='action$two'>\n";
            echo "<option value='-1' selected='selected'>" . __('Bulk Actions','ARForms-Stripe') . "</option>\n";
    
            foreach ( $actions as $name => $title ) {
                $class = 'edit' == $name ? ' class="hide-if-no-js"' : '';
    
                echo "\t<option value='$name'$class>$title</option>\n";
            }
    
            echo "</select></div>\n";
            
            echo '<input type="submit" id="doaction'.$two.'" class="arfbulkbtn arfemailaddbtn" value="'.__('Apply','ARForms-Stripe').'" />'; 
            echo "\n";
            
            ?>
    </div>
    <div class="footer_grid"></div>

    <?php		
		
	}
		
	function edit_form_v3(){
        global $wpdb, $arfform, $arf_stripe, $armainhelper, $arformcontroller,$arfieldhelper,$MdlDb,$is_version_compatible;
		
		if( isset($_REQUEST['save_arf_stripe']) ){
		
			$id = $_REQUEST['id'];		
			if( isset($id) and $id != '' and $_POST['arfaction'] == 'edit' ) {
				
				$form_data = $arfform->getOne($_REQUEST['form_id']);
					
				$new_values['form_name'] = $form_data->name; 
										
				$options['stripe_api'] = esc_attr(isset($_REQUEST['arf_stripe_api'])?$_REQUEST['arf_stripe_api']:'');
				
				$options['stripe_mode'] = esc_attr($_REQUEST['arf_stripe_mode']);
				
				$options['test_secret_key'] = esc_attr($_REQUEST['arf_test_secret_key']);
				
				$options['test_publishable_key'] = esc_attr($_REQUEST['arf_test_publishable_key']);
				
				$options['live_secret_key'] = esc_attr($_REQUEST['arf_live_secret_key']);
				
				$options['live_publishable_key'] = esc_attr($_REQUEST['arf_live_publishable_key']);
								
				$options['notification'] = isset( $_REQUEST['arf_stripe_notification'] ) ? 1 : 0;

				$options['user_notification'] = isset( $_REQUEST['arf_stripe_user_notification'] ) ? 1 : 0;

				$options['email_content'] = esc_attr(isset($_REQUEST['email_content'])?$_REQUEST['email_content']:'');
				
				$options['title'] = esc_attr($_REQUEST['arf_stripe_title']);
				
				$options['currency'] = esc_attr($_REQUEST['arf_stripe_currency']);
					
				$options['first_name'] = esc_attr($_REQUEST['arf_first_name']);
				
				$options['last_name'] = esc_attr($_REQUEST['arf_last_name']);
				
				$options['email'] = esc_attr($_REQUEST['arf_email']);
					
				$options['state'] = esc_attr($_REQUEST['arf_state']);
				
				$options['address'] = esc_attr($_REQUEST['arf_address']);
				
				$options['address_2'] = esc_attr($_REQUEST['arf_address_2']);
				
				$options['city'] = esc_attr($_REQUEST['arf_city']);
				
				$options['zip'] = esc_attr($_REQUEST['arf_zip']);
				
				$options['country'] = esc_attr($_REQUEST['arf_country']);
				
				$options['amount'] = esc_attr($_REQUEST['arf_amount']);

				$options['card_holder_name'] = esc_attr(isset($_REQUEST['arf_card_holder_name'])?$_REQUEST['arf_card_holder_name']:'');
				
				$options['card_number'] = esc_attr($_REQUEST['arf_card_number']);
					
				$options['exp_month'] = esc_attr($_REQUEST['arf_exp_month']);
					
				$options['exp_year'] = esc_attr($_REQUEST['arf_exp_year']);
					
				$options['cvc'] = esc_attr($_REQUEST['arf_cvc']);
					
				$options['payment_type'] = esc_attr($_REQUEST['arf_stripe_payment_type']);

				$options['user_email_content'] = esc_attr($_REQUEST['user_email_content']);
				
				$options['shipping_info'] = (isset($_REQUEST['shipping_info'])) ? esc_attr($_REQUEST['shipping_info']) : 0;
				
				$options['stripe_condition'] = (isset($_REQUEST['arf_stripe_condition'])) ? esc_attr($_REQUEST['arf_stripe_condition']) : 0;
				
				
				
				$options['arf_payment_type'] = esc_attr($_REQUEST['arf_payment_type']);
				
				
				$options['arf_multiple_product_service_type'] = (isset($_REQUEST['arf_multiple_product_service_type'])) ? esc_attr($_REQUEST['arf_multiple_product_service_type']) : 0;				
				$options['arf_cl_field_multiple_product_service_type'] = esc_attr($_REQUEST['arf_cl_field_multiple_product_service_type']);
				$options['arf_cl_op_multiple_product_service_type'] = esc_attr($_REQUEST['arf_cl_op_multiple_product_service_type']);
				$options['cl_rule_value_multiple_product_service_type'] = esc_attr($_REQUEST['cl_rule_value_multiple_product_service_type']);
				
				$options['arf_multiple_product_service_amount'] = esc_attr($_REQUEST['arf_multiple_product_service_amount']);
		
		
				
				$options['arf_multiple_subscription_type'] = (isset($_REQUEST['arf_multiple_subscription_type'])) ? esc_attr($_REQUEST['arf_multiple_subscription_type']) : 0;
						  
				$options['arf_cl_field_multiple_subscription_type'] = esc_attr($_REQUEST['arf_cl_field_multiple_subscription_type']);
				$options['arf_cl_op_multiple_subscription_type'] = esc_attr($_REQUEST['arf_cl_op_multiple_subscription_type']);
				$options['cl_rule_value_multiple_subscription_type'] = esc_attr($_REQUEST['cl_rule_value_multiple_subscription_type']);
				
				$options['arf_multiple_subscription_amount'] = esc_attr(isset($_REQUEST['arf_multiple_subscription_amount'])?$_REQUEST['arf_multiple_subscription_amount']:'');
				
				


				$multiple_subscription_conditional_logic_rules = array();
		
				$rule_array = isset($_REQUEST['rule_array_multiple_subscription']) ? $_REQUEST['rule_array_multiple_subscription'] : array();
				
				
				if( count($rule_array) > 0 ) {
				    $i = 1;
				    foreach($rule_array as $v){

				    $arf_stripe_multipayment_plan_id  = @stripslashes_deep($_REQUEST['arf_stripe_multipayment_plan_id_'.$v]);
				    $arf_multiple_subscription_amount = @stripslashes_deep($_REQUEST['arf_multiple_subscription_amount_'.$v]);
				    $arf_cl_op_multiple_subscription_duration_type = @stripslashes_deep($_REQUEST['arf_cl_op_multiple_subscription_duration_type_'.$v]);
				    $cl_rule_value_multiple_subscription_duration_type = @stripslashes_deep($_REQUEST['cl_rule_value_multiple_subscription_duration_type_'.$v]);

				    $multiple_subscription_conditional_logic_rules[$i]= array(
					'id' => $i, 
					'arf_stripe_multipayment_plan_id'  => $arf_stripe_multipayment_plan_id,
					'arf_multiple_subscription_amount' =>$arf_multiple_subscription_amount,
					'operator' => $arf_cl_op_multiple_subscription_duration_type,
					'value' => $cl_rule_value_multiple_subscription_duration_type,
					);													 
				    $i++;
				    }
				
				}
					
				
					
				$options['multiple_subscription_conditional_logic'] = array('rules' => $multiple_subscription_conditional_logic_rules);
											
				
				
				
					
				$conditional_logic_rules = array();
		
				$rule_array = isset($_REQUEST['rule_array_stripe'])? $_REQUEST['rule_array_stripe'] : array();
				
				if( count($rule_array) > 0 ) {
				    $i = 1;
				    foreach($rule_array as $v){

					$conditional_logic_field 	  = @stripslashes_deep($_REQUEST['arf_cl_field_stripe_'.$v]);
					$conditional_logic_field_type = $arfieldhelper->get_field_type($conditional_logic_field);
					$conditional_logic_op 	  = @stripslashes_deep($_REQUEST['arf_cl_op_stripe_'.$v]);
					$conditional_logic_value 	  = @stripslashes_deep($_REQUEST['cl_rule_value_stripe_'.$v]);

					    $conditional_logic_rules[$i]= array(
						'id'		=> $i, 
						'field_id' 	=> $conditional_logic_field,
						'field_type'    => $conditional_logic_field_type, 
						'operator' 	=> $conditional_logic_op,
						'value' 	=> $conditional_logic_value,
					    );													 					    
					 $i++;
					}
				    }

					$options['conditional_logic'] = array(
					'if_cond'	=> esc_attr(isset($_REQUEST['conditional_logic_if_cond_stripe'])?$_REQUEST['conditional_logic_if_cond_stripe']:''),
					'rules'		=> $conditional_logic_rules,
				    );
				
				$options['stripe_plan_id'] = esc_attr($_REQUEST['arf_stripe_plan_id']);
								
				$options['stripe_recurring_time'] = (isset($_REQUEST['arf_stripe_recurring_time'])) ? esc_attr($_REQUEST['arf_stripe_recurring_time']) : "1";

				$options['invalid_card'] = esc_attr($_REQUEST['arf_invalid_card']);
					
				$options['payment_failure'] = esc_attr($_REQUEST['arf_payment_failure']);
				
				$options['enable_debug_mode'] = isset($_REQUEST['enable_debug_mode'])?esc_attr($_REQUEST['enable_debug_mode']):'';
				
				$options = apply_filters('arf_trim_values',$options);
		
				$new_values['options'] = maybe_serialize( $options );
				
				$res = $wpdb->update($arf_stripe->db_stripe_forms, $new_values, array('id' => $id)); 

				$form_arf_mapped_addon = maybe_unserialize($form_data->arf_mapped_addon);
                if(isset($form_arf_mapped_addon['arf_mapped_addon']) && !empty($form_arf_mapped_addon['arf_mapped_addon']))
                {
                    if(!in_array('stripe',$form_arf_mapped_addon['arf_mapped_addon']))
                    {
                        array_push($form_arf_mapped_addon['arf_mapped_addon'],'stripe');
                    }
                } else {
                	$form_arf_mapped_addon = array();
                    $form_arf_mapped_addon['arf_mapped_addon'] = array('stripe');
                }            
                $new_form_arf_mapped_addon = maybe_serialize($form_arf_mapped_addon);    
                $wpdb->update($MdlDb->forms, array('arf_mapped_addon'=>$new_form_arf_mapped_addon), array('id' => $form_data->id)); 
					
				$values = array();
				
				$values = $new_values;
				
				$values['form_id'] = esc_attr($_REQUEST['form_id']);
				
				$values['form_name'] = esc_attr($_REQUEST['form_name']);
				
				$values['id'] = $id;
				
				unset($values['options']);
				
				foreach( $options as $option_key => $option_val ){
					$values[$option_key] = $option_val;
				}
				
				$arfaction = 'edit';
				
				$message = __('Configuration saved successfully.', 'ARForms-Stripe');
				
				if($is_version_compatible){
				    require(ARF_STRIPE_DIR.'/core/edit_3.0.php');			
				}else{
				    require(ARF_STRIPE_DIR.'/core/edit.php');			
				}
			} else {
				
				$new_form_id = $_REQUEST['arf_stripe_form'];
				
				if( isset($new_form_id) and $new_form_id != '' ) {
					$form_data = $arfform->getOne($new_form_id);
					
					$new_values['form_id'] = $new_form_id;
					
					$new_values['form_name'] = $form_data->name; 
					
					$options['stripe_api'] = esc_attr(isset($_REQUEST['arf_stripe_api'])?$_REQUEST['arf_stripe_api']:'');
					
					$options['stripe_mode'] = esc_attr(isset($_REQUEST['arf_stripe_mode'])? $_REQUEST['arf_stripe_mode']:'');
					
					$options['test_secret_key'] = esc_attr(isset($_REQUEST['arf_test_secret_key'])?$_REQUEST['arf_test_secret_key']:'');
				
					$options['test_publishable_key'] = esc_attr(isset($_REQUEST['arf_test_publishable_key'])?$_REQUEST['arf_test_publishable_key']:'');
				
					$options['live_secret_key'] = esc_attr(isset($_REQUEST['arf_live_secret_key'])?$_REQUEST['arf_live_secret_key']:'');
					
					$options['live_publishable_key'] = esc_attr(isset($_REQUEST['arf_live_publishable_key'])?$_REQUEST['arf_live_publishable_key']:'');
														
					$options['notification'] = isset( $_REQUEST['arf_stripe_notification'] ) ? 1 : 0;

					$options['user_notification'] = isset( $_REQUEST['arf_stripe_user_notification'] ) ? 1 : 0;

					$options['user_email_content'] = esc_attr(isset($_REQUEST['user_email_content'])?$_REQUEST['user_email_content']:'');
					
					$options['title'] = esc_attr($_REQUEST['arf_stripe_title']);
					
					$options['currency'] = esc_attr($_REQUEST['arf_stripe_currency']);
					
					$options['first_name'] = esc_attr($_REQUEST['arf_first_name']);
					
					$options['last_name'] = esc_attr($_REQUEST['arf_last_name']);
					
					$options['email'] = esc_attr($_REQUEST['arf_email']);
					
					$options['state'] = esc_attr($_REQUEST['arf_state']);
					
					$options['address'] = esc_attr($_REQUEST['arf_address']);
					
					$options['address_2'] = esc_attr($_REQUEST['arf_address_2']);
					
					$options['city'] = esc_attr($_REQUEST['arf_city']);
					
					$options['zip'] = esc_attr($_REQUEST['arf_zip']);
					
					$options['country'] = esc_attr($_REQUEST['arf_country']);
					
					$options['amount'] = esc_attr($_REQUEST['arf_amount']);
					
					$options['card_holder_name'] = esc_attr(isset($_REQUEST['arf_card_holder_name'])?$_REQUEST['arf_card_holder_name']:'');

					$options['card_number'] = esc_attr($_REQUEST['arf_card_number']);
					
					$options['exp_month'] = esc_attr($_REQUEST['arf_exp_month']);
					
					$options['exp_year'] = esc_attr($_REQUEST['arf_exp_year']);
					
					$options['cvc'] = esc_attr($_REQUEST['arf_cvc']);
					
					$options['payment_type'] = esc_attr($_REQUEST['arf_stripe_payment_type']);
					
					$options['email_content'] = esc_attr($_REQUEST['email_content']);

					$options['shipping_info'] = (isset($_REQUEST['shipping_info'])) ? esc_attr($_REQUEST['shipping_info']) : 0;
					
					$options['stripe_condition'] = (isset($_REQUEST['arf_stripe_condition'])) ? esc_attr($_REQUEST['arf_stripe_condition']) : 0;
					
					
					
					$options['arf_payment_type'] = esc_attr($_REQUEST['arf_payment_type']);
					
					
					$options['arf_multiple_product_service_type'] = (isset($_REQUEST['arf_multiple_product_service_type'])) ? esc_attr($_REQUEST['arf_multiple_product_service_type']) : 0;				
					$options['arf_cl_field_multiple_product_service_type'] = esc_attr($_REQUEST['arf_cl_field_multiple_product_service_type']);
					$options['arf_cl_op_multiple_product_service_type'] = esc_attr($_REQUEST['arf_cl_op_multiple_product_service_type']);
					$options['cl_rule_value_multiple_product_service_type'] = esc_attr($_REQUEST['cl_rule_value_multiple_product_service_type']);
					
					$options['arf_multiple_product_service_amount'] = esc_attr($_REQUEST['arf_multiple_product_service_amount']);
			
			
					
					$options['arf_multiple_subscription_type'] = (isset($_REQUEST['arf_multiple_subscription_type'])) ? esc_attr($_REQUEST['arf_multiple_subscription_type']) : 0;
							  
					$options['arf_cl_field_multiple_subscription_type'] = esc_attr($_REQUEST['arf_cl_field_multiple_subscription_type']);
					$options['arf_cl_op_multiple_subscription_type'] = esc_attr($_REQUEST['arf_cl_op_multiple_subscription_type']);
					$options['cl_rule_value_multiple_subscription_type'] = esc_attr($_REQUEST['cl_rule_value_multiple_subscription_type']);
					
					$options['arf_multiple_subscription_amount'] = esc_attr(isset($_REQUEST['arf_multiple_subscription_amount'])?$_REQUEST['arf_multiple_subscription_amount']:'');
				
					$multiple_subscription_conditional_logic_rules = array();
			
					$rule_array = isset($_REQUEST['rule_array_multiple_subscription'])?$_REQUEST['rule_array_multiple_subscription'] : array();
					
					
					if( count($rule_array) > 0 ) {
					    $i = 1;
					    foreach($rule_array as $v){

					    $arf_stripe_multipayment_plan_id = @stripslashes_deep($_REQUEST['arf_stripe_multipayment_plan_id_'.$v]);
					    $arf_multiple_subscription_amount= @stripslashes_deep($_REQUEST['arf_multiple_subscription_amount_'.$v]);

					    $arf_cl_op_multiple_subscription_duration_type= @stripslashes_deep($_REQUEST['arf_cl_op_multiple_subscription_duration_type_'.$v]);
					    $cl_rule_value_multiple_subscription_duration_type = @stripslashes_deep($_REQUEST['cl_rule_value_multiple_subscription_duration_type_'.$v]);



					    $multiple_subscription_conditional_logic_rules[$i]= array(
						'id' => $i, 
						'arf_stripe_multipayment_plan_id' => $arf_stripe_multipayment_plan_id,
						'arf_multiple_subscription_amount' =>$arf_multiple_subscription_amount,
						'operator' 	=> $arf_cl_op_multiple_subscription_duration_type,
						'value' 	=> $cl_rule_value_multiple_subscription_duration_type,
						);													 
					    $i++;
					    }
					}
						
					$options['multiple_subscription_conditional_logic'] = array('rules' => $multiple_subscription_conditional_logic_rules);
					
					
					
					$conditional_logic_rules = array();
			
					$rule_array = isset($_REQUEST['rule_array_stripe'])?$_REQUEST['rule_array_stripe'] : array();
					
					if( count($rule_array) > 0 ) {
						$i = 1;
						foreach($rule_array as $v){
							
							$conditional_logic_field 		= @stripslashes_deep($_REQUEST['arf_cl_field_stripe_'.$v]);
                            $conditional_logic_field_type = $arfieldhelper->get_field_type($conditional_logic_field);
							$conditional_logic_op 			= @stripslashes_deep($_REQUEST['arf_cl_op_stripe_'.$v]);
							$conditional_logic_value 		= @stripslashes_deep($_REQUEST['cl_rule_value_stripe_'.$v]);
							
							$conditional_logic_rules[$i]= array(
															'id' => $i, 
															'field_id' 	=> $conditional_logic_field,
															'field_type'=> $conditional_logic_field_type, 
															'operator' 	=> $conditional_logic_op,
															'value' 	=> $conditional_logic_value,
															);													 
						$i++;
						}
					
					}
					
					$options['conditional_logic'] = array(
													'if_cond'	=> esc_attr(isset($_REQUEST['conditional_logic_if_cond_stripe'])?$_REQUEST['conditional_logic_if_cond_stripe']:''),
													'rules'		=> $conditional_logic_rules,
												);
					
					$options['stripe_plan_id'] = esc_attr($_REQUEST['arf_stripe_plan_id']);
								
					$options['stripe_recurring_time'] = (isset($_REQUEST['arf_stripe_recurring_time'])) ? esc_attr($_REQUEST['arf_stripe_recurring_time']) : "1";
					$options['invalid_card'] = esc_attr($_REQUEST['arf_invalid_card']);
					
					$options['payment_failure'] = esc_attr($_REQUEST['arf_payment_failure']);
				
					$options = apply_filters('arf_trim_values',$options);
		
					$new_values['options'] = maybe_serialize( $options );
					
					$new_values['created_at'] = current_time('mysql');
					
					$id = $wpdb->insert($arf_stripe->db_stripe_forms, $new_values); 

					$form_arf_mapped_addon = maybe_unserialize($form_data->arf_mapped_addon);
	                if(isset($form_arf_mapped_addon['arf_mapped_addon']) && !empty($form_arf_mapped_addon['arf_mapped_addon']))
	                {
	                    if(!in_array('stripe',$form_arf_mapped_addon['arf_mapped_addon']))
	                    {
	                        array_push($form_arf_mapped_addon['arf_mapped_addon'],'stripe');
	                    }
	                } else {
	                	$form_arf_mapped_addon = array();
	                    $form_arf_mapped_addon['arf_mapped_addon'] = array('stripe');
	                }            
	                $new_form_arf_mapped_addon = maybe_serialize($form_arf_mapped_addon);    
	                $wpdb->update($MdlDb->forms, array('arf_mapped_addon'=>$new_form_arf_mapped_addon), array('id' => $form_data->id));
					
					$id = $wpdb->insert_id;
						
					$values = array();
					
					$values = $new_values;
					
					$values['id'] = $id;		
					
					unset($values['options']);
					
					foreach( $options as $option_key => $option_val ){
						$values[$option_key] = $option_val;
					}
					
					$arfaction = 'edit';
					
					$message = __('Configuration saved successfully.', 'ARForms-Stripe');
					
					if($is_version_compatible){
					    require(ARF_STRIPE_DIR.'/core/edit_3.0.php');			
					}else{
					    require(ARF_STRIPE_DIR.'/core/edit.php');			
					}			
				} 
			}
		
		} else {
			
			if( $_REQUEST['arfaction'] == 'edit' and isset($_REQUEST['id']) and $_REQUEST['id'] != '' ){

				$form_data = $wpdb->get_results( $wpdb->prepare("SELECT * FROM ".$arf_stripe->db_stripe_forms." WHERE id = %d", $_REQUEST['id']) );
				
				if( count($form_data) > 0 ){
					$form_data = $form_data[0];
					
					$options = maybe_unserialize( $form_data->options );
					
					$values = array();
					
					$values['id'] = $form_data->id;		
					$values['form_id'] = $form_data->form_id;			
					$values['form_name'] = $form_data->form_name; 				
					
					if( count($options) > 0 ){
						foreach( $options as $option_key => $option_val ){
							$values[$option_key] = $option_val;
						}
					}
					
					$form_data_new = $arfform->getOne($form_data->form_id);
					
					$form_options = maybe_unserialize($form_data_new->options);			


					
					$arfaction = 'edit';
					
					if($is_version_compatible){
					    require(ARF_STRIPE_DIR.'/core/edit_3.0.php');			
					}else{
					    require(ARF_STRIPE_DIR.'/core/edit.php');			
					}
				} else {
					
                        echo '<script data-cfasync="false" type="text/javascript">location.href="' . admin_url('admin.php?page=ARForms-Stripe') . '";</script>';
				}
			} else {
				$values['id'] = '';		
				$values['form_id'] = '';			
				$values['form_name'] = ''; 				
				$values['stripe_api'] = '';				
				$values['stripe_mode'] = '1';				
				$values['continue_label'] = '';				
				$values['cancel_url'] = '';
				$values['title'] = '';	
				$values['currency'] = '';	
				$values['notification'] = 0;
				$values['user_notification'] = 0;
				$values['first_name'] = '';
				$values['last_name'] = '';				
				$values['email'] = '';
				$values['address'] = '';
				$values['address_2'] = '';
				$values['city'] = '';
				$values['state'] = '';
				$values['zip'] = '';
				$values['country'] = '';
				$values['amount'] = '';
				$values['card_holder_name'] = '';
				$values['card_number'] = '';
				$values['exp_month'] = '';
				$values['exp_year'] = '';
				$values['cvc'] = '';		
				$values['payment_type'] = 'product_service';
                $values['email_content'] = $this->defalut_email_content();
                $values['user_email_content'] = $this->user_defalut_email_content();
				$values['stripe_plan_id'] = '';							
				$values['stripe_recurring_time'] = '';
				$values['invalid_card'] = __('Please enter correct card details.', 'ARForms-Stripe');
				$values['payment_failure'] = __('Sorry something went wrong while processing payment.', 'ARForms-Stripe');				  $values['enable_debug_mode'] = '';
				$values['shipping_info'] = '0'; 
				
				$arfaction = 'new';
				
				if($is_version_compatible){
				    require(ARF_STRIPE_DIR.'/core/edit_3.0.php');			
				}else{
				    require(ARF_STRIPE_DIR.'/core/edit.php');			
				}
			}
			
		}
			
	}
	
	function edit_form(){
        global $wpdb, $arfform, $arf_stripe, $armainhelper, $arformcontroller,$arfieldhelper;
		
		if( isset($_REQUEST['save_arf_stripe']) ){
		
			$id = $_REQUEST['id'];		
			if( isset($id) and $id != '' and $_POST['arfaction'] == 'edit' ) {
				
				
				$arf_form_chk = $wpdb->get_results( $wpdb->prepare("SELECT id FROM ".$wpdb->prefix."arf_forms WHERE id = %d", $_REQUEST['form_id']) );
				$form_chk = $wpdb->get_results( $wpdb->prepare("SELECT id FROM ".$wpdb->prefix."arf_stripe_forms WHERE id = %d", $id) );
				if( count($arf_form_chk) == 0 || count($form_chk) == 0 ) { 
                        echo '<script data-cfasync="false" type="text/javascript" language="javascript">location.href="' . admin_url('admin.php?page=ARForms-Stripe&err=1') . '";</script>';
				}
			
				$form_data = $arfform->getOne($_REQUEST['form_id']);
					
				$new_values['form_name'] = $form_data->name; 
										
				$options['stripe_api'] =  isset($_REQUEST['arf_stripe_api'])?esc_attr($_REQUEST['arf_stripe_api']):'';
				
				$options['stripe_mode'] = isset($_REQUEST['arf_stripe_mode'])? esc_attr($_REQUEST['arf_stripe_mode']):'';
				
				$options['test_secret_key'] = isset($_REQUEST['arf_test_secret_key'])?esc_attr($_REQUEST['arf_test_secret_key']):'';
				
				$options['test_publishable_key'] = isset($_REQUEST['arf_test_publishable_key'])?esc_attr($_REQUEST['arf_test_publishable_key']):'';
				
				$options['live_secret_key'] = isset($_REQUEST['arf_live_secret_key'])?esc_attr($_REQUEST['arf_live_secret_key']):'';
				
				$options['live_publishable_key'] = isset($_REQUEST['arf_live_publishable_key'])?esc_attr($_REQUEST['arf_live_publishable_key']):'';
								
				$options['notification'] = isset($_REQUEST['arf_stripe_notification'] ) ? 1 : 0;
				
				$options['title'] = isset($_REQUEST['arf_stripe_title'])?esc_attr($_REQUEST['arf_stripe_title']):'';
				
				$options['currency'] = isset($_REQUEST['arf_stripe_currency'])?esc_attr($_REQUEST['arf_stripe_currency']):'';
					
				$options['first_name'] = isset($_REQUEST['arf_first_name'])?esc_attr($_REQUEST['arf_first_name']):'';
				
				$options['last_name'] = isset($_REQUEST['arf_last_name'])?esc_attr($_REQUEST['arf_last_name']):'';
				
				$options['email'] = isset($_REQUEST['arf_email'])?esc_attr($_REQUEST['arf_email']):'';
					
				$options['state'] = isset($_REQUEST['arf_state'])?esc_attr($_REQUEST['arf_state']):'';
				
				$options['address'] = isset($_REQUEST['arf_address'])?esc_attr($_REQUEST['arf_address']):'';
				
				$options['address_2'] = isset($_REQUEST['arf_address_2'])?esc_attr($_REQUEST['arf_address_2']):'';
				
				$options['city'] = isset($_REQUEST['arf_city'])?esc_attr($_REQUEST['arf_city']):'';
				
				$options['zip'] = isset($_REQUEST['arf_zip'])?esc_attr($_REQUEST['arf_zip']):'';
				
				$options['country'] = isset($_REQUEST['arf_country'])?esc_attr($_REQUEST['arf_country']):'';
				
				$options['amount'] = isset($_REQUEST['arf_amount'])?esc_attr($_REQUEST['arf_amount']):'';

				$options['card_holder_name'] = esc_attr(isset($_REQUEST['arf_card_holder_name'])?$_REQUEST['arf_card_holder_name']:'');
				
				$options['card_number'] = isset($_REQUEST['arf_card_number'])?esc_attr($_REQUEST['arf_card_number']):'';
					
				$options['exp_month'] = isset($_REQUEST['arf_exp_month'])?esc_attr($_REQUEST['arf_exp_month']):'';
					
				$options['exp_year'] = isset($_REQUEST['arf_exp_year'])?esc_attr($_REQUEST['arf_exp_year']):'';
					
				$options['cvc'] = isset($_REQUEST['arf_cvc'])?esc_attr($_REQUEST['arf_cvc']):'';
					
				$options['payment_type'] = isset($_REQUEST['arf_stripe_payment_type'])?esc_attr($_REQUEST['arf_stripe_payment_type']):'';
				
				$options['email_content'] = isset($_REQUEST['email_content'])?esc_attr($_REQUEST['email_content']):'';
				
				$options['shipping_info'] = (isset($_REQUEST['shipping_info'])) ? esc_attr($_REQUEST['shipping_info']) : 0;
				
				$options['stripe_condition'] = (isset($_REQUEST['arf_stripe_condition'])) ? esc_attr($_REQUEST['arf_stripe_condition']) : 0;
				
				
				
				$options['arf_payment_type'] = esc_attr($_REQUEST['arf_payment_type']);
				
				
				$options['arf_multiple_product_service_type'] = (isset($_REQUEST['arf_multiple_product_service_type'])) ? esc_attr($_REQUEST['arf_multiple_product_service_type']) : 0;				
				$options['arf_cl_field_multiple_product_service_type'] = isset($_REQUEST['arf_cl_field_multiple_product_service_type'])?esc_attr($_REQUEST['arf_cl_field_multiple_product_service_type']):'';

				$options['arf_cl_op_multiple_product_service_type'] = isset($_REQUEST['arf_cl_op_multiple_product_service_type'])?esc_attr($_REQUEST['arf_cl_op_multiple_product_service_type']):'';

				$options['cl_rule_value_multiple_product_service_type'] = isset($_REQUEST['cl_rule_value_multiple_product_service_type'])?esc_attr($_REQUEST['cl_rule_value_multiple_product_service_type']):'';
				
				$options['arf_multiple_product_service_amount'] = isset($_REQUEST['arf_multiple_product_service_amount'])?esc_attr($_REQUEST['arf_multiple_product_service_amount']):'';
		
		
				
				$options['arf_multiple_subscription_type'] = (isset($_REQUEST['arf_multiple_subscription_type'])) ? esc_attr($_REQUEST['arf_multiple_subscription_type']) : 0;
						  
				$options['arf_cl_field_multiple_subscription_type'] = isset($_REQUEST['arf_cl_field_multiple_subscription_type'])?esc_attr($_REQUEST['arf_cl_field_multiple_subscription_type']):'';

				$options['arf_cl_op_multiple_subscription_type'] = isset($_REQUEST['arf_cl_op_multiple_subscription_type'])?esc_attr($_REQUEST['arf_cl_op_multiple_subscription_type']):'';

				$options['cl_rule_value_multiple_subscription_type'] = isset($_REQUEST['cl_rule_value_multiple_subscription_type'])?esc_attr($_REQUEST['cl_rule_value_multiple_subscription_type']):'';
				
				$options['arf_multiple_subscription_amount'] = isset($_REQUEST['arf_multiple_subscription_amount'])?esc_attr($_REQUEST['arf_multiple_subscription_amount']):'';
				
			
				
				


				$multiple_subscription_conditional_logic_rules = array();
		
				$rule_array = isset($_REQUEST['rule_array_multiple_subscription']) ? $_REQUEST['rule_array_multiple_subscription'] : array();
				
				
				if( count($rule_array) > 0 ) {
					$i = 1;
					foreach($rule_array as $v){
						
						$arf_stripe_multipayment_plan_id 		= @stripslashes_deep($_REQUEST['arf_stripe_multipayment_plan_id_'.$v]);
						$arf_multiple_subscription_amount 		= @stripslashes_deep($_REQUEST['arf_multiple_subscription_amount_'.$v]);
						
						$arf_cl_op_multiple_subscription_duration_type 		= @stripslashes_deep($_REQUEST['arf_cl_op_multiple_subscription_duration_type_'.$v]);
						$cl_rule_value_multiple_subscription_duration_type 		= @stripslashes_deep($_REQUEST['cl_rule_value_multiple_subscription_duration_type_'.$v]);
						
						
						
						$multiple_subscription_conditional_logic_rules[$i]= array(
														'id' => $i, 
														'arf_stripe_multipayment_plan_id' 	=> $arf_stripe_multipayment_plan_id,
														'arf_multiple_subscription_amount' =>$arf_multiple_subscription_amount,
														
														'operator' 	=> $arf_cl_op_multiple_subscription_duration_type,
														'value' 	=> $cl_rule_value_multiple_subscription_duration_type,
														);													 
						$i++;
					}
				
				}
					
				
					
				$options['multiple_subscription_conditional_logic'] = array('rules' => $multiple_subscription_conditional_logic_rules);
											
				
				
				
					
				$conditional_logic_rules = array();
		
				$rule_array = isset($_REQUEST['rule_array_stripe']) ? $_REQUEST['rule_array_stripe'] : array();
				
				if( count($rule_array) > 0 ) {
					$i = 1;
					foreach($rule_array as $v){
						
						$conditional_logic_field 		= @stripslashes_deep($_REQUEST['arf_cl_field_stripe_'.$v]);
                        $conditional_logic_field_type = $arfieldhelper->get_field_type($conditional_logic_field);
						$conditional_logic_op 			= @stripslashes_deep($_REQUEST['arf_cl_op_stripe_'.$v]);
						$conditional_logic_value 		= @stripslashes_deep($_REQUEST['cl_rule_value_stripe_'.$v]);
						
						$conditional_logic_rules[$i]= array(
														'id' => $i, 
														'field_id' 	=> $conditional_logic_field,
														'field_type'=> $conditional_logic_field_type, 
														'operator' 	=> $conditional_logic_op,
														'value' 	=> $conditional_logic_value,
														);													 
					$i++;
					}
				
				}
				
				$options['conditional_logic'] = array(
												'if_cond'	=> (isset($_REQUEST['conditional_logic_if_cond_stripe'])?esc_attr($_REQUEST['conditional_logic_if_cond_stripe']):''),
												'rules'		=> $conditional_logic_rules,
											);
				
				$options['stripe_plan_id'] = esc_attr($_REQUEST['arf_stripe_plan_id']);
								
				$options['stripe_recurring_time'] = (isset($_REQUEST['arf_stripe_recurring_time'])) ? esc_attr($_REQUEST['arf_stripe_recurring_time']) : "1";
				$options['invalid_card'] = esc_attr($_REQUEST['arf_invalid_card']);
					
				$options['payment_failure'] = esc_attr($_REQUEST['arf_payment_failure']);
				
				$options = apply_filters('arf_trim_values',$options);
		
				$new_values['options'] = maybe_serialize( $options );
				
				$res = $wpdb->update($wpdb->prefix."arf_stripe_forms", $new_values, array('id' => $id)); 
					
				$values = array();
				
				$values = $new_values;
				
				$values['form_id'] = esc_attr($_REQUEST['form_id']);
				
				$values['form_name'] = esc_attr($_REQUEST['form_name']);
				
				$values['id'] = $id;
				
				unset($values['options']);
				
				foreach( $options as $option_key => $option_val ){
					$values[$option_key] = $option_val;
				}
				
				$arfaction = 'edit';
				
				$message = __('Configuration saved successfully.', 'ARForms-Stripe');
					
				require(ARF_STRIPE_DIR.'/core/edit.php');			
			} else {
				
				$new_form_id = $_REQUEST['arf_stripe_form'];
				
				if( isset($new_form_id) and $new_form_id != '' ) {
					$form_data = $arfform->getOne($new_form_id);
					
					$new_values['form_id'] = $new_form_id;
					
					$new_values['form_name'] = $form_data->name; 
					
					$options['stripe_api'] = esc_attr(isset($_REQUEST['arf_stripe_api'])?$_REQUEST['arf_stripe_api']:'');
					
					$options['stripe_mode'] = esc_attr(isset($_REQUEST['arf_stripe_mode'])? $_REQUEST['arf_stripe_mode']:'');
					
					$options['test_secret_key'] = esc_attr(isset($_REQUEST['arf_test_secret_key'])?$_REQUEST['arf_test_secret_key']:'');
				
					$options['test_publishable_key'] = esc_attr(isset($_REQUEST['arf_test_publishable_key'])?$_REQUEST['arf_test_publishable_key']:'');
				
					$options['live_secret_key'] = esc_attr(isset($_REQUEST['arf_live_secret_key'])?$_REQUEST['arf_live_secret_key']:'');
					
					$options['live_publishable_key'] = esc_attr(isset($_REQUEST['arf_live_publishable_key'])?$_REQUEST['arf_live_publishable_key']:'');
														
					$options['notification'] = isset( $_REQUEST['arf_stripe_notification'] ) ? 1 : 0;

					$options['user_notification'] = isset( $_REQUEST['arf_stripe_user_notification'] ) ? 1 : 0;
					$options['user_email_content'] = esc_attr(isset($_REQUEST['user_email_content'])?$_REQUEST['user_email_content']:'');
					
					$options['title'] = esc_attr($_REQUEST['arf_stripe_title']);
					
					$options['currency'] = esc_attr($_REQUEST['arf_stripe_currency']);
					
					$options['first_name'] = esc_attr($_REQUEST['arf_first_name']);
					
					$options['last_name'] = esc_attr($_REQUEST['arf_last_name']);
					
					$options['email'] = esc_attr($_REQUEST['arf_email']);
					
					$options['state'] = esc_attr($_REQUEST['arf_state']);
					
					$options['address'] = esc_attr($_REQUEST['arf_address']);
					
					$options['address_2'] = esc_attr($_REQUEST['arf_address_2']);
					
					$options['city'] = esc_attr($_REQUEST['arf_city']);
					
					$options['zip'] = esc_attr($_REQUEST['arf_zip']);
					
					$options['country'] = esc_attr($_REQUEST['arf_country']);
					
					$options['amount'] = esc_attr($_REQUEST['arf_amount']);
					
					$options['card_holder_name'] = esc_attr(isset($_REQUEST['arf_card_holder_name'])?$_REQUEST['arf_card_holder_name']:'');

					$options['card_number'] = esc_attr($_REQUEST['arf_card_number']);
					
					$options['exp_month'] = esc_attr($_REQUEST['arf_exp_month']);
					
					$options['exp_year'] = esc_attr($_REQUEST['arf_exp_year']);
					
					$options['cvc'] = esc_attr($_REQUEST['arf_cvc']);
					
					$options['payment_type'] = esc_attr($_REQUEST['arf_stripe_payment_type']);
					
					$options['email_content'] = esc_attr($_REQUEST['email_content']);

					$options['shipping_info'] = (isset($_REQUEST['shipping_info'])) ? esc_attr($_REQUEST['shipping_info']) : 0;
					
					$options['stripe_condition'] = (isset($_REQUEST['arf_stripe_condition'])) ? esc_attr($_REQUEST['arf_stripe_condition']) : 0;
					
					
					
					$options['arf_payment_type'] = esc_attr($_REQUEST['arf_payment_type']);
					
					
					$options['arf_multiple_product_service_type'] = (isset($_REQUEST['arf_multiple_product_service_type'])) ? esc_attr($_REQUEST['arf_multiple_product_service_type']) : 0;				
					$options['arf_cl_field_multiple_product_service_type'] = esc_attr($_REQUEST['arf_cl_field_multiple_product_service_type']);
					$options['arf_cl_op_multiple_product_service_type'] = esc_attr($_REQUEST['arf_cl_op_multiple_product_service_type']);
					$options['cl_rule_value_multiple_product_service_type'] = esc_attr($_REQUEST['cl_rule_value_multiple_product_service_type']);
					
					$options['arf_multiple_product_service_amount'] = esc_attr($_REQUEST['arf_multiple_product_service_amount']);
			
			
					
					$options['arf_multiple_subscription_type'] = (isset($_REQUEST['arf_multiple_subscription_type'])) ? esc_attr($_REQUEST['arf_multiple_subscription_type']) : 0;
							  
					$options['arf_cl_field_multiple_subscription_type'] = esc_attr($_REQUEST['arf_cl_field_multiple_subscription_type']);
					$options['arf_cl_op_multiple_subscription_type'] = esc_attr($_REQUEST['arf_cl_op_multiple_subscription_type']);
					$options['cl_rule_value_multiple_subscription_type'] = esc_attr($_REQUEST['cl_rule_value_multiple_subscription_type']);
					
					$options['arf_multiple_subscription_amount'] = (isset($_REQUEST['arf_multiple_subscription_amount']))?esc_attr($_REQUEST['arf_multiple_subscription_amount']):'';
				
					$multiple_subscription_conditional_logic_rules = array();
			
					$rule_array = isset($_REQUEST['rule_array_multiple_subscription']) ? $_REQUEST['rule_array_multiple_subscription'] : array();
					
					
					if( count($rule_array) > 0 ) {
						$i = 1;
						foreach($rule_array as $v){
							
							$arf_stripe_multipayment_plan_id 		= @stripslashes_deep($_REQUEST['arf_stripe_multipayment_plan_id_'.$v]);
							$arf_multiple_subscription_amount 		= @stripslashes_deep($_REQUEST['arf_multiple_subscription_amount_'.$v]);
							
							$arf_cl_op_multiple_subscription_duration_type 		= @stripslashes_deep($_REQUEST['arf_cl_op_multiple_subscription_duration_type_'.$v]);
							$cl_rule_value_multiple_subscription_duration_type 		= @stripslashes_deep($_REQUEST['cl_rule_value_multiple_subscription_duration_type_'.$v]);
							
							
							
							$multiple_subscription_conditional_logic_rules[$i]= array(
															'id' => $i, 
															'arf_stripe_multipayment_plan_id' 	=> $arf_stripe_multipayment_plan_id,
															'arf_multiple_subscription_amount' =>$arf_multiple_subscription_amount,

															'operator' 	=> $arf_cl_op_multiple_subscription_duration_type,
															'value' 	=> $cl_rule_value_multiple_subscription_duration_type,
															);													 
							$i++;
						}
					
					}
						
					$options['multiple_subscription_conditional_logic'] = array('rules' => $multiple_subscription_conditional_logic_rules);
					
					
					
					$conditional_logic_rules = array();
			
					$rule_array = isset($_REQUEST['rule_array_stripe']) ? $_REQUEST['rule_array_stripe'] : array();
					
					if( count($rule_array) > 0 ) {
						$i = 1;
						foreach($rule_array as $v){
							
							$conditional_logic_field 		= @stripslashes_deep($_REQUEST['arf_cl_field_stripe_'.$v]);
                            $conditional_logic_field_type = $arfieldhelper->get_field_type($conditional_logic_field);
							$conditional_logic_op 			= @stripslashes_deep($_REQUEST['arf_cl_op_stripe_'.$v]);
							$conditional_logic_value 		= @stripslashes_deep($_REQUEST['cl_rule_value_stripe_'.$v]);
							
							$conditional_logic_rules[$i]= array(
															'id' => $i, 
															'field_id' 	=> $conditional_logic_field,
															'field_type'=> $conditional_logic_field_type, 
															'operator' 	=> $conditional_logic_op,
															'value' 	=> $conditional_logic_value,
															);													 
						$i++;
						}
					
					}
					
					$options['conditional_logic'] = array(
													'if_cond'	=> esc_attr(isset($_REQUEST['conditional_logic_if_cond_stripe'])?$_REQUEST['conditional_logic_if_cond_stripe']:''),
													'rules'		=> $conditional_logic_rules,
												);
					
					$options['stripe_plan_id'] = esc_attr($_REQUEST['arf_stripe_plan_id']);
								
					$options['stripe_recurring_time'] = (isset($_REQUEST['arf_stripe_recurring_time'])) ? esc_attr($_REQUEST['arf_stripe_recurring_time']) : "1";
					$options['invalid_card'] = esc_attr($_REQUEST['arf_invalid_card']);
					
					$options['payment_failure'] = esc_attr($_REQUEST['arf_payment_failure']);
				
					$options = apply_filters('arf_trim_values',$options);
		
					$new_values['options'] = maybe_serialize( $options );
					
					$new_values['created_at'] = current_time('mysql');
					
					$id = $wpdb->insert($wpdb->prefix."arf_stripe_forms", $new_values); 
					
					$id = $wpdb->insert_id;
						
					$values = array();
					
					$values = $new_values;
					
					$values['id'] = $id;		
					
					unset($values['options']);
					
					foreach( $options as $option_key => $option_val ){
						$values[$option_key] = $option_val;
					}
					
					$arfaction = 'edit';
					
					$message = __('Configuration saved successfully.', 'ARForms-Stripe');
					
					require(ARF_STRIPE_DIR.'/core/edit.php');			
				} 
			}
		
		} else {
			
			if( $_REQUEST['arfaction'] == 'edit' and isset($_REQUEST['id']) and $_REQUEST['id'] != '' ){
				$form_data = $wpdb->get_results( $wpdb->prepare("SELECT * FROM ".$wpdb->prefix."arf_stripe_forms WHERE id = %d", $_REQUEST['id']) );
				
				if( count($form_data) > 0 ){
					$form_data = $form_data[0];
					
					$options = maybe_unserialize( $form_data->options );
					
					$values = array();
					
					$values['id'] = $form_data->id;		
					$values['form_id'] = $form_data->form_id;			
					$values['form_name'] = $form_data->form_name; 				
					
					if( count($options) > 0 ){
						foreach( $options as $option_key => $option_val ){
							$values[$option_key] = $option_val;
						}
					}
					
					$form_data_new = $arfform->getOne($form_data->form_id);
					
					$form_options = maybe_unserialize($form_data_new->options);					
					
					$arfaction = 'edit';
					
					require(ARF_STRIPE_DIR.'/core/edit.php');
				} else {
					
                        echo '<script data-cfasync="false" type="text/javascript">location.href="' . admin_url('admin.php?page=ARForms-Stripe') . '";</script>';
				}
			} else {
				$values['id'] = '';		
				$values['form_id'] = '';			
				$values['form_name'] = ''; 				
				$values['stripe_api'] = '';				
				$values['stripe_mode'] = '1';				
				$values['continue_label'] = '';				
				$values['cancel_url'] = '';
				$values['title'] = '';	
				$values['currency'] = '';	
				$values['notification'] = 0;
				$values['first_name'] = '';
				$values['last_name'] = '';				
				$values['email'] = '';
				$values['address'] = '';
				$values['address_2'] = '';
				$values['city'] = '';
				$values['state'] = '';
				$values['zip'] = '';
				$values['country'] = '';
				$values['amount'] = '';
				$values['card_holder_name'] = '';
				$values['card_number'] = '';
				$values['exp_month'] = '';
				$values['exp_year'] = '';
				$values['cvc'] = '';		
				$values['payment_type'] = 'product_service';
                $values['email_content'] = $this->defalut_email_content();
				$values['stripe_plan_id'] = '';							
				$values['stripe_recurring_time'] = '';
				$values['invalid_card'] = __('Please enter correct card details.', 'ARForms-Stripe');
				$values['payment_failure'] = __('Sorry something went wrong while processing payment.', 'ARForms-Stripe');				
				$values['shipping_info'] = '0'; 
				
				$arfaction = 'new';
				
				require(ARF_STRIPE_DIR.'/core/edit.php');
			}
			
		}
			
	}
	
	function field_dropdown($form_id, $name='', $class='', $default_value='', $drpdwn_width = '211px', $rule_i='',$field_array){
		
        global $arffield, $MdlDb, $armainhelper,$is_version_compatible,$arfieldhelper;
	$field_list = array();
	$drpdwn_width = ($drpdwn_width=='')?'211px':$drpdwn_width;
	
	$field_list = isset($field_array)?$field_array:array();
	$exclude = array('divider','captcha','break','file','like');
		
		if( $name == 'arf_amount' || $name == 'arf_multiple_product_service_amount' || $name == 'arf_multiple_subscription_amount_'.$rule_i ) {
		    ?>
		    <div class="sltstandard">
			<?php 
			global $armainhelper;
			$selected_list_id = "";
			$selected_list_label = __('Select Field', 'ARForms-Stripe');
			unset($responder_list_option);
			$responder_list_option = "";
			
			if (count($field_list) > 0) { //echo '<pre>';print_r($field_list);echo '</pre>';exit;
			    $cntr = 0;
			    foreach ($field_list as $field) {
				if(in_array($field->type,$exclude)){ continue;}

				if($default_value == $field->id)
				{
				    $selected_list_id = $field->id;
				    $selected_list_label = $field->name;
				}
				$responder_list_option .= '<li class="arf_selectbox_option" data-value="'.$field->id.'" data-label="'.$arfieldhelper->arf_execute_function($field->name,'strip_tags').'">'.$armainhelper->truncate($arfieldhelper->arf_execute_function($field->name,'strip_tags'), 33).'</li>';
			    $cntr++;
			    }
			}

			?>
			<?php if($is_version_compatible){?>

			<input id="<?php echo $name; ?>"  name="<?php echo $name; ?>" value="<?php echo $selected_list_id; ?>" type="hidden" >
			<dl class="arf_selectbox" data-name="<?php echo $name; ?>" data-id="<?php echo $name;?>" style="width:<?php echo $drpdwn_width;?>;">
			    <dt><span><?php echo $arfieldhelper->arf_execute_function($selected_list_label,'strip_tags'); ?></span>
			    <input value="<?php echo $selected_list_id; ?>" style="display:none;" class="arf_autocomplete" type="text" style="width:211px;" autocomplete="off">
			    <svg viewBox="0 0 2000 1000" width="15px" height="15px">
			    <g fill="#000">
			    <path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
			    </g>
			    </svg>
			    </dt>
			    <dd>
				<ul style="display: none;width:<?php echo $drpdwn_width;?>" data-id="<?php echo $name; ?>" id="<?php echo 'add_field_'.$name?>" class="arf_stripe_fields">
				   <li class="arf_selectbox_option" data-value="" data-label="<?php  _e('Select Field','ARForms-Stripe');?>"><?php  _e('Select Field', 'ARForms-Stripe');?></li>
				<?php echo $responder_list_option;?>
				</ul>
			    </dd>
			</dl>
			
			<?php }else{ ?>
		    <select name="<?php echo $name; ?>" id="<?php echo $name; ?>" style="width:<?php echo $drpdwn_width;?>" class="<?php echo $class; ?> frm-dropdown" data-width="<?php echo $drpdwn_width;?>" data-size="15">
			    <option value=""><?php _e('Select Field', 'ARForms-Stripe'); ?></option>
			    <?php 
			    if( count($field_list) > 0 ){
			    foreach($field_list as $field){
				if(in_array($field->type,$exclude)){
				    continue;
				}?>
				    <option value="<?php echo $field->id; ?>" <?php selected($default_value, $field->id);?>><?php echo $armainhelper->truncate($field->name, 33); ?></option>
			    <?php } } ?>
		    </select>
			<?php }?>
		    </div>
		    <?php
		} else {?>
		    <div class="sltstandard">
			<?php 
			global $armainhelper;
			$selected_list_id = "";
			$selected_list_label = __('Select Field', 'ARForms-Stripe');
			unset($responder_list_option);
			$responder_list_option = "";
			
			if (count($field_list) > 0) { //echo '<pre>';print_r($field_list);echo '</pre>';exit;
			    $cntr = 0;
			    foreach ($field_list as $field) {
				if(in_array($field->type,$exclude)){ continue;}

				if($default_value == $field->id)
				{
				    $selected_list_id = $field->id;
				    $selected_list_label = $field->name;
				}
				$responder_list_option .= '<li class="arf_selectbox_option" data-value="'.$field->id.'" data-label="'.$arfieldhelper->arf_execute_function($field->name,'strip_tags').'">'.$armainhelper->truncate($arfieldhelper->arf_execute_function($field->name,'strip_tags'), 33).'</li>';
			    $cntr++;
			    }
			}

			?>
			<?php if($is_version_compatible){?>
			<input id="<?php echo $name; ?>"  name="<?php echo $name; ?>" value="<?php echo $selected_list_id; ?>" type="hidden" >
			<dl class="arf_selectbox" data-name="<?php echo $name; ?>" data-id="<?php echo $name;?>" style="width:211px;">
			    <dt><span><?php echo $arfieldhelper->arf_execute_function($selected_list_label,'strip_tags'); ?></span>
			    <input value="<?php echo $selected_list_id; ?>" style="display:none;" class="arf_autocomplete" type="text" style="width:211px" autocomplete="off">
			    <svg viewBox="0 0 2000 1000" width="15px" height="15px">
			    <g fill="#000">
			    <path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
			    </g>
			    </svg>
			    </dt>
			    <dd>
				<ul style="display: none;width:211px;" data-id="<?php echo $name; ?>" id="<?php echo 'add_field_'.$name?>" class="arf_stripe_fields">
				  <li class="arf_selectbox_option" data-value="" data-label="<?php _e('Select Field','ARForms-Stripe');?>"><?php  _e('Select Field', 'ARForms-Stripe');?></li>
				<?php echo $responder_list_option;?>
				</ul>
			    </dd>
			</dl>
		    <?php }else{?>
		    <select name="<?php echo $name; ?>" id="<?php echo $name; ?>" style="width:<?php echo $drpdwn_width;?>" class="<?php echo $class; ?> frm-dropdown" data-width="<?php echo $drpdwn_width;?>" data-size="15">
			    <option value=""><?php _e('Select Field', 'ARForms-Stripe'); ?></option>
			    <?php 
			    if( count($field_list) > 0 ){
			    foreach($field_list as $field){
				if(in_array($field->type,$exclude)){
				    continue;
				}?>
			<option value="<?php echo $field->id; ?>" <?php selected($default_value, $field->id); ?>><?php echo $armainhelper->truncate($field->name, 33); ?></option>
			    <?php } } ?>
		    </select>
		    <?php }?>
		    </div>
		    <?php				
		}  
		
	}
	
	function arf_stripe_field_dropdown(){
		
    global $arffield, $MdlDb, $armainhelper,$is_version_compatible,$arfieldhelper;

	$form_id = $_REQUEST['form_id'];
	$field_list = array();
	$res = '';
	
        if(is_numeric($form_id)){
            $exclude = "'divider','captcha','break','file','like'";
            $field_list = $arffield->getAll("fi.type not in (". $exclude .") and fi.form_id=". (int)$form_id, 'id');
        }

	    if($is_version_compatible){
            $selected_list_id = "";
            $selected_list_label = __('Select Field', 'ARForms-Stripe');
            $responder_list_option = '<li class="arf_selectbox_option" data-value="" data-label='. __('Select Field','ARForms-Stripe').'>'. __('Select Field', 'ARForms-Stripe').'</li>';
	    
            if (count($field_list) > 0) { //echo '<pre>';print_r($field_list);echo '</pre>';exit;
                foreach ($field_list as $field) {
		    $responder_list_option .= '<li class="arf_selectbox_option" data-value="'.$field->id.'" data-label="'.$arfieldhelper->arf_execute_function($field->name,'strip_tags').'">'.$armainhelper->truncate($arfieldhelper->arf_execute_function($field->name,'strip_tags'), 33).'</li>';
                }
            }
        } else {

        	$responder_list_option = '<option value="">'.__('Select Field', 'ARForms-Stripe').'</option>';
           
			if( count($field_list) > 0 ){
			foreach($field_list as $field){
            	$responder_list_option.= '<option value="'.$field->id.'">'.$armainhelper->truncate($field->name, 33).'</option>';
        		}
        	}

    	}

		$res.= $responder_list_option;
		$res.='^|^';
			
	if(is_numeric($form_id)){
  	    $exclude = "'divider','captcha','break','file','like'";
            $field_list = $arffield->getAll("fi.type not in (". $exclude .") and fi.form_id=". (int)$form_id, 'id');
        }	
	    global $armainhelper;

	    if($is_version_compatible){
            $selected_list_id = "";
            $selected_list_label = __('Select Field', 'ARForms-Stripe');
            $responder_list_option = '<li class="arf_selectbox_option" data-value="" data-label='. __('Select Field','ARForms-Stripe').'>'. __('Select Field', 'ARForms-Stripe').'</li>';
            if (count($field_list) > 0) { //echo '<pre>';print_r($field_list);echo '</pre>';exit;
                $cntr = 0;
                foreach ($field_list as $field) {
		    $responder_list_option .= '<li class="arf_selectbox_option" data-value="'.$field->id.'" data-label="'.$arfieldhelper->arf_execute_function($field->name,'strip_tags').'">'.$armainhelper->truncate($arfieldhelper->arf_execute_function($field->name,'strip_tags'), 33).'</li>';
                $cntr++;
                }
            }

        } else {

        	$responder_list_option = '<option value="">'.__('Select Field', 'ARForms-Stripe').'</option>';
        	if( count($field_list) > 0 ){
			foreach($field_list as $field){
            	$responder_list_option .= '<option value="'.$field->id.'">'.$armainhelper->truncate($field->name, 33).'</option>';
        		}
        	}

    	}

	    $res.=$responder_list_option;
	    echo $res;
        die();
	
            
	die();
	}
	
	function arfdelete_stripe_form( $form_id ){
		global $wpdb, $db_record,$arf_stripe;
		
		if( !$form_id )
			return;
		
		$form_data = $wpdb->get_results( $wpdb->prepare("SELECT id FROM ".$arf_stripe->db_stripe_forms." WHERE form_id = %d", $form_id) );
		
		if( count($form_data) > 0 ){
			$form_data = $form_data[0];
			$entries = $db_record->getAll(array('it.form_id' => $form_id));
			if( count($entries) > 0 ){
				foreach( $entries as $item ){
					$res = $wpdb->query( $wpdb->prepare("DELETE FROM ".$arf_stripe->db_stripe_order." WHERE entry_id = %d", $item->id) );
				}
			}
			
			$res = $wpdb->query( $wpdb->prepare("DELETE FROM ".$arf_stripe->db_stripe_forms." WHERE id = %d", $form_data->id) );
		}
					
	}
		
	function getwpversion()
	{
		global $arf_stripe_version,$arf_stripe;
		$bloginformation = array();
        $str = $arf_stripe->get_rand_alphanumeric(10);

		$bloginformation[] = get_bloginfo('name');
		$bloginformation[] = get_bloginfo('description');
		$bloginformation[] = home_url();
		$bloginformation[] = get_bloginfo('admin_email');
		$bloginformation[] = get_bloginfo('version');
		$bloginformation[] = get_bloginfo('language');
		$bloginformation[] = $arf_stripe_version;
		$bloginformation[] = $_SERVER['SERVER_ADDR'];
		$bloginformation[] = $str;
		
		update_option('wp_stripe_get_version',$str);
		
		$valstring = implode("||",$bloginformation);
		$encodedval = base64_encode($valstring);
		
		$urltopost = "http://reputeinfosystems.net/arforms/wpinfo_stripe.php";
		$response = wp_remote_post( $urltopost, array(
			'method' => 'POST',
			'timeout' => 45,
			'redirection' => 5,
			'httpversion' => '1.0',
			'blocking' => true,
			'headers' => array(),
			'body' => array( 'wpversion' => $encodedval ),
			'cookies' => array()
			)
		);
	}
	
	function assign_rand_value($num) {

		switch($num) {
			case "1"  : $rand_value = "a"; break;
			case "2"  : $rand_value = "b"; break;
			case "3"  : $rand_value = "c"; break;
			case "4"  : $rand_value = "d"; break;
			case "5"  : $rand_value = "e"; break;
			case "6"  : $rand_value = "f"; break;
			case "7"  : $rand_value = "g"; break;
			case "8"  : $rand_value = "h"; break;
			case "9"  : $rand_value = "i"; break;
			case "10" : $rand_value = "j"; break;
			case "11" : $rand_value = "k"; break;
			case "12" : $rand_value = "l"; break;
			case "13" : $rand_value = "m"; break;
			case "14" : $rand_value = "n"; break;
			case "15" : $rand_value = "o"; break;
			case "16" : $rand_value = "p"; break;
			case "17" : $rand_value = "q"; break;
			case "18" : $rand_value = "r"; break;
			case "19" : $rand_value = "s"; break;
			case "20" : $rand_value = "t"; break;
			case "21" : $rand_value = "u"; break;
			case "22" : $rand_value = "v"; break;
			case "23" : $rand_value = "w"; break;
			case "24" : $rand_value = "x"; break;
			case "25" : $rand_value = "y"; break;
			case "26" : $rand_value = "z"; break;
			case "27" : $rand_value = "0"; break;
			case "28" : $rand_value = "1"; break;
			case "29" : $rand_value = "2"; break;
			case "30" : $rand_value = "3"; break;
			case "31" : $rand_value = "4"; break;
			case "32" : $rand_value = "5"; break;
			case "33" : $rand_value = "6"; break;
			case "34" : $rand_value = "7"; break;
			case "35" : $rand_value = "8"; break;
			case "36" : $rand_value = "9"; break;
		}
		return $rand_value;
	}

	function get_rand_alphanumeric($length) {
		if ($length>0) {
			$rand_id="";
			for ($i=1; $i<=$length; $i++) {
				mt_srand((double)microtime() * 1000000);
				$num = mt_rand(1,36);
                $rand_id .= $this->assign_rand_value($num);
			}
		}
		return $rand_id;
	}

	function arfstripe_backup(){
		$databaseversion = get_option('arf_stripe_version');
		update_option('old_arf_stripe_version',$databaseversion);
	}
	
	function upgrade_data(){
		
		global $newarfstripeversion;
		
		if(!isset($newarfstripeversion) || $newarfstripeversion == "")
			$newarfstripeversion = get_option('arf_stripe_version');
		
		if(version_compare($newarfstripeversion, '1.6', '<'))
		{
			$path = ARF_STRIPE_DIR.'/core/upgrade_stripe_latest_data.php';
			if (file_exists($path)) {
			    include($path);
			}
		}
	}
	
	function stripe_form_dropdown($name, $default_value ='', $blank=true, $onchange = false){
		global $wpdb,$arf_stripe,$MdlDb,$is_version_compatible,$arfieldhelper;
		$forms = $wpdb->get_results( "SELECT stp.*,frm.name FROM ".$arf_stripe->db_stripe_forms." stp INNER JOIN ".$MdlDb->forms." frm ON frm.id=stp.form_id" );?>
                <?php if($is_version_compatible){ ?> 
                         <?php
                        $selected_list_id = "";
                        $selected_list_label = __('- All Forms -','ARForms-Stripe');
                        $list_option = "";
                        if (count($forms) > 0) {
                            $cntr = 0;
                             foreach($forms as $form){
                             	$form->name = $arfieldhelper->arf_execute_function($form->name,'strip_tags');
                             	$order_count = $this->get_order_count($form->form_id);
                                if ($default_value == $form->form_id) {
                                    $selected_list_id = $form->form_id;
                                    $selected_list_label = $form->name.'('.$order_count.')';
                                }
                               
                                $list_option .= '<li class="arf_selectbox_option" data-value="' . $form->form_id . '" data-label="' .$form->name.' ('.$order_count.')">' .$form->name.' ('.$order_count.')</li>';
                                $cntr++;
                            }
                        }
                        ?>
                        <input name="<?php echo $name; ?>" id="<?php echo $name; ?>" value="<?php echo $selected_list_id;?>" type="hidden" <?php if ($onchange) echo 'onchange="'.$onchange.'"'; ?>>
                        <dl class="arf_selectbox" data-name="<?php echo $name; ?>" data-id="<?php echo $name; ?>" style="<?php echo ( $name != 'arf_stripe_forms_dropdown' ) ? 'width:241px;' : ''; ?>">
                        <dt><span><?php echo $selected_list_label; ?></span>
                        <input value="" class="arf_autocomplete" type="text" style="display:none;width:118px;" autocomplete="off">
                            <svg viewBox="0 0 2000 1000" width="15px" height="15px">
                            <g fill="#000">
                            <path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
                            </g>
                            </svg>
                        </dt>
                        <dd>
                            <ul style="display: none;<?php echo ($name != 'arf_stripe_forms_dropdown') ? 'width:241px;' : ''; ?>" data-id="<?php echo $name; ?>" class="">
                              <li class="arf_selectbox_option" data-value="" data-label="<?php _e('- All Forms -','ARForms-Stripe'); ?>"><?php _e('- All Forms -','ARForms-Stripe'); ?></li>
                                <?php echo $list_option;?>
                            </ul>
                        </dd>
                    </dl>
                <?php } else { ?>
                    <select name="<?php echo $name; ?>" id="<?php echo $name; ?>" <?php if ($onchange) echo 'onchange="'.$onchange.'"'; ?> style="width:290px;" data-width="290px" data-size="20">
                        <option value=""><?php echo ($blank == 1) ? '' : '- '. $blank .' -'; ?></option>
                    <?php 
                                if( count($forms) > 0 ){
                                        foreach($forms as $form){					
                                                ?>
                        <option value="<?php echo $form->form_id; ?>" <?php selected($default_value, $form->form_id); ?>><?php echo $form->name ?> (<?php echo $this->get_order_count($form->form_id); ?>)</option> 
                                <?php
                                        }
                                }
                                ?>
                </select>
                <?php } ?>
        
        <?php
	}
	
	function get_order_count($form_id=0){
		global $wpdb,$arf_stripe;
		$record_count = $wpdb->get_results( $wpdb->prepare("SELECT count(*) AS record_count FROM ".$arf_stripe->db_stripe_order." WHERE form_id = %d", $form_id) );	
		$record_count = $record_count[0];
		return (isset($record_count->record_count)) ? $record_count->record_count : 0;
	}
	
	function get_form_name($form_id=0){
		global $wpdb,$arf_stripe,$MdlDb;
		$form_name = $wpdb->get_results( $wpdb->prepare("SELECT name FROM ".$MdlDb->forms." WHERE id = %d", $form_id) );	
		$form_name = $form_name[0];
        return (isset($form_name->name)) ? stripslashes($form_name->name) : '';
	}
	
	function arfs_form_order(){
		$form_id = $_POST['form_id'];
		
		$startdate = $_POST['start_date'];
		$enddate = $_POST['end_date'];
		
		global $style_settings, $wp_scripts;
		$wp_format_date = get_option('date_format');

		if( $wp_format_date == 'F j, Y' || $wp_format_date =='m/d/Y' ) {
			$date_format_new = 'mm/dd/yy';
		} else if( $wp_format_date == 'd/m/Y' ) {
			$date_format_new = 'dd/mm/yy';
		} else if( $wp_format_date == 'Y/m/d' ) {
			$date_format_new = 'dd/mm/yy';
		} else {
			$date_format_new = 'mm/dd/yy';
		}
		
		$datequery = "";
		if( $startdate != '' and $enddate != '' ) {
			if($date_format_new=='dd/mm/yy')
			{
				$startdate = str_replace('/', '-', $startdate);
				$enddate = str_replace('/', '-', $enddate);
			}
			$new_start_date_var = date('Y-m-d', strtotime($startdate));
			$new_end_date_var = date('Y-m-d', strtotime($enddate));
			
			$datequery .= " and DATE(created_at) >= '".$new_start_date_var."' and DATE(created_at) <= '".$new_end_date_var."'";
		
		} else if( $startdate != '' and $enddate == '' ) {
			if($date_format_new=='dd/mm/yy')
			{	
				$startdate = str_replace('/', '-', $startdate);
			}
			$new_start_date_var = date('Y-m-d', strtotime($startdate));
			
			$datequery .= " and DATE(created_at) >= '".$new_start_date_var."'";
		
		} else if( $startdate == '' and $enddate != '' ) {
			if($date_format_new=='dd/mm/yy')
			{
				$enddate = str_replace('/', '-', $enddate);
			}
			$new_end_date_var = date('Y-m-d', strtotime($enddate));
			
			$datequery .= " and DATE(created_at) <= '".$new_end_date_var."'";
		}
		
		$message = '';
		$errors = array();
		global $is_version_compatible;
	    if($is_version_compatible){
        	$this->arf_stripe_order_new($message, $errors, $form_id, $datequery, $start_date, $end_date);
        }
        else{
        	$this->arf_stripe_order($message, $errors, $form_id, $datequery, $start_date, $end_date);
        }
	die();
	}

	function defalut_email_content(){
		$message = "";
		
		$message .= __('Hello admin,', 'ARForms-Stripe')."\n\n";
		$message .= __('Payment successfully received from', 'ARForms-Stripe')." [site_name]. \r\n\n";
		$message .= __('Following are the payment details:', 'ARForms-Stripe')."\r\n\n";
		$message .= __('Transaction id:', 'ARForms-Stripe')." [transaction_id] \n";
		$message .= __('Amount paid', 'ARForms-Stripe')." [amount] [currency] \n";
		$message .= __('Payment date', 'ARForms-Stripe')." [payment_date]";
		$message .= "\n\n\n".__('Thank you', 'ARForms-Stripe');
		$message .= "\n[site_name]";
		
		return $message;
	}

	function user_defalut_email_content() {
        $message = "";
        $message .= __('Hello user,', 'ARForms-Stripe') . "\n\n";
        $message .= __('Payment successfully done to', 'ARForms-Stripe') . " [site_name]. \r\n\n";
        $message .= __('Following are the payment details:', 'ARForms-Stripe') . "\r\n\n";
        $message .= __('Transaction id:', 'ARForms-Stripe') . " [transaction_id] \n";
        $message .= __('Amount paid', 'ARForms-Stripe') . " $ [amount] \n"; //[currency]
        $message .= __('Payment date', 'ARForms-Stripe') . " [payment_date]";
        $message .= "\n\n\n" . __('Thank you', 'ARForms-Stripe');
        $message .= "\n[site_name]";
        return $message;
    }
	
	function parse_standalone_request(){

        global $armainhelper;
        if (!$this->is_arforms_support())
			return;
			
        $plugin = $armainhelper->get_param('plugin');

        $action 	= isset($_REQUEST['arfaction']) ? 'arfaction' : 'action';

        $action = $armainhelper->get_param($action);

        if( !empty($plugin) and $plugin == 'ARForms-Stripe' and !empty($action) and $action == 'csv' ){
			
            $this->export_to_csv();
        }


    }
	
	function export_to_csv()
	{
		if(!current_user_can('arfstripetransaction')){

            global $arfsettings;

            wp_die($arfsettings->admin_permission);

        }

        if( !ini_get('safe_mode') ){
            set_time_limit(0); 
        }

        global $current_user, $arfform, $arffield, $db_record, $arfrecordmeta, $wpdb, $style_settings;

        require(ARF_STRIPE_DIR.'/core/export_data.php');
	}
	
	function arfstripe_validate_process($flag, $form)
	{
		global $wpdb,$arf_stripe;
		
		$form_id = $form->id;		
		if(isset($GLOBALS['arf_form_stripe_not_set'][$form_id])) {
			return $flag;
		}
		if(!isset($GLOBALS['arf_form_stripe_form_data'][$form_id]))
		{
			$form_data	= $wpdb->get_row( $wpdb->prepare("SELECT * FROM ".$arf_stripe->db_stripe_forms." WHERE form_id = %d", $form_id) );
			if( ! $form_data )
				return $flag;
		} else {
			$form_data = $GLOBALS['arf_form_stripe_form_data'][$form_id];
		}
		
		$form_options	= maybe_unserialize( $form_data->options );
		
		if( $form_options['stripe_mode'] == '1' )
		{
			if( ! isset($form_options['live_secret_key']) or empty( $form_options['live_secret_key'] ) )
				return $flag;
				
			if( ! isset($form_options['live_publishable_key']) or empty( $form_options['live_publishable_key'] ) )
				return $flag;		
		}
		else
		{
			if( ! isset($form_options['test_secret_key']) or empty( $form_options['test_secret_key'] ) )
				return $flag;
				
			if( ! isset($form_options['test_publishable_key']) or empty( $form_options['test_publishable_key'] ) )
				return $flag;
		}
		
		if( ( $form_options['amount'] || $form_options['payment_type'] == 'subscription' ) && $form_options['card_number'] && $form_options['exp_month'] && $form_options['exp_year'] && $form_options['cvc'] )
		{
			return true;	
		}
		
		return $flag; 		
	}
		
	function arf_prevalidate_card($arf_errors, $form_id, $values, $arf_form_data=array())
	{
		
                global $wpdb, $arfrecordmeta, $arfsettings, $current_user,$arf_stripe,$is_version_compatible;
		
		$form_data = $wpdb->get_results( $wpdb->prepare('SELECT * FROM  '.$arf_stripe->db_stripe_forms.' WHERE form_id = %d', $form_id) );
				
		if( count($form_data) < 1 )
			return $arf_errors;
		
		$form_data 	= $form_data[0];
								
		$form_options = maybe_unserialize( $form_data->options ); 
		
		$mapped_conditional_field = array();
		if( $form_options['stripe_condition'] && $form_options['stripe_condition'] == 1 )
		{
			$rules = $form_options['conditional_logic']['rules'] ? $form_options['conditional_logic']['rules'] : array();				
			if( $rules )
			{
				foreach( $rules as $rule )
				{
					if( $rule['field_id'] != '' )
						$mapped_conditional_field[] = $rule['field_id']; 													
				}				
			}				  
		}
											
		if( isset($values['item_meta']) && $values['item_meta'] )
		{
			foreach($values['item_meta'] as $field_id => $field_value )
			{					
				if( $mapped_conditional_field )
				{
					foreach($mapped_conditional_field as $rule_field)
					{
						if( $rule_field == $field_id )
							$mapped_field_values[$field_id] = $field_value;  								
					}
				}																		
			}
		}
		
		
		if( $form_options['stripe_condition'] && $form_options['stripe_condition'] == 1 )
		{
			$rules = $form_options['conditional_logic']['rules'] ? $form_options['conditional_logic']['rules'] : array();
			
			if( $rules )
			{
				$matched = 0;
				$total_rules = 0;
				
				foreach( $rules as $rule )
				{
					if( $rule['field_id'] != '' )
					{
						$total_rules++;
						
						$value1 = isset( $mapped_field_values[ $rule['field_id'] ] ) ? $mapped_field_values[ $rule['field_id'] ] : '';
						
						$value1 = is_array($value1) ? $value1 : trim( strtolower($value1) );
	
						$value2 = @trim( strtolower( $rule['value'] ) );
						
						$operator = $rule['operator'];
						
                        if ($this->calculate_rule($value1, $value2, $operator, $rule['field_type']))
							$matched++;								
					}
						
				}
				
				
				if( ($form_options['conditional_logic']['if_cond'] == 'all' && $total_rules == $matched) || ($form_options['conditional_logic']['if_cond'] == 'any' && $matched > 0) )
				{
					
				}
				else
				{
					
					return $arf_errors;
				}
				
			}
			  
		}

		$arf_stripe_enable_debug_mode =  isset($form_options['enable_debug_mode']) ? $form_options['enable_debug_mode'] : '';

		$card_holder_name = '';
		if( isset($values['item_meta']) && $values['item_meta'] )
		{
			foreach($values['item_meta'] as $field_id => $field_value )
			{				
				if( !is_array($field_value) && $form_options['card_number'] == $field_id && $field_value != '' )
					$card_number	= $field_value; 
				
				if( !is_array($field_value) && $form_options['exp_month'] == $field_id && $field_value != '' )
					$exp_month	= $field_value; 
					
				
				if( !is_array($field_value) && $form_options['exp_year'] == $field_id && $field_value != '' )
					$exp_year	= $field_value; 
				
				
				if( !is_array($field_value) && $form_options['cvc'] == $field_id && $field_value != '' )
					$cvc	= $field_value; 
				
				if( !is_array($field_value) && $form_options['payment_type'] != 'subscription' && $form_options['amount'] == $field_id && $field_value != '' )
					$amount	= $field_value; 
				
				if( !is_array($field_value) && isset($form_options['card_holder_name']) && $form_options['card_holder_name'] == $field_id && $field_value != '' )
					$card_holder_name = $field_value;
																	
			}
		}
		
		if( $form_options['stripe_mode'] == '1' )
		{
			if( ! isset($form_options['live_secret_key']) or empty( $form_options['live_secret_key'] ) )
				return $arf_errors;
				
			if( ! isset($form_options['live_publishable_key']) or empty( $form_options['live_publishable_key'] ) )
				return $arf_errors;  		
		}
		else
		{
			if( ! isset($form_options['test_secret_key']) or empty( $form_options['test_secret_key'] ) )
				return $arf_errors;
				
			if( ! isset($form_options['test_publishable_key']) or empty( $form_options['test_publishable_key'] ) )
				return $arf_errors;
		}
		
		if( !$form_options['card_number'] || !$form_options['exp_month'] || !$form_options['exp_year'] || !$form_options['cvc'] )
			return $arf_errors;	
		
		if( $form_options['payment_type'] != 'subscription' && !$form_options['amount'] )
			return $arf_errors;
				
		if( $form_options['payment_type'] == 'subscription' )  
			$amount = "1";
				
		if( isset($card_number) && isset($exp_month) && isset($exp_year) && isset($cvc) && isset($amount) )
		{
                        require_once ARF_STRIPE_DIR . "/lib/init.php";
			$apikey ="";
                        
			if( $form_options['stripe_mode'] == '1' )
				$apikey = $form_options['live_secret_key']; 
			else
				$apikey = $form_options['test_secret_key']; 
			
			\ARFStripe\ARFStripe::setApiKey( $apikey );
                        
                        try {
				$arfCard = array(
								'number' 	=> $card_number, 
								'exp_month' => $exp_month, 
								'exp_year' 	=> $exp_year,
								'cvc'		=> $cvc,
								'name'		=> $card_holder_name,
							);
                                $token = \ARFStripe\Token::create(array( "card" => $arfCard ) );
                                $request_token = $token->id;
						
						} catch(Stripe_CardError $e) { 
				
				if( isset($form_options['invalid_card']) && ! empty( $form_options['invalid_card'] ) )
					$arf_errors['arf_message_error']	= $form_options['invalid_card'];
				else
					$arf_errors['arf_message_error']	= __('Please enter correct card details.', 'ARForms-Stripe'); 
			} catch (Stripe_InvalidRequestError $e) { 
				
				if( isset($form_options['payment_failure']) && ! empty( $form_options['payment_failure'] ) )
					$arf_errors['arf_message_error']	= $form_options['payment_failure'];
				else
					$arf_errors['arf_message_error']	= __('Sorry something went wrong while processing payment.', 'ARForms-Stripe'); 
			} catch (Stripe_AuthenticationError $e) { 
				
				
				if( isset($form_options['payment_failure']) && ! empty( $form_options['payment_failure'] ) )
					$arf_errors['arf_message_error']	= $form_options['payment_failure'];
				else
					$arf_errors['arf_message_error']	= __('Sorry something went wrong while processing payment.', 'ARForms-Stripe'); 
			} catch (Stripe_ApiConnectionError $e) { 
				
				if( isset($form_options['payment_failure']) && ! empty( $form_options['payment_failure'] ) )
					$arf_errors['arf_message_error']	= $form_options['payment_failure'];
				else
					$arf_errors['arf_message_error']	= __('Sorry something went wrong while processing payment.', 'ARForms-Stripe');   
			} catch (Stripe_Error $e) { 
				
				if( isset($form_options['payment_failure']) && ! empty( $form_options['payment_failure'] ) )
					$arf_errors['arf_message_error']	= $form_options['payment_failure'];
				else
					$arf_errors['arf_message_error']	= __('Sorry something went wrong while processing payment.', 'ARForms-Stripe');   
			} catch (Exception $e) { 
				
				if ($arf_stripe_enable_debug_mode) {
				    if (isset($token->response_reason_text) && !empty($token->response_reason_text)) {
					$arf_errors['arf_message_error'] = json_encode($token);
				    } 
				}
				
				if( isset($form_options['payment_failure']) && ! empty( $form_options['payment_failure'] ) )
				{
					$arf_errors['arf_message_error']	= $form_options['payment_failure'];
				}
				else
				{
					$arf_errors['arf_message_error']	= __('Sorry something went wrong while processing payment.', 'ARForms-Stripe');  
				}
			}
				
		}

		if ($arf_stripe_enable_debug_mode) {
		    if ( isset($e) ) {
				$arf_errors['arf_message_error'] = json_encode($e);
		    } 
		}

		return $arf_errors;
	}
	
	function arf_prevalidatecard(){

        $form_id = $_POST['form_id'];
		
		global $wpdb, $arfrecordmeta, $arfsettings, $current_user,$arf_stripe;
				
		$form_data 	= $wpdb->get_results( $wpdb->prepare('SELECT * FROM  '.$arf_stripe->db_stripe_forms.' WHERE form_id = %d', $form_id) );
				
		if( count($form_data) < 1 )
			return;
		
		$form_data 	= $form_data[0];
		
		$errors = array();
								
		$form_options = maybe_unserialize( $form_data->options ); 
		
		
		$mapped_conditional_field = array();
		if( $form_options['stripe_condition'] && $form_options['stripe_condition'] == 1 )
		{
			$rules = $form_options['conditional_logic']['rules'] ? $form_options['conditional_logic']['rules'] : array();				
			if( $rules )
			{
				foreach( $rules as $rule )
				{
					if( $rule['field_id'] != '' )
						$mapped_conditional_field[] = $rule['field_id']; 													
				}				
			}				  
		}
											
		if( isset($_POST['item_meta']) && $_POST['item_meta'] )
		{
			foreach($_POST['item_meta'] as $field_id => $field_value )
			{					
				if( $mapped_conditional_field )
				{
					foreach($mapped_conditional_field as $rule_field)
					{
						if( $rule_field == $field_id )
							$mapped_field_values[$field_id] = $field_value;  								
					}
				}																		
			}
		}
		
		
		if( $form_options['stripe_condition'] && $form_options['stripe_condition'] == 1 )
		{
			$rules = $form_options['conditional_logic']['rules'] ? $form_options['conditional_logic']['rules'] : array();
			
			if( $rules )
			{
				$matched = 0;
				$total_rules = 0;
				
				foreach( $rules as $rule )
				{
					if( $rule['field_id'] != '' )
					{
						$total_rules++;
						
						$value1 = isset( $mapped_field_values[ $rule['field_id'] ] ) ? $mapped_field_values[ $rule['field_id'] ] : '';
						
						$value1 = is_array($value1) ? $value1 : trim( strtolower($value1) );
	
						$value2 = @trim( strtolower( $rule['value'] ) );
						
						$operator = $rule['operator'];
						
						if( $this->calculate_rule($value1, $value2, $operator, $rule['field_type']) )
							$matched++;								
					}
						
				}
				
				
				if( ($form_options['conditional_logic']['if_cond'] == 'all' && $total_rules == $matched) || ($form_options['conditional_logic']['if_cond'] == 'any' && $matched > 0) )
				{
					
				}
				else
				{
					
					return;
				}
				
			}
			  
		}
		
		
		if( $form_options['stripe_mode'] == '1' )
		{
			if( ! isset($form_options['live_secret_key']) or empty( $form_options['live_secret_key'] ) )
				return;
				
			if( ! isset($form_options['live_publishable_key']) or empty( $form_options['live_publishable_key'] ) )
				return;		
		}
		else
		{
			if( ! isset($form_options['test_secret_key']) or empty( $form_options['test_secret_key'] ) )
				return;
				
			if( ! isset($form_options['test_publishable_key']) or empty( $form_options['test_publishable_key'] ) )
				return;
		}
		
		if( !$form_options['card_number'] || !$form_options['exp_month'] || !$form_options['exp_year'] || !$form_options['cvc'] )
			return;	
		
		if( $form_options['payment_type'] != 'subscription' && !$form_options['amount'] )
			return;
		
		$card_holder_name = '';
		if( isset($_POST['item_meta']) && $_POST['item_meta'] )
		{
			foreach($_POST['item_meta'] as $field_id => $field_value )
			{				
				if( !is_array($field_value) && $form_options['card_number'] == $field_id && $field_value != '' )
					$card_number	= $field_value; 
								
				if( !is_array($field_value) && $form_options['exp_month'] == $field_id && $field_value != '' )
					$exp_month	= $field_value; 
				
				
				if( !is_array($field_value) && $form_options['exp_year'] == $field_id && $field_value != '' )
					$exp_year	= $field_value; 
				
				
				if( !is_array($field_value) && $form_options['cvc'] == $field_id && $field_value != '' )
					$cvc	= $field_value; 
				
					
				if( !is_array($field_value) && $form_options['payment_type'] != 'subscription' && $form_options['amount'] == $field_id && $field_value != '' )
					$amount	= $field_value; 
				
				if( !is_array($field_value) && isset($form_options['card_holder_name']) && $form_options['card_holder_name'] == $field_id && $field_value != '' )
					$card_holder_name = $field_value;				
												
			}
		}
		
		if( $form_options['payment_type'] == 'subscription' )  
			$amount = "1";
			
                
               		
		if( isset($card_number) && isset($exp_month) && isset($exp_year) && isset($cvc) && isset($amount) )
		{
			require_once ARF_STRIPE_DIR . "/lib/init.php";
			$apikey ="";
			
			if( $form_options['stripe_mode'] == '1' )
				$apikey = $form_options['live_secret_key']; 
			else
				$apikey = $form_options['test_secret_key']; 
			
			\ARFStripe\ARFStripe::setApiKey( $apikey );
			
			try {
				$arfCard = array(
								'number' 	=> $card_number, 
								'exp_month' => $exp_month, 
								'exp_year' 	=> $exp_year,
								'cvc'		=> $cvc,
								'name'		=> $card_holder_name,
							);
				$token = \ARFStripe\Token::create(array( "card" => $arfCard ) );
                                $request_token = $token->id;
				
			} catch(Stripe_CardError $e) { 
				if ($arf_stripe_enable_debug_mode) {
				    if (isset($token->response_reason_text) && !empty($token->response_reason_text)) {
						$arf_errors['arf_message_error'] = json_encode($token);
				    } 
				    else if(isset($token->error_message) && !empty($token->error_message)){
						$arf_errors['arf_message_error'] = json_encode($token);
				    }
				    else { 
					$arf_errors['arf_message_error'] = __('Uncaught Exception while authorizeOnly.', 'ARForms-Stripe');                             
				    }
				}else{
				
				    if( isset($form_options['invalid_card']) && ! empty( $form_options['invalid_card'] ) )
					    $errors['arf_message_error']	= $form_options['invalid_card'];
				    else
					    $errors['arf_message_error']	= __('Please enter correct card details.', 'ARForms-Stripe'); 
				}
			} catch (Stripe_InvalidRequestError $e) { 
				
				if ($arf_stripe_enable_debug_mode) {
				    if (isset($token->response_reason_text) && !empty($token->response_reason_text)) {
					$arf_errors['arf_message_error'] = json_encode($token);
				    } 
				    else if(isset($token->error_message) && !empty($token->error_message)){
					$arf_errors['arf_message_error'] = json_encode($token);
				    }
				    else { 
					$arf_errors['arf_message_error'] = __('Uncaught Exception while authorizeOnly.', 'ARForms-Stripe');                             
				    }
				}
				else
				{
				    if( isset($form_options['payment_failure']) && ! empty( $form_options['payment_failure'] ) )
					    $errors['arf_message_error']	= $form_options['payment_failure'];
				    else
					    $errors['arf_message_error']	= __('Sorry something went wrong while processing payment.', 'ARForms-Stripe');				
				}
			} catch (Stripe_AuthenticationError $e) { 
				
				if ($arf_stripe_enable_debug_mode) {
				    if (isset($token->response_reason_text) && !empty($token->response_reason_text)) {
					$arf_errors['arf_message_error'] = json_encode($token);
				    } 
				    else if(isset($token->error_message) && !empty($token->error_message)){
					$arf_errors['arf_message_error'] = json_encode($token);
				    }
				    else { 
					$arf_errors['arf_message_error'] = __('Uncaught Exception while authorizeOnly.', 'ARForms-Stripe');                             
				    }
				}
				else
				{
				    if( isset($form_options['payment_failure']) && ! empty( $form_options['payment_failure'] ) )
					    $errors['arf_message_error']	= $form_options['payment_failure'];
				    else
					    $errors['arf_message_error']	= __('Sorry something went wrong while processing payment.', 'ARForms-Stripe'); 
				}
			} catch (Stripe_ApiConnectionError $e) { 
				
				if ($arf_stripe_enable_debug_mode) {
				    if (isset($token->response_reason_text) && !empty($token->response_reason_text)) {
					$arf_errors['arf_message_error'] = json_encode($token);
				    } 
				    else if(isset($token->error_message) && !empty($token->error_message)){
					$arf_errors['arf_message_error'] = json_encode($token);
				    }
				    else { 
					$arf_errors['arf_message_error'] = __('Uncaught Exception while authorizeOnly.', 'ARForms-Stripe');                             
				    }
				}
				else
				{
				    if( isset($form_options['payment_failure']) && ! empty( $form_options['payment_failure'] ) )
					    $errors['arf_message_error']	= $form_options['payment_failure'];
				    else
					    $errors['arf_message_error']	= __('Sorry something went wrong while processing payment.', 'ARForms-Stripe');   
				}
			} catch (Stripe_Error $e) { 
				
				if ($arf_stripe_enable_debug_mode) {
				    if (isset($token->response_reason_text) && !empty($token->response_reason_text)) {
					$arf_errors['arf_message_error'] = json_encode($token);
				    } 
				    else if(isset($token->error_message) && !empty($token->error_message)){
					$arf_errors['arf_message_error'] = json_encode($token);
				    }
				    else { 
					$arf_errors['arf_message_error'] = __('Uncaught Exception while authorizeOnly.', 'ARForms-Stripe');                             
				    }
				}
				else
				{
				    if( isset($form_options['payment_failure']) && ! empty( $form_options['payment_failure'] ) )
					    $errors['arf_message_error']	= $form_options['payment_failure'];
				    else
					    $errors['arf_message_error']	= __('Sorry something went wrong while processing payment.', 'ARForms-Stripe');   
				}
			} catch (Exception $e) { 
				
				if ($arf_stripe_enable_debug_mode) {
				    if (isset($token->response_reason_text) && !empty($token->response_reason_text)) {
					$arf_errors['arf_message_error'] = json_encode($token);
				    } 
				    else if(isset($token->error_message) && !empty($token->error_message)){
					$arf_errors['arf_message_error'] = json_encode($token);
				    }
				    else { 
					$arf_errors['arf_message_error'] = __('Uncaught Exception while authorizeOnly.', 'ARForms-Stripe');                             
				    }
				}
				else
				{
				    if( isset($form_options['payment_failure']) && ! empty( $form_options['payment_failure'] ) )
					    $errors['arf_message_error']	= $form_options['payment_failure'];
				    else
					    $errors['arf_message_error']	= __('Sorry something went wrong while processing payment.', 'ARForms-Stripe');  
				}
			}
				
		}
						
		if( count($errors) > 0 )
		{
			foreach( $errors as $field_id => $error )
			{
				echo $field_id.'^|^'.$error.'~|~'; 	
			}
		}
		else
		{
			echo 0;
		}
		
		die();
	}
	
	function arf_before_form_render_v3($arf_from ,$form )
	{	
	    global $wpdb,$arf_stripe;

	    $form_id2	= $form->id; 
	    $form_mapped = maybe_unserialize($form->arf_mapped_addon);
        if(isset($form_mapped) && !empty($form_mapped))
        {
            $form_mapped = $form_mapped['arf_mapped_addon'];
            if(!in_array('stripe', $form_mapped))
            {
                $GLOBALS['arf_form_stripe_not_set'][$form_id2] = true;
                return $arf_from;
            }
        } else if(empty($form_mapped)) {
            $GLOBALS['arf_form_stripe_not_set'][$form_id2] = true;
            return $arf_from;
        }
	    $form_data2 = array();
	 	if(!isset($GLOBALS['arf_form_stripe_not_set'][$form_id2])) {
	    	$form_data2 = $wpdb->get_results( $wpdb->prepare('SELECT * FROM '.$arf_stripe->db_stripe_forms.' WHERE form_id = %d', $form_id2) );
	    }

	    if( count($form_data2) < 1 ) {
	    	$GLOBALS['arf_form_stripe_not_set'][$form_id2] = true;
		    return $arf_from;
	    } else {
			$GLOBALS['arf_form_stripe_form_data'][$form_id2] = $form_data2[0];
		}

	    $form_data2 	= $form_data2[0];

	    $form_options	= maybe_unserialize( $form_data2->options );

	    if( $form_options['stripe_mode'] == '1' )
	    {
		    if( ! isset($form_options['live_secret_key']) or empty( $form_options['live_secret_key'] ) )
			    return $arf_from;

		    if( ! isset($form_options['live_publishable_key']) or empty( $form_options['live_publishable_key'] ) )
			   return $arf_from;	
	    }
	    else
	    {
		    if( ! isset($form_options['test_secret_key']) or empty( $form_options['test_secret_key'] ) )
			  return $arf_from;

		    if( ! isset($form_options['test_publishable_key']) or empty( $form_options['test_publishable_key'] ) )
			    return $arf_from;
	    }

	    if( ( $form_options['amount'] || $form_options['payment_type'] == 'subscription' ) && $form_options['card_number'] && $form_options['exp_month'] && $form_options['exp_year'] && $form_options['cvc'] )
	    {				
		 $arf_from .= '<div id="arf_message_error" class="frm_error_style" style="display:none;">
		    <div class="msg-detail">
			<div class="msg-description-success">'.__('Sorry something went wrong while processing payment.', 'ARForms-Stripe').'</div>
		    </div>
		</div>';           	 	
	    }
	    return $arf_from;
	}
	
	function arf_before_form_render( $form )
	{
		global $wpdb;
		
		$form_id2	= $form->id; 
		
		$form_data2 	= $wpdb->get_results( $wpdb->prepare('SELECT * FROM '.$wpdb->prefix.'arf_stripe_forms WHERE form_id = %d', $form_id2) );
		
		if( count($form_data2) < 1 )
			return;
		
		$form_data2 	= $form_data2[0];
		
		$form_options	= maybe_unserialize( $form_data2->options );
		
		if( $form_options['stripe_mode'] == '1' )
		{
			if( ! isset($form_options['live_secret_key']) or empty( $form_options['live_secret_key'] ) )
				return;
				
			if( ! isset($form_options['live_publishable_key']) or empty( $form_options['live_publishable_key'] ) )
				return;		
		}
		else
		{
			if( ! isset($form_options['test_secret_key']) or empty( $form_options['test_secret_key'] ) )
				return;
				
			if( ! isset($form_options['test_publishable_key']) or empty( $form_options['test_publishable_key'] ) )
				return;
		}
		
		if( ( $form_options['amount'] || $form_options['payment_type'] == 'subscription' ) && $form_options['card_number'] && $form_options['exp_month'] && $form_options['exp_year'] && $form_options['cvc'] )
		{				
            echo '<div id="arf_message_error" class="frm_error_style" style="display:none;">
                <div class="msg-detail">
                    <div class="msg-description-success">'.__('Sorry something went wrong while processing payment.', 'ARForms-Stripe').'</div>
                </div>
            </div>';           	 	
		}

	}
	
	function arf_before_submission_process_payment( $values ){
		
		global $wpdb, $arfrecordmeta, $arfsettings,$arf_stripe;
		
		$form_id = isset($values['form_id']) ? $values['form_id'] : '';

		if( $form_id == '' ){
			return;
		}
		
		$form_data 	= $wpdb->get_results( $wpdb->prepare('SELECT * FROM  '.$arf_stripe->db_stripe_forms.' WHERE form_id = %d', $form_id) );
				
		if( ! $form_data || count($form_data) < 1 )
			return $values;
		
		$form_data 	= $form_data[0];
		
		$form_options	= maybe_unserialize( $form_data->options );
		
		$item_meta	= $values['item_meta'];
		
		
		$mapped_conditional_field = array();
		if( $form_options['stripe_condition'] && $form_options['stripe_condition'] == 1 )
		{
			$rules = $form_options['conditional_logic']['rules'] ? $form_options['conditional_logic']['rules'] : array();				
			if( $rules )
			{
				foreach( $rules as $rule )
				{
					if( $rule['field_id'] != '' )
						$mapped_conditional_field[] = $rule['field_id']; 													
				}				
			}				  
		}
			
		if( $item_meta )
		{
			foreach($item_meta as $field_id => $field_value)
			{					
				if( $mapped_conditional_field )
				{
					foreach($mapped_conditional_field as $rule_field)
					{
						if( $rule_field == $field_id )
							$mapped_field_values[$field_id] = $field_value;  								
					}
				}
																								 
			}			
		}
		
		
		if( $form_options['stripe_condition'] && $form_options['stripe_condition'] == 1 )
		{
			$rules = $form_options['conditional_logic']['rules'] ? $form_options['conditional_logic']['rules'] : array();
			
			if( $rules )
			{
				$matched = 0;
				$total_rules = 0;
				
				foreach( $rules as $rule )
				{
					if( $rule['field_id'] != '' )
					{
						$total_rules++;
						
						$value1 = isset( $mapped_field_values[ $rule['field_id'] ] ) ? $mapped_field_values[ $rule['field_id'] ] : '';
						
						$value1 = is_array($value1) ? $value1 : trim( strtolower($value1) );
	
						$value2 = @trim( strtolower( $rule['value'] ) );
						
						$operator = $rule['operator'];
						
                        if ($this->calculate_rule($value1, $value2, $operator, $rule['field_type']))
							$matched++;								
					}
						
				}
				
				
				if( ($form_options['conditional_logic']['if_cond'] == 'all' && $total_rules == $matched) || ($form_options['conditional_logic']['if_cond'] == 'any' && $matched > 0) )
				{
					
				}
				else
				{
					
					return $values;
				}
				
			}
			  
		}
		
		
		if( $form_options['stripe_mode'] == '1' )
		{
			if( ! isset($form_options['live_secret_key']) or empty( $form_options['live_secret_key'] ) )
				return $values;
				
			if( ! isset($form_options['live_publishable_key']) or empty( $form_options['live_publishable_key'] ) )
				return $values;		
		}
		else
		{
			if( ! isset($form_options['test_secret_key']) or empty( $form_options['test_secret_key'] ) )
				return $values;
				
			if( ! isset($form_options['test_publishable_key']) or empty( $form_options['test_publishable_key'] ) )
				return $values;
		}
		
		if( !$form_options['card_number'] || !$form_options['exp_month'] || !$form_options['exp_year'] || !$form_options['cvc'] )
			return $values;	
		
		if( $form_options['payment_type'] != 'subscription' && !$form_options['amount'] && $form_options['arf_payment_type']=="arf_payment_type_single")
			return $values;
		
		$card_holder_name = "";
		$card_number	= "";
		$exp_month		= "";
		$exp_year		= "";
		$cvc			= "";
		$amount			= ""; 
		
		if( $item_meta )
		{
			foreach($item_meta as $field_id => $field_value)
			{				
				if( $field_id == $form_options['card_number'] && $field_value != '' )
					$card_number = $field_value;
					
				if( $field_id == $form_options['exp_month'] && $field_value != '' )
					$exp_month = $field_value;								
				
				if( $field_id == $form_options['exp_year'] && $field_value != '' )
					$exp_year = $field_value;		
					
				if( $field_id == $form_options['cvc'] && $field_value != '' )
					$cvc = $field_value;		
					
				if( $field_id == $form_options['amount'] && $field_value != '' )
					$amount = $field_value;

				if( $field_id == $form_options['card_holder_name'] && $field_value != '' )
					$card_holder_name = $field_value;																	 
			}			
		}
		if(file_exists(ARF_STRIPE_DIR . "/lib/init.php")){
			require_once ARF_STRIPE_DIR . "/lib/init.php";
		}
		
		$apikey ="";
		
		if( $form_options['stripe_mode'] == '1' )
			$apikey = $form_options['live_secret_key']; 
		else
			$apikey = $form_options['test_secret_key']; 
		
		\ARFStripe\ARFStripe::setApiKey( $apikey );
		
		$currency	= ( $form_options['currency'] ) ? $form_options['currency'] : 'USD'; 
		
		$amount		= $amount ? ( is_float($amount) ? ($amount * 10000) : ($amount * 100) ) : "0";	
		
		$fname 		= "";
		$lname		= "";
		$email		= "";
		$address1	= "";
		$address2	= "";
		$city		= "";
		$state		= "";
		$zip		= "";
		$country	= "";
		if( isset($form_options['shipping_info']) && $form_options['shipping_info'] == 1 )
		{
			if( $item_meta )
			{
				foreach($item_meta as $field_id => $field_value)
				{
					if( $field_id == $form_options['first_name'] && $field_value != '' )
						$fname = $field_value;
					
					if( $field_id == $form_options['last_name'] && $field_value != '' )
						$lname = $field_value;
					
					if( $field_id == $form_options['email'] && $field_value != '' )
						$email = $field_value;
					
					if( $field_id == $form_options['address'] && $field_value != '' )
						$address1 = $field_value;
						
					if( $field_id == $form_options['address_2'] && $field_value != '' )
						$address2 = $field_value;
					
					if( $field_id == $form_options['city'] && $field_value != '' )
						$city = $field_value;
					
					if( $field_id == $form_options['state'] && $field_value != '' )
						$state = $field_value;
					
					if( $field_id == $form_options['zip'] && $field_value != '' )
						$zip = $field_value;
					
					if( $field_id == $form_options['country'] && $field_value != '' )
						$country = $field_value;																		
				}
			}
			
		}

		if(empty($card_holder_name))
		{
			$card_holder_name = $fname ." ".$lname;
		}
		
		try {
			$card_detail = array( 
							"number" 	=> $card_number, 
							"exp_month" => $exp_month, 
							"exp_year" 	=> $exp_year, 
							"cvc" 		=> $cvc,
							'name' 		=> $card_holder_name,
							'address_line1'	=> $address1,
							'address_line2'	=> $address2,
							'address_city'	=> $city,
							'address_zip' 	=> $zip,
							'address_state' => $state,
							'address_country' => $country, 
							);
			
			$token = \ARFStripe\Token::create(array( "card" => $card_detail ) );
            		$request_token = $token->id;
			
			if($form_options['arf_payment_type'] == 'arf_payment_type_multiple'){
				
				$as__payment_type =  $this->arf_get_multiple_payment_type($values,$form_data);
				
				if(!empty($as__payment_type) && $as__payment_type['type'] != 'product_service' && $as__payment_type['type'] != 'subscription' ){
					return false;
				}		
				if(!empty($as__payment_type)){
					if($as__payment_type['type'] == 'product_service'){
						$amount = $as__payment_type['amount'];
						$amount		= $amount ? ( is_float($amount) ? ($amount * 10000) : ($amount * 100) ) : "0";	
						
						$options['payment_type'] = $as__payment_type['type'];
						
						$charge_details	= array(
									'card' 			=> $request_token, 
									'amount' 		=> $amount, 
									'currency' 		=> $currency, 
									'metadata' 		=> array( 'form_id' => $form_id ),
									);
									
						if( $email && $email != "" )
							$charge_details['receipt_email']	= $email;
						
						if( $form_options['title'] && $form_options['title'] != "" )
							$charge_details['description']	= $form_options['title'];
						
						$charge = \ARFStripe\Charge::create( $charge_details );
						
						$payment_type_flag = "0";
						
                        $stripe_payment_order_id = $this->process_after_stripe_payment($charge, $form_id, $form_options, $email, $payment_type_flag);
					}
					
					if($as__payment_type['type'] == 'subscription'){
						$amount = $as__payment_type['amount'];
						$options['payment_type'] = $as__payment_type['type'];
						
						$planID = $as__payment_type['plan_detail']['arf_stripe_multipayment_plan_id'];
							
						
						$customer_card_detail = array( 'card' => $request_token );
						
						if( $email && $email != "" )
							$customer_card_detail['email']	= $email;
								
						$customer	= \ARFStripe\Customer::create( $customer_card_detail );
						$sub = $customer->subscriptions->create(
														array(
															'plan' 		=> $planID,
															'quantity'	=> 1,
															'metadata' 	=> array( 'form_id' => $form_id ),
															)
														);
						$payment_type_flag = "1";
						
                        $stripe_payment_order_id = $this->process_after_stripe_payment($sub, $form_id, $form_options, $email, $payment_type_flag);
												
					}
					
				}
				
				$values['item_meta']['-91']	= $stripe_payment_order_id;
				
				
				$card_number_new	= @substr_replace($card_number, str_repeat('X', strlen($card_number) - 4), 0, -4);
				$values['item_meta'][ $form_options['card_number'] ]= $card_number_new;
				$values['item_meta'][ $form_options['exp_month'] ]	= "";
				$values['item_meta'][ $form_options['exp_year'] ]	= "";
				$values['item_meta'][ $form_options['cvc'] ]		= "";
				
			}else {
				
			    if( $form_options['payment_type'] == 'subscription' )
			    {	


				$planID = ($form_options['stripe_plan_id']) ? $form_options['stripe_plan_id'] : ""; 


					$customer_card_detail = array( 'card' => $request_token );

				if( $email && $email != "" )
					$customer_card_detail['email']	= $email;    

					$customer	= \ARFStripe\Customer::create( $customer_card_detail );
				$sub = $customer->subscriptions->create(
												array(
													'plan' 		=> $planID,
													'quantity'	=> 1,
													'metadata' 	=> array( 'form_id' => $form_id ),
													)
												);
				$payment_type_flag = "1";

				$stripe_payment_order_id = $this->process_after_stripe_payment($sub, $form_id, $form_options, $email, $payment_type_flag);
			    }
			    else
			    {
				    $charge_details	= array(
							    'card' 			=> $request_token, 
							    'amount' 		=> $amount, 
							    'currency' 		=> $currency, 
							    'metadata' 		=> array( 'form_id' => $form_id ),
							    );

				    if( $email && $email != "" )
					    $charge_details['receipt_email']	= $email;

				    if( $form_options['title'] && $form_options['title'] != "" )
					    $charge_details['description']	= $form_options['title'];

					$charge = \ARFStripe\Charge::create( $charge_details );

				    $payment_type_flag = "0";
				    $arf_stripe_payment_status = '';


		$stripe_payment_order_id = $this->process_after_stripe_payment($charge, $form_id, $form_options, $email, $payment_type_flag, $arf_stripe_payment_status);

			    }

			    $values['item_meta']['-91']	= $stripe_payment_order_id;


			    $card_number_new	= @substr_replace($card_number, str_repeat('X', strlen($card_number) - 4), 0, -4);
			    $values['item_meta'][ $form_options['card_number'] ]= $card_number_new;
			    $values['item_meta'][ $form_options['exp_month'] ]	= "";
			    $values['item_meta'][ $form_options['exp_year'] ]	= "";
			    $values['item_meta'][ $form_options['cvc'] ]		= "";
			}
		} catch(Stripe_CardError $e) { 
			$values	= array( 'item_meta' => array( '-92'	=> $form_id.'|'.'card_error'.'|'.$e->getMessage() ) );
		} catch (Stripe_InvalidRequestError $e) { 
			
			$values	= array( 'item_meta' => array( '-92'	=> $form_id.'|'.'payment_error'.'|'.$e->getMessage() ) );
		} catch (Stripe_AuthenticationError $e) { 
			
			$values	= array( 'item_meta' => array( '-92'	=> $form_id.'|'.'payment_error'.'|'.$e->getMessage() ) );
		} catch (Stripe_ApiConnectionError $e) { 
			
			$values	= array( 'item_meta' => array( '-92'	=> $form_id.'|'.'payment_error'.'|'.$e->getMessage() ) );
		} catch (Stripe_Error $e) { 
			
			$values	= array( 'item_meta' => array( '-92'	=> $form_id.'|'.'payment_error'.'|'.$e->getMessage() ) );
		} catch (Exception $e) { 
			
			$values	= array( 'item_meta' => array( '-92'	=> $form_id.'|'.'payment_error'.'|'.$e->getMessage() ) );
		}
		
		return $values;
	}
	
	function process_after_stripe_payment( $charge, $form_id, $form_options, $payer_email, $payment_type_flag=0 ) {
	    
        global $wpdb, $arfrecordmeta, $arfsettings, $arf_stripe, $arnotifymodel;
		
		$created_at 	= current_time('mysql', 0);
		$payment_type	= 0;
		$transaction_id	= $charge->id ? $charge->id : ''; 
		$payment_status	= ( $charge->paid ) ? 'Completed' : 'Pending';
		$amount			= floatval( $charge->amount / 100 );
		$currency		= strtoupper($charge->currency); 

		if( $payment_type_flag==1 )
		{
			$payment_type	= 1;
			$transaction_id	= $charge->id ? $charge->id : '';
			$payment_status = $charge->id ? 'Completed' : 'Pending';
			$amount			= floatval( $charge->plan['amount'] / 100 );
			$currency		= strtoupper($charge->plan['currency']); 
		}
					
		$insert_array = array(
				'item_name' 		=> $form_options['title'],
				'txn_id'		=> $transaction_id,
				'payment_status' 	=> $payment_status,
				'mc_gross' 		=> $amount,
				'mc_currency' 		=> $currency,
				'quantity' 		=> 1,
				'payer_email'		=> $payer_email,
				'payment_type'		=> $payment_type,
				'user_id'		=> get_current_user_id(),
				'entry_id'		=> '',
				'form_id'		=> $form_id,
				'created_at'		=> $created_at,
				);
																
		$wpdb->insert( $arf_stripe->db_stripe_order, $insert_array, array('%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%d', '%d', '%d', '%s') );

		
		
		return $wpdb->insert_id; 		
	}
	
	function arf_change_entry_id( $entry_id, $form_id )
	{
	    global $wpdb, $arfrecordmeta, $arfsettings,$arf_stripe,$armainhelper,$arfieldhelper,$arnotifymodel;

	    if(empty($entry_id)){
	    	return;
	    }
	    $form_data 	= $wpdb->get_results( $wpdb->prepare('SELECT * FROM  '.$arf_stripe->db_stripe_forms.' WHERE form_id = %d', $form_id) );

	    if( !$form_data || count($form_data) < 1 ){
			return;	    	
	    }

	    $entry_ids = array( $entry_id );
	    $values = $arfrecordmeta->getAll("it.field_id != 0 and it.entry_id in (". implode(',', $entry_ids).")", " ORDER BY fi.id");

	    if( $values ){
			foreach($values as $field){
			    if( $field->field_id == '-91' && $field->entry_value != '' )
				$wpdb->update($arf_stripe->db_stripe_order, array('entry_id' => $entry_id), array('id' => $field->entry_value ));
			}
	    }

	    $form_options = maybe_unserialize($form_data[0]->options);

        $stripe_order = $wpdb->get_row( $wpdb->prepare("SELECT * FROM `".$arf_stripe->db_stripe_order."` WHERE entry_id = %d",$entry_id) );

        if( isset($stripe_order) && count($stripe_order) > 0){
        	$transaction_id = $stripe_order->txn_id;
	        $payment_status = $stripe_order->payment_status;
	        $amount = $stripe_order->mc_gross;
	        $payment_currency = $stripe_order->mc_currency;
	        $created_at = $stripe_order->created_at;
	        if(isset($stripe_order->payer_email)){
	            $payer_email = $stripe_order->payer_email;
	        }

		    if( ((isset($form_options['notification']) and $form_options['notification']) || ((isset($form_options['user_notification']) and $form_options['user_notification']))) and $this->is_arforms_support() ) {
				global $arfsettings,$MdlDb;
				
				$arf_form_data = $wpdb->get_results( $wpdb->prepare("SELECT * FROM ".$MdlDb->forms." WHERE id = %d", $form_id) );
				$arf_form_data = $arf_form_data[0];	
				$arf_options = maybe_unserialize($arf_form_data->options);
			
				$arfblogname = wp_specialchars_decode( get_option('blogname'), ENT_QUOTES );

				$item_name 			= $form_options['title'];
				$txn_id 			= $transaction_id;
				$payment_status 	= $payment_status;
				$payment_amount 	= $amount;
				//$payment_currency 	= $currency;
				$payment_date 		= date( get_option('date_format'), strtotime($created_at) );

				$entry = $wpdb->get_row($wpdb->prepare("SELECT * FROM `".$MdlDb->entries."` WHERE id = %d",$entry_id));

				$admin_email = $arf_options['reply_to'];
				if( !is_email($admin_email) ) {
					$admin_email = $arfsettings->reply_to;
				}
				$admin_from_reply =  $arf_options['ar_admin_from_email'];
				if( ! is_email($admin_from_reply) ) {
					$admin_from_reply = $admin_email;
				}

				$reply_to_name = (isset($arf_options['ar_admin_from_name'])) ? $arf_options['ar_admin_from_name'] : $arfsettings->reply_to_name;

				if( isset($admin_from_reply) && $admin_from_reply != '' ){
	                $shortcodes = $armainhelper->get_shortcodes($admin_from_reply, $form_id);
	                $reply_to = $arfieldhelper->replace_shortcodes($admin_from_reply, $entry, $shortcodes);
	                $reply_to = trim($reply_to);
	                $admin_from_reply = $arfieldhelper->arf_replace_shortcodes($reply_to,$entry);
	            }

	            $admin_nreply_to = isset($arf_options['ar_admin_reply_to_email']) ? $arf_options['ar_admin_reply_to_email'] : $arfsettings->reply_to_email;

	            if( isset($admin_nreply_to) && $admin_nreply_to != '' ){
	                $shortcodes = $armainhelper->get_shortcodes($admin_nreply_to, $form_id);
	                $reply_to = $arfieldhelper->replace_shortcodes($admin_nreply_to, $entry, $shortcodes);
	                $reply_to = trim($reply_to);
	                $admin_nreply_to = $arfieldhelper->arf_replace_shortcodes($reply_to, $entry);
	            }

	            $user_from_email = isset($arf_options['ar_user_from_email']) ? $arf_options['ar_user_from_email'] : $arfsettings->reply_to;

	            if( isset($user_from_email) && $user_from_email != '' ){
	                $shortcodes = $armainhelper->get_shortcodes($user_from_email, $form_id);
	                $reply_to = $arfieldhelper->replace_shortcodes($user_from_email, $entry, $shortcodes);
	                $reply_to = trim($reply_to);
	                $user_from_email = $arfieldhelper->arf_replace_shortcodes($reply_to, $entry);
	            }
	            
	            $user_reply_to_email = isset($arf_options['ar_user_nreplyto_email']) ? $arf_options['ar_user_nreplyto_email'] : $arfsettings->reply_to_email;

	            if( isset($user_reply_to_email) && $user_reply_to_email != '' ){
	                $shortcodes = $armainhelper->get_shortcodes($user_reply_to_email, $form_id);
	                $reply_to = $arfieldhelper->replace_shortcodes($user_reply_to_email, $entry, $shortcodes);
	                $reply_to = trim($reply_to);
	                $user_reply_to_email = $arfieldhelper->arf_replace_shortcodes($reply_to, $entry);
	            }

	            $user_reply_to_name = isset($arf_options['ar_user_from_name']) ? $arf_options['ar_user_from_name'] : $arfsettings->reply_to_name;

				if(isset($form_options['notification']) and $form_options['notification']) {

					$subject = __('Payment received on', 'ARForms-Stripe').' '.$arfblogname;
					$message = nl2br($form_options['email_content']);
					
					if( empty($message) ) {
						$message = $arf_stripe->defalut_email_content();
					}
					
					$message = str_replace('[transaction_id]', $txn_id, $message);
					$message = str_replace('[amount]', floatval($payment_amount), $message);
					$message = str_replace('[currency]', $payment_currency, $message);
					$message = str_replace('[payment_date]', $payment_date, $message);
					$message = str_replace('[site_name]', $arfblogname, $message);

					$arnotifymodel->send_notification_email_user($admin_email, $subject, $message, $admin_from_reply, $reply_to_name, true, array(),false,false,true,false,$admin_nreply_to);
				}

				if (isset($form_options['user_notification']) and $form_options['user_notification'] and isset($payer_email)) {
		            $user_subject = __('Payment received on', 'ARForms-Stripe') . ' ' . $arfblogname;
		            $user_message = nl2br($form_options['user_email_content']);

		            if (empty($user_message)) {
		                $user_message = $arf_authnet->user_defalut_email_content();
		            }

		            $user_message = str_replace('[transaction_id]', $txn_id, $user_message);
		            $user_message = str_replace('[amount]', floatval($payment_amount), $user_message);
		            $user_message = str_replace('[currency]', $payment_currency, $user_message);
		            $user_message = str_replace('[payment_date]', $payment_date, $user_message);
		            $user_message = str_replace('[site_name]', $arfblogname, $user_message);

		           	$arnotifymodel->send_notification_email_user($payer_email, $user_subject, $user_message, $user_from_email, $user_reply_to_name, true,array(),false,false,true,false,$user_reply_to_email);
		        }
			}
        }
	}
	
	function arf_change_entryid_fail( $entry_id, $form_id )
	{
		global $wpdb, $arfrecordmeta, $arfsettings;
		if(empty($entry_id)){
	    	return;
	    }
		$entry_ids = array( $entry_id );
		
		$values = $arfrecordmeta->getAll("it.field_id != 0 and it.entry_id in (". implode(',', $entry_ids).")", " ORDER BY fi.id");
		$form_id2 = "";
		if( $values )
		{
			foreach($values as $field)
			{
				if( $field->field_id == '-92' && $field->entry_value != '' )
				{
					$fieldvalue = explode('|', $field->entry_value);
					if( $fieldvalue[1] == 'payment_error' || $fieldvalue[1] == 'card_error' )
						$form_id2	= $fieldvalue[0];	 
				}	
			}
		}
		
		if( ! $form_id2 )
			return $entry_id;
			global $arf_stripe;
		$form_data 	= $wpdb->get_results( $wpdb->prepare('SELECT * FROM  '.$arf_stripe->db_stripe_forms.' WHERE form_id = %d', $form_id2) );
				
		if( !$form_data || count($form_data) < 1 )
			return $entry_id;
		
		$form_data 	= $form_data[0];
		
		$form_options	= maybe_unserialize( $form_data->options );

		if( isset($form_options['enable_debug_mode']) && $form_options['enable_debug_mode'] == 1 ){
			$arfsettings->failed_msg = $fieldvalue[2];
		} else {
			if( $fieldvalue[1] == 'card_error' ){
				if( isset($form_options['invalid_card']) && ! empty( $form_options['invalid_card'] ) )
					$arfsettings->failed_msg = $form_options['invalid_card'];
				else
					$arfsettings->failed_msg = __('Please enter correct card details.', 'ARForms-Stripe');
			} else {
				if( isset($form_options['payment_failure']) && ! empty( $form_options['payment_failure'] ) )
					$arfsettings->failed_msg = $form_options['payment_failure'];
				else
					$arfsettings->failed_msg = __('Sorry something went wrong while processing payment.', 'ARForms-Stripe');
			}
		}
				
		return false;	
	}
	
	function arfprechangestripeformcols($form_cols, $form_id)
	{
		if( ! $form_id )
			return $form_cols;
			
		global $wpdb,$arf_stripe;
		if(isset($GLOBALS['arf_form_stripe_not_set'][$form_id])) { 
            return $form_cols;
        }
        if(!isset($GLOBALS['arf_form_stripe_form_data'][$form_id])) 
        {
            $form_data2 = $wpdb->get_results( $wpdb->prepare('SELECT * FROM '.$arf_stripe->db_stripe_forms.' WHERE form_id = %d', $form_id) );
            if (count($form_data2) < 1){
                $GLOBALS['arf_form_stripe_not_set'][$form_id] = true;
                return $form_cols;
            }
            $form_data2 = $form_data2[0];
            $GLOBALS['arf_form_stripe_form_data'][$form_id] = $form_data2;
        } else {
            $form_data2 = $GLOBALS['arf_form_stripe_form_data'][$form_id];
        }
		$form_options = maybe_unserialize( $form_data2->options ); 
		
		if( $form_cols )
		{
			foreach($form_cols as $col_key => $col_val)	
			{
				if( $form_options['exp_month'] == $col_val->id )
					unset($form_cols[ $col_key ]);
					
				if( $form_options['exp_year'] == $col_val->id )
					unset($form_cols[ $col_key ]);
					
				if( $form_options['cvc'] == $col_val->id )
					unset($form_cols[ $col_key ]);		
			}
		}
		$form_cols = array_values($form_cols);
		return $form_cols;
	}
	
    function add_new_rule_stripe_v3() {
	global $arf_stripe,$arffield;
		$form_id= $_POST['form_id'];	
		$rule_i = $_POST['next_rule_id'] ? $_POST['next_rule_id'] : 1;
		$field_array = array();
		if(isset($form_id) && $form_id != '' && $form_id != '0'){
		    $field_array =  $arffield->getAll("fi.form_id=" . (int) $form_id, 'id');
		}
		?>
        <input type="hidden" name="rule_array_stripe[]" value="<?php echo $rule_i; ?>" />
        <div class="sltstandard" style="float:none; display:inline;"><?php echo $arf_stripe->arf_cl_field_menu($form_id, 'arf_cl_field_stripe_' . $rule_i, 'arf_cl_field_stripe_' . $rule_i,'',$field_array); ?></div>
        &nbsp;
        <div class="sltstandard" style="float:none; display:inline; margin-left: 15px;"><?php echo $arf_stripe->arf_cl_rule_menu('arf_cl_op_stripe_' . $rule_i, 'arf_cl_op_stripe_' . $rule_i, 'is'); ?></div>
        &nbsp;
        <input type="text" name="cl_rule_value_stripe_<?php echo $rule_i; ?>" id="cl_rule_value_stripe_<?php echo $rule_i; ?>" class="txtmodal1" value="" style=" width:auto !important;margin-left: 15px;"/>
        &nbsp;
        <span class="bulk_add_remove">
            <span onclick="arf_add_new_law_stripe();" class="bulk_add">
		<svg viewBox="0 -4 32 32">
		    <g><?php echo((ARF_PLUS_ICON!='')?ARF_PLUS_ICON:'');?></g>
		</svg>
	    </span>
            <span onclick="delete_rule_stripe(this);" class="bulk_remove">
		<svg viewBox="0 -4 32 32">
		    <g><?php echo((ARF_MINUS_ICON!='')?ARF_MINUS_ICON:'');?></g>
		</svg>
	    </span>
        </span>
        <?php
		
	die();
	}
	
    function add_new_rule_stripe() {
        global $arf_stripe,$arffield;
		$form_id= $_POST['form_id'];	
		$rule_i = $_POST['next_rule_id'] ? $_POST['next_rule_id'] : 1;
		$field_array = array();
		if(isset($form_id) && $form_id != '' && $form_id != '0'){
		    $field_array =  $arffield->getAll("fi.form_id=" . (int) $form_id, 'id');
		}

		?>
        <input type="hidden" name="rule_array_stripe[]" value="<?php echo $rule_i; ?>" />
        <div class="sltstandard" style="float:none; display:inline;"><?php echo $arf_stripe->arf_cl_field_menu($form_id, 'arf_cl_field_stripe_' . $rule_i, 'arf_cl_field_stripe_' . $rule_i,'',$field_array); ?></div>
        &nbsp;
        <div class="sltstandard" style="float:none; display:inline;"><?php echo $arf_stripe->arf_cl_rule_menu('arf_cl_op_stripe_' . $rule_i, 'arf_cl_op_stripe_' . $rule_i, 'is'); ?></div>
        &nbsp;
        <input type="text" name="cl_rule_value_stripe_<?php echo $rule_i; ?>" id="cl_rule_value_stripe_<?php echo $rule_i; ?>" class="txtstandardnew" value="" />
        &nbsp;
        <span class="bulk_add_remove">
            <button type="button" onclick="arf_add_new_law_stripe();" class="bulk_add">&nbsp;</button>
            <span onclick="delete_rule_stripe(this);" class="bulk_remove">&nbsp;</span>
        </span>
        <?php
		
	die();
	}
	
	function arf_cl_field_menu($form_id, $select_name, $select_id='', $default_field_id=0,$field_array){
		
    global $arffield, $arfieldhelper,$is_version_compatible;
	$exclude    = array('divider', 'captcha', 'break', 'file');
	$field_list = isset($field_array)?$field_array:array();
	$select_id  = (isset($select_id)) ? $select_id : $select_name; 
	
	 global $armainhelper;
            $selected_list_id = "";
            $selected_list_label = __('Select Field', 'ARForms-Stripe');
            $responder_list_option = "";
            if (count($field_list) > 0) { //echo '<pre>';print_r($field_list);echo '</pre>';exit;
                $cntr = 0;
                foreach ($field_list as $field) {
		    if(in_array($field->type,$exclude)){ continue;}
		    
                    if($default_field_id == $field->id)
                    {
                        $selected_list_id = $field->id;
                        $selected_list_label = $field->name;
                    }
                    $responder_list_option .= '<li class="arf_selectbox_option" data-value="'.$field->id.'" data-label="'.$arfieldhelper->arf_execute_function($field->name,'strip_tags').'">'.$armainhelper->truncate($arfieldhelper->arf_execute_function($field->name,'strip_tags'), 33).'</li>';
                $cntr++;
                }
            }
	   
            ?>
            <?php if($is_version_compatible){?>
            <input id="<?php echo $select_name; ?>"  name="<?php echo $select_name; ?>" value="<?php echo $selected_list_id; ?>" type="hidden" >
            <dl class="arf_selectbox" data-name="<?php echo $select_name; ?>" data-id="<?php echo $select_name;?>" style="width:131px;">
                <dt><span><?php echo $arfieldhelper->arf_execute_function($selected_list_label,'strip_tags'); ?></span>
                <input value="<?php echo $selected_list_id; ?>" style="display:none;" class="arf_autocomplete" type="text" style="width:118px;" autocomplete="off">
                <svg viewBox="0 0 2000 1000" width="15px" height="15px">
                <g fill="#000">
                <path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
                </g>
                </svg>
                </dt>
                <dd>
                    <ul style="display: none;width:131px;" data-id="<?php echo $select_name; ?>" id="<?php echo 'add_field_'.$select_id?>" class="arf_stripe_fields">
                    <?php echo $responder_list_option;?>
                    </ul>
                </dd>
            </dl>
	<?php }else{
			echo '<select name="'.$select_name.'" id="'.$select_id.'" class="arf_stripe_fields field_dropdown_menu" data-size="6" data-width="150px">';
			echo '<option value="">'.__('Select Field', 'ARForms-Stripe').'</option>';

			
				$fields = $field_array;
				if( count($fields) > 0 ) {			
			    foreach($fields as $field) {
			    if(in_array($field->type,$exclude)){
				continue;
			    }	
			    $field_id = $arfieldhelper->get_actual_id($field->id);
			    	if($default_field_id != 0 and $default_field_id == $field_id)
				    echo '<option value="'.$field_id.'" selected="selected">'.$field->name.'</option>';
				else
				    echo '<option value="'.$field_id.'">'.$field->name.'</option>';
			    }
			}?>	
		</select>
		<?php 
		}
	}
	
	function arf_cl_rule_menu($select_name, $select_id='', $default_rule='is'){
		$conditional_rules = array(
		    'is' 			=> __('equals', 'ARForms-Stripe'),
		    'is not' 		=> __('not equals', 'ARForms-Stripe'),
		    'greater than' 	=> __('greater than', 'ARForms-Stripe'),
		    'less than' 	=> __('less than', 'ARForms-Stripe'),
		    'contains' 		=> __('contains', 'ARForms-Stripe'),
		    'not contains' 	=> __('not contains', 'ARForms-Stripe'),
		);
		
		$select_id = (isset($select_id)) ? $select_id : $select_name; 
	    
		global $armainhelper,$is_version_compatible;
		unset($responder_list_option);
		$responder_list_option = '';
		$id = (isset($id) && $id != '')?$id:'';
		$cnt =0;
		foreach ($conditional_rules as $rule_id => $rule) {
		    if($default_rule == $rule_id){
			$selected_list_id = $rule_id;
			$selected_list_label = $rule;
		    }
		    else if($cnt==0){
			$selected_list_id = $rule_id;
			$selected_list_label = $rule;
		    }
		    $cnt++;
		   $responder_list_option .= '<li class="arf_selectbox_option" data-value="'.$rule_id.'" data-label="'.$rule.'">'.$rule.'</li>';
		}
           
	   
            ?>
            <?php if($is_version_compatible){?>
            <input id="<?php echo $select_name; ?>"  name="<?php echo $select_name; ?>" value="<?php echo $default_rule; ?>" type="hidden" >
            <dl class="arf_selectbox" data-name="<?php echo $select_name; ?>" data-id="<?php echo $select_name;?>" style="width:131px;">
                <dt><span><?php echo $selected_list_label; ?></span>
                <input value="<?php echo $selected_list_id; ?>" style="display:none;" class="" type="text" style="width:118px;">
                <svg viewBox="0 0 2000 1000" width="15px" height="15px">
                <g fill="#000">
                <path d="M1024 320q0 -26 -19 -45t-45 -19h-896q-26 0 -45 19t-19 45t19 45l448 448q19 19 45 19t45 -19l448 -448q19 -19 19 -45z"></path>
                </g>
                </svg>
                </dt>
                <dd>
                    <ul style="display: none;width:131px;" data-id="<?php echo $select_name; ?>" id="<?php echo 'add_field_'.$select_id?>" class="operator_dropdown_menu">
                    <?php echo $responder_list_option;?>
                    </ul>
                </dd>
            </dl>
	    <?php 
		} else {
			echo '<select name="'.$select_name.'" class="operator_dropdown_menu" id="'.$select_id.'" data-width="150px">';	
				foreach($conditional_rules as $rule_id => $rule) {
					
					if( isset($default_rule) and $default_rule == $rule_id)
						echo '<option value="'.$rule_id.'" selected="selected">'.$rule.'</option>';
					else
						echo '<option value="'.$rule_id.'">'.$rule.'</option>';
				}	
			echo '</select>';
		
		}
	}
	
	function calculate_rule($value1, $value2, $operator, $field_type)
	{
            global $arfieldhelper;
		if( $field_type == 'checkbox' ){
			$chk = 0;
            global $arfieldhelper;
			$default_value = maybe_unserialize( $value1 );
			
			if( $default_value && is_array($default_value) )
			{
				foreach($default_value as $chk_value)
				{
					$value1 = trim( strtolower($chk_value) );		
                    if ($arfieldhelper->ar_match_rule($value1, $value2, $operator))
						$chk++;
				}
			}
            else if ($arfieldhelper->ar_match_rule($value1, $value2, $operator)) {
				$chk++;
			}
			
			if($chk > 0) 
				return true; 
			else 
				return false;							
		} else {
			
			return $arfieldhelper->ar_match_rule($value1, $value2, $operator);
		}
		
		return false;
	}
	
    function add_new_rule_stripe_multiple_subscription_v3() {
        global $arf_stripe,$arffield;
		
		$form_id= $_POST['form_id'];	
		$rule_i = $_POST['next_rule_id'] ? $_POST['next_rule_id'] : 1;
		$duration_name = $_POST['duration_name'] ? $_POST['duration_name'] : '';
		$field_array = array();
		if(isset($form_id) && $form_id != ''){
		    $field_array =  $arffield->getAll("fi.form_id=" . (int)$form_id, 'id');
		}
		?>
        	 <input type="hidden"  name="rule_array_multiple_subscription[]" value="<?php echo $rule_i; ?>" />
                    <div class="arf_form_dropdown">
                    	<label class="lblsubtitle" style="float:left; margin-right:5px;text-align:right;padding-top:10px;"><b><?php _e('Plan / Product ID', 'ARForms-Stripe'); ?></b></label>&nbsp;&nbsp;<span class="arfglobalrequiredfield" style="float:left; margin:5px; vertical-align:middle">*</span>
                        
                        <div class="sltstandard" style="float:left;" >
                        	<input type="text" name="arf_stripe_multipayment_plan_id_<?php echo $rule_i; ?>" id="arf_stripe_multipayment_plan_id_<?php echo $rule_i; ?>" style="width:485px;" class="txtmodal1" value="<?php if(isset($rule["arf_stripe_multipayment_plan_id"])) { echo $rule["arf_stripe_multipayment_plan_id"];  } ?>" />                     		
                    	</div>
                        
                        <label class="lblsubtitle" style="float:left; margin:10px 5px;"><?php _e('If', 'ARForms-Stripe'); ?></label>
                      
                        <span class="bulk_add_remove_subscription_multiple" style="float:left; margin-top:8px;">
			    
			    <span onclick="arf_add_new_law_multiple_subscription();" class="bulk_add">
				<svg viewBox="0 -4 32 32">
				    <g><?php echo((ARF_PLUS_ICON!='')?ARF_PLUS_ICON:'');?></g>
				</svg>
			    </span>
			    <span onclick="delete_rule_multiple_subscription(this);" class="bulk_remove" <?php echo(isset($rule_i) && $rule_i=='1')?'style="display:none"':'';?>>
				<svg viewBox="0 -4 32 32">
				    <g><?php echo((ARF_MINUS_ICON!='')?ARF_MINUS_ICON:'');?></g>
				</svg>
			    </span>
			</span>
                      
                        
                        <div style="float: left; margin:10px 0 0px 0px; width: 100%;">	
                        
                            
                            <div class="arf_multiple_subscription_amount_dropdown" style="float:left;margin-left:67px;">
                    <?php echo $arf_stripe->field_dropdown($form_id, 'arf_multiple_subscription_amount_' . $rule_i, 'arf_stripe_fields',  isset($values['arf_multiple_subscription_amount'])?$values['arf_multiple_subscription_amount']:'', "170px", $rule_i,$field_array); ?>
                            	<div class="arferrmessage" id="arf_multiple_subscription_amount_<?php echo $rule_i;?>_msg" style="display:none; clear:both;"><?php _e('This field cannot be blank.', 'ARForms-Stripe');  ?></div>
                            </div> 
                            
                            
				            <div class="arf_amount_dropdown" style="float:left;">
                            
                            <div id="arf_cl_rule_multiple_subscription_type">
                                <div class="sltstandard" style="float:left;margin-left:15px; display:inline;">
                            <?php echo $arf_stripe->arf_cl_rule_menu('arf_cl_op_multiple_subscription_duration_type_' . $rule_i, 'arf_cl_op_multiple_subscription_type_' . $rule_i, isset($values['arf_cl_op_multiple_subscription_type']) ? $values['arf_cl_op_multiple_subscription_type']:'is'); ?>
                				</div>&nbsp;
						<input type="text"  style="width:125px;margin-left:7px;" name="cl_rule_value_multiple_subscription_duration_type_<?php echo $rule_i; ?>" id="cl_rule_value_multiple_subscription_duration_type_<?php echo $rule_i; ?>" class="txtmodal1" value="<?php echo(isset($values['cl_rule_value_multiple_subscription_type_.'.$rule_i])?$values['cl_rule_value_multiple_subscription_type_.'.$rule_i]:''); ?>" />&nbsp;
                            </div>
                            </div> 
						</div>
                     </div>
      				</br>
		<?php
		die();
	}
	
    function add_new_rule_stripe_multiple_subscription() {
        global $arf_stripe,$arffield;
		
		$form_id= $_POST['form_id'];	
		$rule_i = $_POST['next_rule_id'] ? $_POST['next_rule_id'] : 1;
		$duration_name = $_POST['duration_name'] ? $_POST['duration_name'] : '';
		
		$field_array = array();
		if(isset($form_id) && $form_id != ''){
		    $field_array =  $arffield->getAll("fi.form_id=" . (int)$form_id, 'id');
		}
		?>
        	 <input type="hidden"  name="rule_array_multiple_subscription[]" value="<?php echo $rule_i; ?>" />
                    <div class="arf_form_dropdown">
                    	<label class="lblsubtitle" style="float:left; margin-right:5px;text-align:right;padding-top:10px;"><b><?php _e('Plan / Product ID', 'ARForms-Stripe'); ?></b></label>&nbsp;&nbsp;<span class="arfglobalrequiredfield" style="float:left; margin:5px; vertical-align:middle">*</span>
                        
                        <div class="sltstandard" style="float:left;" >
                        	<input type="text" name="arf_stripe_multipayment_plan_id_<?php echo $rule_i; ?>" id="arf_stripe_multipayment_plan_id_<?php echo $rule_i; ?>" style="width:485px;" class="txtstandardnew" value="<?php if(isset($rule["arf_stripe_multipayment_plan_id"])) { echo $rule["arf_stripe_multipayment_plan_id"];  } ?>" />                     		
                    	</div>
                        
                        <label class="lblsubtitle" style="float:left; margin-left:5px;"><?php _e('If', 'ARForms-Stripe'); ?></label>
                      
                        <span class="bulk_add_remove_subscription_multiple" style="float:left; margin-left:8px;">
									<button type="button" onclick="arf_add_new_law_multiple_subscription();" class="bulk_add">&nbsp;</button>
									<span onclick="delete_rule_multiple_subscription(this);" class="bulk_remove">&nbsp;</span>
						</span>
                      
                        
                        <div style="float: left; margin:10px 0 0px 0px; width: 100%;">	
                        
                            
                            <div class="arf_multiple_subscription_amount_dropdown" style="float:left;margin-right:10px;margin-left:68px;">
                    <?php echo $arf_stripe->field_dropdown($form_id, 'arf_multiple_subscription_amount_' . $rule_i, 'arf_stripe_fields', (isset($values['arf_multiple_subscription_amount'])?$values['arf_multiple_subscription_amount']:''), "150px", $rule_i,$field_array); ?>
                            	<div class="arferrmessage" id="arf_multiple_subscription_amount_<?php echo $rule_i;?>_msg" style="display:none; clear:both;"><?php _e('This field cannot be blank.', 'ARForms-Stripe');  ?></div>
                            </div> 
                            
                            
				            <div class="arf_amount_dropdown" style="float:left;">
                            
                            <div id="arf_cl_rule_multiple_subscription_type">
                                <div class="sltstandard" style="float:none; display:inline;">
                            <?php echo $arf_stripe->arf_cl_rule_menu('arf_cl_op_multiple_subscription_duration_type_' . $rule_i, 'arf_cl_op_multiple_subscription_type_' . $rule_i, (isset($values['arf_cl_op_multiple_subscription_type'])?$values['arf_cl_op_multiple_subscription_type']:'')); ?>
                				</div>&nbsp;
						<input type="text"  style="width:163px;" name="cl_rule_value_multiple_subscription_duration_type_<?php echo $rule_i; ?>" id="cl_rule_value_multiple_subscription_duration_type_<?php echo $rule_i; ?>" class="txtstandardnew" value="<?php echo isset($values['cl_rule_value_multiple_subscription_type_.'.$rule_i])?$values['cl_rule_value_multiple_subscription_type_.'.$rule_i]:''; ?>" />&nbsp;
                            </div>
                            </div> 
						</div>
                     </div>
      				</br>
		<?php
		die();
	}
		
	
	function arf_get_multiple_payment_type($values,$form_data){
		global $arfieldhelper;
		$options = maybe_unserialize( $form_data->options );
		$stripe_field_amount = $options['amount'];
		if($options['arf_payment_type'] == 'arf_payment_type_single'){
			return true;
		}		
		$ReturnPaymentType =  array();
		if($options['arf_payment_type'] == 'arf_payment_type_multiple'){
			
			if(isset($options['arf_multiple_product_service_type']) && $options['arf_multiple_product_service_type'] == '1'){
			
				$mapped_field_values_product_service = '';
				$mapped_field_values_product_service_amount = '';
				if( count($values) > 0 ){
					foreach( $values['item_meta'] as $field_id => $value ){		
						if( $options['arf_cl_field_multiple_product_service_type'] == $field_id ){
							$mapped_field_values_product_service = $value;  	
						}
						if( $options['arf_multiple_product_service_amount'] == $field_id ){
							$mapped_field_values_product_service_amount = $value;  	
						}
						
					}
				}

                $field_type = $arfieldhelper->get_field_type($options['arf_cl_field_multiple_product_service_type']);
				
				$value1 = isset($mapped_field_values_product_service ) ? $mapped_field_values_product_service : '';
						
				$value1 = trim(strtolower($value1) );
				
				$value2 = trim( strtolower($options['cl_rule_value_multiple_product_service_type']));
						
				$operator = $options['arf_cl_op_multiple_product_service_type'];
						
                if ($this->calculate_rule($value1, $value2, $operator, $field_type)) {
					$ReturnPaymentType = array(
							'type'	=> 'product_service',
							'amount' => $mapped_field_values_product_service_amount,
					);
				}
				
			}
			
			
			
			if(isset($options['arf_multiple_subscription_type']) && $options['arf_multiple_subscription_type'] == '1'){
				 
				$mapped_field_values_subscription = '';
				$mapped_field_values_subscription_amount = '';
				
				if( count($values) > 0 ){
					foreach( $values['item_meta'] as $field_id => $value ){		
						
						
						if( $options['arf_cl_field_multiple_subscription_type'] == $field_id ){
							$mapped_field_values_subscription = $value;  	
						}
						
						if(isset($subscription_amount) && $subscription_amount == $field_id ){
							$mapped_field_values_subscription_amount = $value;  	
						}
						
					}
				}
						
                $field_type = $arfieldhelper->get_field_type($options['arf_cl_field_multiple_subscription_type']);
				
				$value1 = isset( $mapped_field_values_subscription ) ? $mapped_field_values_subscription : '';
						
				$value1 = trim( strtolower($value1) );
				
				$value2 = trim( strtolower($options['cl_rule_value_multiple_subscription_type'] ) );
						
				$operator = $options['arf_cl_op_multiple_subscription_type'];
				
                if ($this->calculate_rule($value1, $value2, $operator, $field_type)) {
                
					if( count($options['multiple_subscription_conditional_logic']['rules']) > 0 ){
							
						foreach($options['multiple_subscription_conditional_logic']['rules'] as $key => $rules_value){
						
							$mapped_field_values_subscription_amount = $rules_value['arf_multiple_subscription_amount'];
							
                            $conditional_logic_field_type = $arfieldhelper->get_field_type($mapped_field_values_subscription_amount);
							
							
							
							if($mapped_field_values_subscription_amount!="")
							{
								$conditional_logic_value1 = $values['item_meta'][$mapped_field_values_subscription_amount];
							}
							
							$conditional_logic_value1 = isset( $conditional_logic_value1 ) ? $conditional_logic_value1 : '';
							
							$conditional_logic_value1 = trim( strtolower($conditional_logic_value1) );
					
							$conditional_logic_value2 = trim( strtolower($rules_value['value'] ) );
							
							$conditional_logic_operator = $rules_value['operator'];
							
                            if ($this->calculate_rule($conditional_logic_value1, $conditional_logic_value2, $conditional_logic_operator, $conditional_logic_field_type)) {
								$ReturnPaymentType = array(
										'type'	=> 'subscription',
										'amount' => $mapped_field_values_subscription_amount,
										'plan_detail' => $rules_value
									);
							}
						}
					}
				}
			}
		}				
		return $ReturnPaymentType;
	
	}
	
	function arf_stripe_prevent_rocket_loader_script($tag, $handle) {
        return str_replace(' src', ' data-cfasync="false" src', $tag);
    }
	
    function is_arforms_version() {
        if (version_compare($this->get_arforms_version(), '3.0', '>='))
        {
            return true;
        }
        else
        {
            return false;
        }
    }

    function arf_stripe_send_conditional_email($prevent_sending_email,$entry_id,$form_id){

		global $MdlDb,$wpdb;

		if( $prevent_sending_email ){
			return $prevent_sending_email;
		}

        $form_data  = $wpdb->get_results( $wpdb->prepare('SELECT * FROM  '.$this->db_stripe_forms.' WHERE form_id = %d', $form_id) );
        if( !$form_data || count($form_data) < 1 ){
            return $prevent_sending_email;
        } else {
            
            $form_options = maybe_unserialize($form_data[0]->options);

            $mapped_conditional_field = array();
            $mapped_field_values = array();

            if( isset($form_options['stripe_condition']) && $form_options['stripe_condition'] == 1 ){
                $rules = $form_options['conditional_logic']['rules'] ? $form_options['conditional_logic']['rules'] : array();               
                if( $rules ){
                    foreach( $rules as $rule ){
                        if( $rule['field_id'] != '' ){
                            $mapped_conditional_field[] = $rule['field_id'];                                                    
                        }
                    }
                }
            }
            $query_in = " field_id IN";
            if( count($mapped_conditional_field) == 1 ){
                $query_in .= "(".$mapped_conditional_field[0].")";
            } else if(count($mapped_conditional_field) > 1) {
                $query_in .= "(".implode(',',$mapped_conditional_field).")";
            } else {
            	$query_in = " 1=1";
            }

            $values = $wpdb->get_results($wpdb->prepare("SELECT `field_id`,`entry_value` FROM `".$MdlDb->entry_metas."` WHERE `entry_id` = %d AND {$query_in}",$entry_id));
            foreach($values as $value){
                $mapped_field_values[$value->field_id] = $value->entry_value;
            }

            if( $form_options['stripe_condition'] && $form_options['stripe_condition'] == 1 ){
                $rules = $form_options['conditional_logic']['rules'] ? $form_options['conditional_logic']['rules'] : array();
                if( $rules ){
                    $matched = 0;
                    $total_rules = 0;
                    
                    foreach( $rules as $rule ){
                        if( $rule['field_id'] != '' )
                        {
                            $total_rules++;
                            
                            $value1 = isset( $mapped_field_values[ $rule['field_id'] ] ) ? $mapped_field_values[ $rule['field_id'] ] : '';
                            
                            $value1 = is_array($value1) ? $value1 : trim( strtolower($value1) );
        
                            $value2 = @trim( strtolower( $rule['value'] ) );
                            
                            $operator = $rule['operator'];
                            
                            if ($this->calculate_rule($value1, $value2, $operator, $rule['field_type']))
                                $matched++;                             
                        }
                    }
                    
                    
                    if( ($form_options['conditional_logic']['if_cond'] == 'all' && $total_rules == $matched) || ($form_options['conditional_logic']['if_cond'] == 'any' && $matched > 0) ){
                        $prevent_sending_email = true;
                    } else {
                        return $prevent_sending_email;
                    }
                    
                }
            }
        }

		return $prevent_sending_email;
	}
}

global $arf_stripe_api_url, $arf_stripe_plugin_slug;

$arf_stripe_api_url = $arf_stripe->arf_stripe_getapiurl();
$arf_stripe_plugin_slug = basename(dirname(__FILE__));

add_filter('pre_set_site_transient_update_plugins', 'arf_stripe_check_for_plugin_update');

function arf_stripe_check_for_plugin_update($checked_data) {
    global $arf_stripe_api_url, $arf_stripe_plugin_slug, $wp_version, $arf_stripe, $arf_stripe_version;


    if (empty($checked_data->checked))
        return $checked_data;

    $args = array(
        'slug' => $arf_stripe_plugin_slug,
        'version' => $arf_stripe_version,
        'other_variables' => $arf_stripe->arf_stripe_get_remote_post_params(),
    );

    $request_string = array(
        'body' => array(
            'action' => 'basic_check',
            'request' => serialize($args),
            'api-key' => md5(home_url())
        ),
        'user-agent' => 'ARFSTRP-WordPress/' . $wp_version . '; ' . home_url()
    );


    $raw_response = wp_remote_post($arf_stripe_api_url, $request_string);

    if (!is_wp_error($raw_response) && ($raw_response['response']['code'] == 200))
        $response = @unserialize($raw_response['body']);

    if (isset($response) && !empty($response) && isset($response->token) && $response->token != "")
    {
        update_option('arfstripe_update_token', $response->token);
    }


    if (isset($response) && is_object($response) && is_object($checked_data) && !empty($response))
        $checked_data->response[$arf_stripe_plugin_slug . '/' . $arf_stripe_plugin_slug . '.php'] = $response;

    return $checked_data;
}

add_filter('plugins_api', 'arf_stripe_plugin_api_call', 10, 3);

function arf_stripe_plugin_api_call($def, $action, $args) {
    global $arf_stripe_plugin_slug, $arf_stripe_api_url, $wp_version;

    if (!isset($args->slug) || ($args->slug != $arf_stripe_plugin_slug))
        return false;


    $plugin_info = get_site_transient('update_plugins');
    $current_version = $plugin_info->checked[$arf_stripe_plugin_slug . '/' . $arf_stripe_plugin_slug . '.php'];
    $args->version = $current_version;

    $request_string = array(
        'body' => array(
            'action' => $action,
            'update_token' => get_site_option('arfstripe_update_token'),
            'request' => serialize($args),
            'api-key' => md5(home_url())
        ),
        'user-agent' => 'ARFSTRP-WordPress/' . $wp_version . '; ' . home_url()
    );

    $request = wp_remote_post($arf_stripe_api_url, $request_string);

    if (is_wp_error($request)) {
        $res = new WP_Error('plugins_api_failed', 'An Unexpected HTTP Error occurred during the API request.</p> <p><a href="?" onclick="document.location.reload(); return false;">Try again</a>', $request->get_error_message());
    } else {
        $res = maybe_unserialize($request['body']);

        if ($res === false)
            $res = new WP_Error('plugins_api_failed', 'An unknown error occurred', $request['body']);
    }

    return $res;
}

?>